fc_address_list = [
    {'code': '*XFR', 'address': '2021 7th Avenue', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98121'},
    {'code': '0RY1', 'address': 'Pole 45 , 1401 Rue Champ Rouge', 'city': 'Saran', 'state': 'Loiret', 'country': 'France', 'zip_code': '45770'},
    {'code': 'ABE1', 'address': '705 Boulder Dr', 'city': 'Breinigsville', 'state': 'PA', 'country': 'USA', 'zip_code': '18105'},
    {'code': 'ABE2', 'address': '705 Boulder Dr', 'city': 'Breinigsville', 'state': 'PA', 'country': 'USA', 'zip_code': '18031-1533'},
    {'code': 'ABE3', 'address': '650 BOULDER DRIVE', 'city': 'BREINIGSVILLE', 'state': 'PA', 'country': 'USA', 'zip_code': '18031-1536'},
    {'code': 'ABE4', 'address': '1610 VAN BUREN RD.', 'city': 'EASTON', 'state': 'PA', 'country': 'USA', 'zip_code': '18045-7807'},
    {'code': 'ABE5', 'address': '100 Quality Circle, Suite 107', 'city': 'Harrisburg', 'state': 'PA', 'country': 'USA', 'zip_code': '17112'},
    {'code': 'ABE7', 'address': '12510 Micro Dr', 'city': 'Mira Loma', 'state': 'CA', 'country': 'USA', 'zip_code': '91752'},
    {'code': 'ABE8', 'address': '309 CEDAR LANE', 'city': 'FLORENCE', 'state': 'NJ', 'country': 'USA', 'zip_code': '08518-2802'},
    {'code': 'ABE9', 'address': '100 Quality Circle, Suite 106', 'city': 'Harrisburg', 'state': 'PA', 'country': 'USA', 'zip_code': '17112'},
    {'code': 'ABEX', 'address': '698 Route 46 West', 'city': 'Teterboro', 'state': 'NJ', 'country': 'USA', 'zip_code': '7608'},
    {'code': 'ABQ1', 'address': '701 ATRISCO VISTA BLVD', 'city': 'ALBUQUERQUE', 'state': 'NM', 'country': 'USA', 'zip_code': '87120'},
    {'code': 'ABQ5', 'address': '15480 RESERVOIR RD NW', 'city': 'ALBUQUERQUE', 'state': 'NM', 'country': 'USA', 'zip_code': '87121'},
    {'code': 'ACY1', 'address': '240 Mantua Grove Rd', 'city': 'West Deptford', 'state': 'NJ', 'country': 'USA', 'zip_code': '08066-1731'},
    {'code': 'ACY2', 'address': '1101 E Pearl St', 'city': 'Burlington', 'state': 'NJ', 'country': 'USA', 'zip_code': '08016-1934'},
    {'code': 'ACY5', 'address': '2277 Center Square Rd', 'city': 'Logan Township', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'ACY8', 'address': '8 CAMPUS DR', 'city': 'BURLINGTON', 'state': 'NJ', 'country': 'USA', 'zip_code': '8016'},
    {'code': 'ACY9', 'address': '1150 COMMERCE BLVD', 'city': 'LOGAN TOWNSHIP', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'ADS1', 'address': '4121 INTERNATIONAL PARKWAY', 'city': 'CARROLLTON', 'state': 'TX', 'country': 'USA', 'zip_code': '75007'},
    {'code': 'AFW1', 'address': '1511 NE Loop 820', 'city': 'Ft Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76106-9755'},
    {'code': 'AFW2', 'address': '12728 LAKE JUNERD', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75180'},
    {'code': 'AGS1', 'address': '2150 DISCOVERY DRIVE', 'city': 'APPLING', 'state': 'GA', 'country': 'USA', 'zip_code': '30802'},
    {'code': 'AGS2', 'address': '429 Toy Wright Rd', 'city': 'Pendergrass', 'state': 'GA', 'country': 'USA', 'zip_code': '30567'},
    {'code': 'AGS5', 'address': '785 INNOVATION PKWY', 'city': 'APPLING', 'state': 'GA', 'country': 'USA', 'zip_code': '30802'},
    {'code': 'AKC1', 'address': '2400 ROMING RD', 'city': 'AKRON', 'state': 'OH', 'country': 'USA', 'zip_code': '44320'},
    {'code': 'ALB1', 'address': '1835 US 9', 'city': 'CASTLETON', 'state': 'NY', 'country': 'USA', 'zip_code': '12033'},
    {'code': 'ALT9', 'address': '(920 Highway 124)', 'city': 'Braselton', 'state': 'GA', 'country': 'USA', 'zip_code': '30517'},
    {'code': 'AMA1', 'address': '2395 N. LAKESIDE DR', 'city': 'AMARILLO', 'state': 'TX', 'country': 'USA', 'zip_code': '79118'},
    {'code': 'ARR1', 'address': '4200 FERRY RD', 'city': 'AURORA', 'state': 'IL', 'country': 'USA', 'zip_code': '60502'},
    {'code': 'ASE3', 'address': '20526 59th Place South', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'ASH1', 'address': '267 LOWELL RD', 'city': 'HUDSON', 'state': 'NH', 'country': 'USA', 'zip_code': '3051'},
    {'code': 'ASH2', 'address': '15 STEELE RD', 'city': 'HUDSON', 'state': 'NH', 'country': 'USA', 'zip_code': '3051'},
    {'code': 'ATL2', 'address': '2255 W Park Blvd', 'city': 'Stone Mountain', 'state': 'GA', 'country': 'USA', 'zip_code': '30087'},
    {'code': 'ATL6', 'address': '4200 N Commerce Dr', 'city': 'Atlanta', 'state': 'GA', 'country': 'USA', 'zip_code': '30344-5707'},
    {'code': 'ATL7', 'address': '6855 Shannon Pkwy', 'city': 'Union City', 'state': 'GA', 'country': 'USA', 'zip_code': '30291-2091'},
    {'code': 'ATL8', 'address': '2201 THORNTON ROAD', 'city': 'LITHIA SPRINGS', 'state': 'GA', 'country': 'USA', 'zip_code': '30122-3895'},
    {'code': 'ATL9', 'address': '2232 Northmont Parkway', 'city': 'Duluth', 'state': 'GA', 'country': 'USA', 'zip_code': '30096'},
    {'code': 'ATS3', 'address': '8601 W JEFFERSON ST., SUITE 300', 'city': 'TOLLESON', 'state': 'AZ', 'country': 'USA', 'zip_code': '85353'},
    {'code': 'AUN2', 'address': '7449 45TH STREET CTE', 'city': 'FIFE', 'state': 'WA', 'country': 'USA', 'zip_code': '98424'},
    {'code': 'AUS2', 'address': '00 E Pecan St', 'city': 'Pflugerville', 'state': 'TX', 'country': 'USA', 'zip_code': '78660'},
    {'code': 'AUS3', 'address': '2000 EXCHANGE PARKWAY', 'city': 'WACO', 'state': 'TX', 'country': 'USA', 'zip_code': '76712'},
    {'code': 'AUS5', 'address': '2575 Kyle Crossing', 'city': 'Kyle', 'state': 'TX', 'country': 'USA', 'zip_code': '78640-5345'},
    {'code': 'AVP1', 'address': '550 OAK RIDGE RD', 'city': 'Hazleton', 'state': 'PA', 'country': 'USA', 'zip_code': '18202-9361'},
    {'code': 'AVP2', 'address': '298 1st Ave', 'city': 'Gouldsboro', 'state': 'PA', 'country': 'USA', 'zip_code': '18424'},
    {'code': 'AVP3', 'address': '298 1ST AVE.', 'city': 'GOULDSBORO', 'state': 'PA', 'country': 'USA', 'zip_code': '18424-9492'},
    {'code': 'AVP6', 'address': '1 COMMERCE ROAD', 'city': 'PITTSTON', 'state': 'PA', 'country': 'USA', 'zip_code': '18640'},
    {'code': 'AVP8', 'address': '250 ENTERPRISE WAY', 'city': 'PITTSTON', 'state': 'PA', 'country': 'USA', 'zip_code': '18640-5000'},
    {'code': 'AVP9', 'address': '45 VALLEY VIEW DR', 'city': 'JESSUP', 'state': 'PA', 'country': 'USA', 'zip_code': '18434'},
    {'code': 'AWA1', 'address': '20529 24TH AVE S', 'city': 'SEATAC', 'state': 'WA', 'country': 'USA', 'zip_code': '98198'},
    {'code': 'AWA2', 'address': '20530 24TH AVE S', 'city': 'SEATAC', 'state': 'WA', 'country': 'USA', 'zip_code': '98198'},
    {'code': 'AZA4', 'address': '3333 S 59th Ave', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'AZA5', 'address': '6000 W Van Buren St.', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'AZA6', 'address': '2150 East Riverview Drive', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85034'},
    {'code': 'AZA9', 'address': '6395 N. SARIVAL AVE', 'city': 'LITCHFIELD PARK', 'state': 'AZ', 'country': 'USA', 'zip_code': '85340'},
    {'code': 'B0M1', 'address': 'Bhiwandi, Mumbai, Maharashtra', 'city': 'Bhiwandi, Mumbai', 'state': 'Maharashtra', 'country': 'India', 'zip_code': '250000'},
    {'code': 'BAY1', 'address': '555 Maritime Street, Bldg. D512', 'city': 'OAKLAND', 'state': 'CA', 'country': 'USA', 'zip_code': '94607'},
    {'code': 'BCN1', 'address': 'Mas Blau II industrial estate', 'city': 'El Prat de Llobregat', 'state': 'Barcelona', 'country': 'Spain', 'zip_code': ''},
    {'code': 'BDL1', 'address': '200 Old Iron Ore Rd', 'city': 'Windsor', 'state': 'CT', 'country': 'USA', 'zip_code': '06095-2144'},
    {'code': 'BDL2', 'address': '200 Old Iron Ore Rd', 'city': 'Windsor', 'state': 'CT', 'country': 'USA', 'zip_code': '06095-2144'},
    {'code': 'BDL3', 'address': '409 Washington Ave.', 'city': 'North Haven', 'state': 'CT', 'country': 'USA', 'zip_code': '6473'},
    {'code': 'BDL4', 'address': '1215 KENNEDY RD', 'city': 'WINDSOR', 'state': 'CT', 'country': 'USA', 'zip_code': '6095'},
    {'code': 'BDL5', 'address': '29 RESEARCH PARKWAY', 'city': 'WALLINGFORD', 'state': 'CT', 'country': 'USA', 'zip_code': '06492-1927'},
    {'code': 'BDL6', 'address': '120 County Line Dr', 'city': 'Cromwell', 'state': 'CT', 'country': 'USA', 'zip_code': '06416-1186'},
    {'code': 'BDU2', 'address': '8350 Quintero St', 'city': 'COMMERCE CITY', 'state': 'CO', 'country': 'USA', 'zip_code': '80022'},
    {'code': 'BDU5', 'address': '8350 Quintero St', 'city': 'Commerce City', 'state': 'CO', 'country': 'USA', 'zip_code': '80022-8453'},
    {'code': 'BEK1', 'address': '2495 Bancroft Way Room 235, MLK Student Union Building', 'city': 'Berkeley', 'state': 'CA', 'country': 'USA', 'zip_code': '94720'},
    {'code': 'BER3', 'address': 'Amazon Logistik Potsdam GmbH Havellandsrasse 5', 'city': 'Brieselang', 'state': 'Brandenburg', 'country': 'Germany', 'zip_code': '14656'},
    {'code': 'BFC1', 'address': '380 Middlesex Ave', 'city': 'CARTERET', 'state': 'NJ', 'country': 'USA', 'zip_code': '07008-3445'},
    {'code': 'BFI1', 'address': '1800 140TH AVE. EAST', 'city': 'SUMNER', 'state': 'WA', 'country': 'USA', 'zip_code': '98390-9624'},
    {'code': 'BFI2', 'address': '1800 140th Avenue E', 'city': 'SUMNER', 'state': 'WA', 'country': 'USA', 'zip_code': '98390'},
    {'code': 'BFI3', 'address': '2700 Center Dr', 'city': 'Dupont', 'state': 'WA', 'country': 'USA', 'zip_code': '98327-9607'},
    {'code': 'BFI4', 'address': '21005 64TH AVENUE S', 'city': 'KENT', 'state': 'WA', 'country': 'USA', 'zip_code': '98032-2423'},
    {'code': 'BFI5', 'address': '20526 59th Plc S', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'BFI6', 'address': '20280 84TH AVE. SOUTH', 'city': 'KENT', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'BFI7', 'address': '1901 140TH AVE. E', 'city': 'SUMNER', 'state': 'WA', 'country': 'USA', 'zip_code': '98390'},
    {'code': 'BFI8', 'address': '20529 24th Ave S', 'city': 'SEATAC', 'state': 'WA', 'country': 'USA', 'zip_code': '98198'},
    {'code': 'BFI9', 'address': '3230 INTERNATIONAL PLACE', 'city': 'DUPONT', 'state': 'WA', 'country': 'USA', 'zip_code': '98327'},
    {'code': 'BFIX', 'address': '1800 140th Ave E, Suite XB', 'city': 'Sumner', 'state': 'WA', 'country': 'USA', 'zip_code': '98390-9624'},
    {'code': 'BFL1', 'address': '1601 PETROL RD', 'city': 'BAKERSFIELD', 'state': 'CA', 'country': 'USA', 'zip_code': '93308'},
    {'code': 'BFL2', 'address': '4500 EXPRESS AVE', 'city': 'SHAFTER', 'state': 'CA', 'country': 'USA', 'zip_code': '93263'},
    {'code': 'BFN1', 'address': '6001 BETHLEHEM BLVD', 'city': 'SPARROWS POINT', 'state': 'MD', 'country': 'USA', 'zip_code': '21219'},
    {'code': 'BHM1', 'address': '975 POWDER PLANT RD.', 'city': 'BESSEMER', 'state': 'AL', 'country': 'USA', 'zip_code': '35022'},
    {'code': 'BHX1', 'address': 'Towers Business Park, Power Station Road', 'city': 'Rugeley', 'state': 'Staffordshire', 'country': 'United Kingdom', 'zip_code': 'WS15 1LX'},
    {'code': 'BLF1', 'address': '1601 PETROL RD', 'city': 'BAKERSFIELD', 'state': 'CA', 'country': 'USA', 'zip_code': '93308'},
    {'code': 'BLR5', 'address': 'Bengaluru, Bangalore, Karnataka', 'city': 'Bengaluru, Bangalore', 'state': 'Karnataka', 'country': 'India', 'zip_code': ''},
    {'code': 'BLR6', 'address': 'Bengaluru, Bangalore. Karnataka', 'city': 'Bengaluru, Bangalore', 'state': 'Karnataka', 'country': 'India', 'zip_code': ''},
    {'code': 'BLV2', 'address': '8850 SpringdaleAve', 'city': 'BERKLEY', 'state': 'MO', 'country': 'USA', 'zip_code': '63134'},
    {'code': 'BNA1', 'address': '14840 CENTRAL PIKE STE 190', 'city': 'LEBANON', 'state': 'TN', 'country': 'USA', 'zip_code': '37090-8119'},
    {'code': 'BNA2', 'address': '500 DUKE DR', 'city': 'LEBANON', 'state': 'TN', 'country': 'USA', 'zip_code': '37087-8123'},
    {'code': 'BNA3', 'address': '2020 JOE B JACKSON PKWY', 'city': 'MURFREESBORO', 'state': 'TN', 'country': 'USA', 'zip_code': '37127-7792'},
    {'code': 'BNA4', 'address': '50 Airways Blvd.', 'city': 'Nashville', 'state': 'TN', 'country': 'USA', 'zip_code': '37217'},
    {'code': 'BNA5', 'address': '50 Airways Blvd', 'city': 'Nashville', 'state': 'TN', 'country': 'USA', 'zip_code': '37217-2516'},
    {'code': 'BNA8', 'address': '1000 DARRELL WALTRIP DR', 'city': 'LEBANON', 'state': 'TN', 'country': 'USA', 'zip_code': '37090'},
    {'code': 'BNA9', 'address': '700 MASON RD, PARK 24/BLDG 7', 'city': 'LA VERGNE', 'state': 'TN', 'country': 'USA', 'zip_code': '37086'},
    {'code': 'BOI2', 'address': '5295 E Franklin Rd', 'city': 'Nampa', 'state': 'ID', 'country': 'USA', 'zip_code': '83687-5548'},
    {'code': 'BOI5', 'address': '2155 E. FREIGHT ST', 'city': 'BOISE', 'state': 'ID', 'country': 'USA', 'zip_code': '83716'},
    {'code': 'BOM1', 'address': 'Bhiwandi', 'city': 'Bhiwandi', 'state': '', 'country': 'India', 'zip_code': ''},
    {'code': 'BOS1', 'address': '10 State St', 'city': 'Nashua', 'state': 'NH', 'country': 'USA', 'zip_code': '3063'},
    {'code': 'BOS3', 'address': '', 'city': 'Fall River', 'state': 'MA', 'country': 'USA', 'zip_code': '2720'},
    {'code': 'BOS4', 'address': '1 NATIONAL ST', 'city': 'MILFORD', 'state': 'MA', 'country': 'USA', 'zip_code': '1757'},
    {'code': 'BOS5', 'address': '1000 Technology Center Dr', 'city': 'Stoughton', 'state': 'MA', 'country': 'USA', 'zip_code': '02072-4744'},
    {'code': 'BOS6', 'address': '201 BEACHAM ST.', 'city': 'EVERETT', 'state': 'MA', 'country': 'USA', 'zip_code': '02149-5518'},
    {'code': 'BOS7', 'address': '1180 Innovation Way', 'city': 'Fall River', 'state': 'MA', 'country': 'USA', 'zip_code': '02720-4766'},
    {'code': 'BOS8', 'address': '870 Commonwealth Ave', 'city': 'Brookline', 'state': 'MA', 'country': 'USA', 'zip_code': '2215'},
    {'code': 'BOS9', 'address': '750 Everett St', 'city': 'Norwood', 'state': 'MA', 'country': 'USA', 'zip_code': '02062-2618'},
    {'code': 'BTR9', 'address': '3191 Webster Lane', 'city': 'Port Allen', 'state': 'LA', 'country': 'USA', 'zip_code': '70767-4100'},
    {'code': 'BUF5', 'address': '4201 WALDEN AVE.', 'city': 'LANCASTER', 'state': 'NY', 'country': 'USA', 'zip_code': '14086'},
    {'code': 'BUF9', 'address': '4201 Walden Ave', 'city': 'Lancaster', 'state': 'NY', 'country': 'USA', 'zip_code': '14086'},
    {'code': 'BUR2', 'address': '925 Westwood Boulevard', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90024'},
    {'code': 'BUR7', 'address': '11200 Iberia St.', 'city': 'MIRA LOMA', 'state': 'CA', 'country': 'USA', 'zip_code': '91752'},
    {'code': 'BWI0', 'address': '2010 Broening Highway', 'city': 'Baltimore', 'state': 'MD', 'country': 'USA', 'zip_code': '21224'},
    {'code': 'BWI1', 'address': '45121 GLOBAL PLAZA', 'city': 'STERLING', 'state': 'VA', 'country': 'USA', 'zip_code': '20166'},
    {'code': 'BWI2', 'address': '2010 Broening Hwy', 'city': 'Baltimore', 'state': 'MD', 'country': 'USA', 'zip_code': '21224-6027'},
    {'code': 'BWI4', 'address': '165 BUSINESS BLVD', 'city': 'CLEAR BROOK', 'state': 'VA', 'country': 'USA', 'zip_code': '22624'},
    {'code': 'BWI5', 'address': '5501 Holabird Ave', 'city': 'Baltimore', 'state': 'MD', 'country': 'USA', 'zip_code': '21224-6026'},
    {'code': 'BWI6', 'address': '5617 INDUSTRIAL DRIVE, SUITE A', 'city': 'SPRINGFIELD', 'state': 'VA', 'country': 'USA', 'zip_code': '22151-4410'},
    {'code': 'CAE1', 'address': '4400 12TH ST EXTENSION', 'city': 'WEST COLUMBIA', 'state': 'SC', 'country': 'USA', 'zip_code': '29172-3300'},
    {'code': 'CAE3', 'address': '222 OLD WIRE ROAD', 'city': 'WEST COLUMBIA', 'state': 'SC', 'country': 'USA', 'zip_code': '29172-2862'},
    {'code': 'CAK1', 'address': '290 E Exchange Street', 'city': 'Akron', 'state': 'OH', 'country': 'USA', 'zip_code': '44304'},
    {'code': 'CAN1', 'address': 'Huangpu District, Guangzhou, Guangdong', 'city': 'Guangzhou', 'state': 'Guangdong', 'country': 'China', 'zip_code': ''},
    {'code': 'CAN2', 'address': 'Guangdong Champion Valley Park', 'city': 'Guangzhou', 'state': 'Guangdong', 'country': 'China', 'zip_code': ''},
    {'code': 'CAN4', 'address': 'Huangpu Development Zone', 'city': 'Guangzhou', 'state': 'Guangdong', 'country': 'China', 'zip_code': ''},
    {'code': 'CFL1', 'address': '4225 East Plaza Drive', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32816'},
    {'code': 'CGN1', 'address': 'Amazonstrasse 1 / Am Autobahnkreuz', 'city': 'Koblenz', 'state': 'North Rhineland', 'country': 'Germany', 'zip_code': '56068'},
    {'code': 'CHA1', 'address': '7200 DISCOVERY DRIVE', 'city': 'CHATTANOOGA', 'state': 'TN', 'country': 'USA', 'zip_code': '37421'},
    {'code': 'CHA2', 'address': '225 INFINITY DR NW', 'city': 'CHARESTON', 'state': 'TN', 'country': 'USA', 'zip_code': '37310-1400'},
    {'code': 'CHI1', 'address': '750 S Halsted St, Student Center East, #214', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60607'},
    {'code': 'CHI3', 'address': '2720 N Clark St', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60614'},
    {'code': 'CHS1', 'address': '7290 Investment Drive', 'city': 'N Charleston', 'state': 'SC', 'country': 'USA', 'zip_code': '29418'},
    {'code': 'CHS4', 'address': '400 Long Point Rd', 'city': 'MOUNT PLEASANT', 'state': 'SC', 'country': 'USA', 'zip_code': '29464'},
    {'code': 'CIN1', 'address': '241 Calhoun St', 'city': 'Cincinnati', 'state': 'OH', 'country': 'USA', 'zip_code': '45219'},
    {'code': 'CLE1', 'address': '2020 Euclid Ave', 'city': 'Cleveland', 'state': 'OH', 'country': 'USA', 'zip_code': '44115'},
    {'code': 'CLE2', 'address': '21500 Emery Rd', 'city': 'North Randall', 'state': 'OH', 'country': 'USA', 'zip_code': '44128-4546'},
    {'code': 'CLE3', 'address': '1155 BABBITT ROAD', 'city': 'EUCLID', 'state': 'OH', 'country': 'USA', 'zip_code': '44132'},
    {'code': 'CLE5', 'address': '8685 INDEPENDENCE PARKWAY', 'city': 'TWINSBURG', 'state': 'OH', 'country': 'USA', 'zip_code': '44087-1971'},
    {'code': 'CLE6', 'address': '23371 Aurora Road', 'city': 'Bedford Heights', 'state': 'OH', 'country': 'USA', 'zip_code': '44146'},
    {'code': 'CLT1', 'address': '7035 Northwinds Drive', 'city': 'Concord', 'state': 'NC', 'country': 'USA', 'zip_code': '28027'},
    {'code': 'CLT2', 'address': '10240 OLD DOWD ROAD', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28214-8082'},
    {'code': 'CLT3', 'address': '6500 Davidson Hwy', 'city': 'Concord', 'state': 'NC', 'country': 'USA', 'zip_code': '28027-7995'},
    {'code': 'CLT4', 'address': '8000 TUCKASEEGEE RD', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28214'},
    {'code': 'CLT5', 'address': '1745 Derita Rd', 'city': 'Concord', 'state': 'NC', 'country': 'USA', 'zip_code': '28027-3353'},
    {'code': 'CLT6', 'address': '12220 CAROLINA LOGISTICS DR', 'city': 'PINEVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '28134'},
    {'code': 'CLT9', 'address': '3620 REEVES RIDGE RD', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28214'},
    {'code': 'CMH0', 'address': '11903 National RD SW Etna Township Park', 'city': 'Etna', 'state': 'OH', 'country': 'USA', 'zip_code': '43062'},
    {'code': 'CMH1', 'address': '11903 National Rd SW', 'city': 'Etna', 'state': 'OH', 'country': 'USA', 'zip_code': '43062-7793'},
    {'code': 'CMH2', 'address': '6050 Gateway Court', 'city': 'Obetz', 'state': 'OH', 'country': 'USA', 'zip_code': '43125'},
    {'code': 'CMH3', 'address': '700 GATEWAY BLVD', 'city': 'MONROE', 'state': 'OH', 'country': 'USA', 'zip_code': '45050'},
    {'code': 'CMH4', 'address': '1550 W Main St.', 'city': 'West Jefferson', 'state': 'OH', 'country': 'USA', 'zip_code': '43162'},
    {'code': 'CMH5', 'address': '6400 State Route 29', 'city': 'West Jefferson', 'state': 'OH', 'country': 'USA', 'zip_code': '43162-9746'},
    {'code': 'CMH6', 'address': '3538 Tradeport Ct.', 'city': 'LOCKBOURNE', 'state': 'OH', 'country': 'USA', 'zip_code': '43137'},
    {'code': 'CMI1', 'address': '809S Wright Street', 'city': 'Champaign', 'state': 'IL', 'country': 'USA', 'zip_code': '61820'},
    {'code': 'CNO5', 'address': '8601 MERRILL AVE', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91710'},
    {'code': 'CON1', 'address': '40 Wilbur Cross Way, Suite 104', 'city': 'Mansfield', 'state': 'CT', 'country': 'USA', 'zip_code': '6268'},
    {'code': 'COS5', 'address': '4333 Integration Loop', 'city': 'Colorado Springs', 'state': 'CO', 'country': 'USA', 'zip_code': '80916-5770'},
    {'code': 'CSD1', 'address': '9500 Gilman Drive #0102', 'city': 'La Jolla', 'state': 'CA', 'country': 'USA', 'zip_code': '92093'},
    {'code': 'CSG1', 'address': '280 Bridgeport Blvd', 'city': 'Newnan', 'state': 'GA', 'country': 'USA', 'zip_code': '30263'},
    {'code': 'CTU1', 'address': 'ProLogis Industrial Park in the west park of Chengdu Hi-Tech Zone', 'city': 'Chengdu', 'state': 'Sichuan', 'country': 'China', 'zip_code': ''},
    {'code': 'CTU2', 'address': 'Tianfu New Area', 'city': 'Chengdu', 'state': 'Sichuan', 'country': 'China', 'zip_code': ''},
    {'code': 'CVG1', 'address': '1155 Worldwide Blvd., Bldg. F Park W Intl.', 'city': 'Hebron', 'state': 'KY', 'country': 'USA', 'zip_code': '41048-8640'},
    {'code': 'CVG2', 'address': '1600 Worldwide Blvd.', 'city': 'Hebron', 'state': 'KY', 'country': 'USA', 'zip_code': '41048-8640'},
    {'code': 'CVG3', 'address': '3680 Langley Dr.', 'city': 'Hebron', 'state': 'KY', 'country': 'USA', 'zip_code': '41048-9135'},
    {'code': 'CVG5', 'address': '2285 LITTON WAY', 'city': 'HEBRON', 'state': 'KY', 'country': 'USA', 'zip_code': '41048-8435'},
    {'code': 'CVG7', 'address': '560 Erlanger Rd', 'city': 'Erlanger', 'state': 'KY', 'country': 'USA', 'zip_code': '41018-1242'},
    {'code': 'CVG8', 'address': '7968 Kentucky Drive, Suites 2-3', 'city': 'Florence', 'state': 'KY', 'country': 'USA', 'zip_code': '41042'},
    {'code': 'CVG9', 'address': '2305 LITTON LANE', 'city': 'HEBRON', 'state': 'KY', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'CWL1', 'address': 'Ffordd Amazon, Crymlyn Burrows', 'city': 'Jersey Marine', 'state': 'Swansea Bay', 'country': 'United Kingdom', 'zip_code': 'SA1 8QX'},
    {'code': 'DAB4', 'address': '1785 State Hwy 55', 'city': 'Amsterdam', 'state': 'NY', 'country': 'USA', 'zip_code': '12010-8173'},
    {'code': 'DAB8', 'address': '100 PRECISION DR', 'city': 'SHIRLEY', 'state': 'NY', 'country': 'USA', 'zip_code': '11967'},
    {'code': 'DAE1', 'address': '2595 Brodhead Rd.', 'city': 'Bethlehem', 'state': 'PA', 'country': 'USA', 'zip_code': '18020'},
    {'code': 'DAE8', 'address': '53 WEST GERMANTOWN PIKE', 'city': 'EAST NORRITON', 'state': 'PA', 'country': 'USA', 'zip_code': '19401'},
    {'code': 'DAL2', 'address': '2601 S AIRFIELD DR', 'city': 'IRVING', 'state': 'TX', 'country': 'USA', 'zip_code': '75038'},
    {'code': 'DAL3', 'address': '1301 Chalk Hill Rd', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75211-0108'},
    {'code': 'DAL6', 'address': '4601 Gold Spike', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76106'},
    {'code': 'DAL9', 'address': '1400 SOUTHPORT PKWY', 'city': 'WILMER', 'state': 'TX', 'country': 'USA', 'zip_code': '75172'},
    {'code': 'DAS8', 'address': '110 Fordham Rd.', 'city': 'WILMINGTON', 'state': 'MA', 'country': 'USA', 'zip_code': '1887'},
    {'code': 'DAT2', 'address': '1700 BELLE MEADE CT', 'city': 'LAWRENCEVILLE', 'state': 'GA', 'country': 'USA', 'zip_code': '30043'},
    {'code': 'DAT6', 'address': '7055 CAMPBELLTON RD', 'city': 'ATLANTA', 'state': 'GA', 'country': 'USA', 'zip_code': '30331'},
    {'code': 'DAU1', 'address': '2093-2209 Rutland Dr', 'city': 'Austin', 'state': 'TX', 'country': 'USA', 'zip_code': '78758'},
    {'code': 'DAU5', 'address': '2956 MAIN ST.', 'city': 'BUDA', 'state': 'TX', 'country': 'USA', 'zip_code': '78610'},
    {'code': 'DAU7', 'address': '3150 CHISHOLM TRAIL RD', 'city': 'ROUND ROCK', 'state': 'TX', 'country': 'USA', 'zip_code': '78681'},
    {'code': 'DAV1', 'address': '1 Shields Ave, Room 182', 'city': 'Davis', 'state': 'CA', 'country': 'USA', 'zip_code': '95616-8662'},
    {'code': 'DAX3', 'address': '20730 Prairie St', 'city': 'Charsworth', 'state': 'CA', 'country': 'USA', 'zip_code': '91311-6010'},
    {'code': 'DAX7', 'address': '9350 RAYO AVE', 'city': 'SOUTH GATE', 'state': 'CA', 'country': 'USA', 'zip_code': '90280'},
    {'code': 'DAX8', 'address': '500 W Technology Dr', 'city': 'Palmdale', 'state': 'CA', 'country': 'USA', 'zip_code': '93551-3748'},
    {'code': 'DAY3', 'address': '700 Gateway Blvd', 'city': 'Monroe', 'state': 'OH', 'country': 'USA', 'zip_code': '45050-1848'},
    {'code': 'DB01', 'address': '201 Beacham Street', 'city': 'Everett (Chelsea)', 'state': 'MA', 'country': 'USA', 'zip_code': '2149'},
    {'code': 'DB02', 'address': '500 Sprague St.', 'city': 'Dedham', 'state': 'MA', 'country': 'USA', 'zip_code': '2026'},
    {'code': 'DBA7', 'address': '16604 INDUSTRIAL LANE', 'city': 'WILLIAMSPORT', 'state': 'MD', 'country': 'USA', 'zip_code': '21795'},
    {'code': 'DBA8', 'address': '7021 DORSEY RD', 'city': 'HANOVER', 'state': 'MD', 'country': 'USA', 'zip_code': '21076'},
    {'code': 'DBC3', 'address': '800 JOHN QUINCY ADAMDS RD', 'city': 'TAUNTON', 'state': 'MA', 'country': 'USA', 'zip_code': '2780'},
    {'code': 'DBC6', 'address': '100 INDUSTRIAL PARK RD', 'city': 'HINGHAM', 'state': 'MA', 'country': 'USA', 'zip_code': '2043'},
    {'code': 'DBK1', 'address': '1 BULOVA AVE', 'city': 'WOODSIDE', 'state': 'NY', 'country': 'USA', 'zip_code': '11377'},
    {'code': 'DBK6', 'address': '2300 Linden Blvd', 'city': 'Brooklyn', 'state': 'NY', 'country': 'USA', 'zip_code': '11208-4844'},
    {'code': 'DBL8', 'address': '8 OLD SHERMAN TURNPIKE, #24', 'city': 'DANBURY', 'state': 'CT', 'country': 'USA', 'zip_code': '6810'},
    {'code': 'DBO8', 'address': '24 ALGER ST', 'city': 'BOSTON', 'state': 'MA', 'country': 'USA', 'zip_code': '2127'},
    {'code': 'DBO9', 'address': '30 COMMERCE BLVD', 'city': 'MIDDLEBOROUGH', 'state': 'MA', 'country': 'USA', 'zip_code': '2346'},
    {'code': 'DBU1', 'address': '400 RIVERWALK PKWY', 'city': 'TONAWANDA NY', 'state': 'NY', 'country': 'USA', 'zip_code': '14150-5815'},
    {'code': 'DBU3', 'address': '2 WESTBURY AVE', 'city': 'CARLE PLACE', 'state': 'NY', 'country': 'USA', 'zip_code': '11514'},
    {'code': 'DCA1', 'address': '1700 SPARROWS POINT BLVD.', 'city': 'SPARROWS POINT', 'state': 'MD', 'country': 'USA', 'zip_code': '21219'},
    {'code': 'DCA2', 'address': '5250 Goodman Way', 'city': 'Eastvale', 'state': 'CA', 'country': 'USA', 'zip_code': '91752-5088'},
    {'code': 'DCA6', 'address': '6001 BETHLEHEM BLVD', 'city': 'EDGEMERE', 'state': 'MD', 'country': 'USA', 'zip_code': '21219'},
    {'code': 'DCB2', 'address': '560 WEST ST', 'city': 'MANSFIELD', 'state': 'MA', 'country': 'USA', 'zip_code': '2048'},
    {'code': 'DCB8', 'address': '351 MAPLE ST', 'city': 'BELLINGHAM', 'state': 'MA', 'country': 'USA', 'zip_code': '2019'},
    {'code': 'DCH1', 'address': '2801 S. Western Ave.', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60608'},
    {'code': 'DCH2', 'address': '8220 Austin Ave.', 'city': 'Morton Grove', 'state': 'IL', 'country': 'USA', 'zip_code': '60053'},
    {'code': 'DCH3', 'address': '4500 Western Ave.', 'city': 'Lisle', 'state': 'IL', 'country': 'USA', 'zip_code': '60532'},
    {'code': 'DCH9', 'address': '7557 S 78TH AVE., #7575', 'city': 'BRIDGEVIEW', 'state': 'IL', 'country': 'USA', 'zip_code': '60455'},
    {'code': 'DCL4', 'address': '24800 MILES RD', 'city': 'BEDFORD', 'state': 'OH', 'country': 'USA', 'zip_code': '44146'},
    {'code': 'DCL5', 'address': '2040 S. REYNOLDS RD', 'city': 'TOLEDO', 'state': 'OH', 'country': 'USA', 'zip_code': '43614'},
    {'code': 'DCM3', 'address': '43500 VICTORY PARKWAY', 'city': 'SOLON', 'state': 'OH', 'country': 'USA', 'zip_code': '44139'},
    {'code': 'DCM5', 'address': '8591 Mink St SW', 'city': 'Etna', 'state': 'OH', 'country': 'USA', 'zip_code': '43062-8870'},
    {'code': 'DCM6', 'address': '1280 London Groveport Rd', 'city': 'Lockbourne', 'state': 'OH', 'country': 'USA', 'zip_code': '43137'},
    {'code': 'DCR1', 'address': 'Units 2 - 4, Access 23, Purley Way, 4-8 Queensway', 'city': 'Croydon', 'state': 'South London', 'country': 'United Kingdom', 'zip_code': 'CRO 4BD'},
    {'code': 'DCX1', 'address': '7227 CENTRAL AVE', 'city': 'RIVERSIDE', 'state': 'CA', 'country': 'USA', 'zip_code': '92504'},
    {'code': 'DCX2', 'address': '25725 JERONIMO RD.', 'city': 'MISSION VIEJO', 'state': 'CA', 'country': 'USA', 'zip_code': '92691'},
    {'code': 'DCX5', 'address': '970 McLaughlin Ave', 'city': 'San Jose', 'state': 'CA', 'country': 'USA', 'zip_code': '95122-2611'},
    {'code': 'DCX7', 'address': '950 FRANCISCO ST', 'city': 'TORRANCE', 'state': 'CA', 'country': 'USA', 'zip_code': '90502'},
    {'code': 'DCX8', 'address': '1256 N Magnolia Ave.', 'city': 'Anaheim', 'state': 'CA', 'country': 'USA', 'zip_code': '92801'},
    {'code': 'DCY9', 'address': '48 Boston Post Rd', 'city': 'Orange', 'state': 'CT', 'country': 'USA', 'zip_code': '6477'},
    {'code': 'DDA2', 'address': '3838 W MILLER RD', 'city': 'GARLAND', 'state': 'TX', 'country': 'USA', 'zip_code': '75041'},
    {'code': 'DDA3', 'address': '4601 GOLD SPIKE DR.', 'city': 'FORT WORTH', 'state': 'TX', 'country': 'USA', 'zip_code': '76106'},
    {'code': 'DDA8', 'address': '8901 FORNEY RD', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75227'},
    {'code': 'DDA9', 'address': '3700 San Jacinto Dr', 'city': 'Ft Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76126'},
    {'code': 'DDC1', 'address': '12401 North Stemmons Fwy.', 'city': 'Farmers Branch', 'state': 'TX', 'country': 'USA', 'zip_code': '75234'},
    {'code': 'DDC2', 'address': '861 E Gude Drive', 'city': 'Rockville', 'state': 'MD', 'country': 'USA', 'zip_code': '20850'},
    {'code': 'DDC9', 'address': '5533 WELLINGTON RD', 'city': 'GAINESVILLE', 'state': 'VA', 'country': 'USA', 'zip_code': '20155'},
    {'code': 'DDF1', 'address': '1303 RIDGEVIEW DR', 'city': 'LEWISVILLE', 'state': 'TX', 'country': 'USA', 'zip_code': '75057'},
    {'code': 'DDO6', 'address': '2751 Skypark Dr', 'city': 'Torrance', 'state': 'CA', 'country': 'USA', 'zip_code': '90505-5351'},
    {'code': 'DDP2', 'address': '2400 S. WECCACOE AVE', 'city': 'PHILADELPHIA', 'state': 'PA', 'country': 'USA', 'zip_code': '19148'},
    {'code': 'DDP5', 'address': '6300 BRISTOL PIKE', 'city': 'LEVITTOWN', 'state': 'PA', 'country': 'USA', 'zip_code': '19057'},
    {'code': 'DDP7', 'address': '3750 State Rd', 'city': 'Bensalem', 'state': 'PA', 'country': 'USA', 'zip_code': '19020-5903'},
    {'code': 'DDT3', 'address': '28415 AUTOMATION BLVD.', 'city': 'WIXOM', 'state': 'MI', 'country': 'USA', 'zip_code': '48393'},
    {'code': 'DDT4', 'address': '7009 W. Mountain Hope Hwy', 'city': 'Lansing', 'state': 'MI', 'country': 'USA', 'zip_code': '48917'},
    {'code': 'DDT6', 'address': '1200 FEATHERSTONE RD', 'city': 'PONTIAC', 'state': 'MI', 'country': 'USA', 'zip_code': '48342'},
    {'code': 'DDV2', 'address': '900 E 128th Ave', 'city': 'Thornton', 'state': 'CO', 'country': 'USA', 'zip_code': '80241'},
    {'code': 'DDV5', 'address': '2889 HIMALAYA RD', 'city': 'AURORA', 'state': 'CO', 'country': 'USA', 'zip_code': '80011'},
    {'code': 'DDX', 'address': '4949 Amon Carter Blvd.', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76155'},
    {'code': 'DDX2', 'address': '1398 INDUSTRIAL BLVD', 'city': 'MCKINNEY', 'state': 'TX', 'country': 'USA', 'zip_code': '75069'},
    {'code': 'DDX6', 'address': '16399 GATEWAY PATH', 'city': 'FRISCO', 'state': 'TX', 'country': 'USA', 'zip_code': '75078'},
    {'code': 'DDX7', 'address': '1101 S. GATEWAY BLVD', 'city': 'FORNEY', 'state': 'TX', 'country': 'USA', 'zip_code': '75126'},
    {'code': 'DEDC', 'address': '2020 Joe B Jackson Parkway', 'city': 'Murfreesboro', 'state': 'TN', 'country': 'USA', 'zip_code': '37127'},
    {'code': 'DEL2', 'address': 'Delhi, India', 'city': 'Delhi', 'state': '', 'country': 'India', 'zip_code': 'l6000'},
    {'code': 'DEL3', 'address': 'Tauru, Haryana', 'city': 'Tauru', 'state': 'Haryana', 'country': 'India', 'zip_code': ''},
    {'code': 'DEN1', 'address': '189 W 144th Ave', 'city': 'Thornton', 'state': 'CO', 'country': 'USA', 'zip_code': '80023'},
    {'code': 'DEN2', 'address': '22205 E. 19TH AVE.', 'city': 'AURORA', 'state': 'CO', 'country': 'USA', 'zip_code': '80019-3710'},
    {'code': 'DEN3', 'address': '14601 GRANT ST.', 'city': 'THORNTON', 'state': 'CO', 'country': 'USA', 'zip_code': '80023-6622'},
    {'code': 'DEN4', 'address': '4222 INTEGRATION LOOP', 'city': 'COLORADO SPRINGS', 'state': 'CO', 'country': 'USA', 'zip_code': '80916'},
    {'code': 'DEN5', 'address': '19799 E 36TH AVE.', 'city': 'AURORA', 'state': 'CO', 'country': 'USA', 'zip_code': '80011-8189'},
    {'code': 'DEN6', 'address': '480 E. 55TH ST.', 'city': 'DENVER', 'state': 'CO', 'country': 'USA', 'zip_code': '80216'},
    {'code': 'DEN7', 'address': '22300 E 26TH AVE', 'city': 'AURORA', 'state': 'CO', 'country': 'USA', 'zip_code': '80019'},
    {'code': 'DEN8', 'address': '20500 E Colfax Ave', 'city': 'Aurora', 'state': 'CO', 'country': 'USA', 'zip_code': '80018'},
    {'code': 'DET1', 'address': '39000 AMRHEIN RD.', 'city': 'LIVONIA', 'state': 'MI', 'country': 'USA', 'zip_code': '48150-1043'},
    {'code': 'DET2', 'address': '50500 Mound Rd', 'city': 'Shelby Township', 'state': 'MI', 'country': 'USA', 'zip_code': '48317-1318'},
    {'code': 'DET3', 'address': '1200 Featherstone Rd', 'city': 'Pontiac', 'state': 'MI', 'country': 'USA', 'zip_code': '48342'},
    {'code': 'DET7', 'address': '33700 Prescott Street', 'city': 'ROMULUS', 'state': 'MI', 'country': 'USA', 'zip_code': '48174'},
    {'code': 'DEV1', 'address': '2121 7th Ave', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98121-5114'},
    {'code': 'DEV2', 'address': '125 SW HOPKINS AVE', 'city': 'CORVALLIS', 'state': 'OR', 'country': 'USA', 'zip_code': '97333'},
    {'code': 'DEV3', 'address': '6050 E MARGINAL WAY S', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98108'},
    {'code': 'DEV4', 'address': '6050 E MARGINAL WAY S', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98108'},
    {'code': 'DEW1', 'address': '2 Empire Boulevard', 'city': 'Moonachie', 'state': 'NJ', 'country': 'USA', 'zip_code': '7074'},
    {'code': 'DEW5', 'address': '10 PRINCESS RD', 'city': 'LAWRENCE TOWNSHIP', 'state': 'NJ', 'country': 'USA', 'zip_code': '8648'},
    {'code': 'DFA5', 'address': '400 LITTLEFIELD AVE., #438', 'city': 'SOUTH SAN FRANCISCO', 'state': 'CA', 'country': 'USA', 'zip_code': '94080'},
    {'code': 'DFL3', 'address': '2121 NW 67TH PL', 'city': 'GAINESVILLE', 'state': 'FL', 'country': 'USA', 'zip_code': '32653'},
    {'code': 'DFL4', 'address': '4401 SEABOARD RD', 'city': 'ORLANDO', 'state': 'FL', 'country': 'USA', 'zip_code': '32808'},
    {'code': 'DFL7', 'address': '8100 FL-33', 'city': 'LAKELAND', 'state': 'FL', 'country': 'USA', 'zip_code': '33809'},
    {'code': 'DFM3', 'address': '770 COMMERCE DR', 'city': 'VENICE', 'state': 'FL', 'country': 'USA', 'zip_code': '34292'},
    {'code': 'DFO1', 'address': '22801 8th St E', 'city': 'Sonoma', 'state': 'CA', 'country': 'USA', 'zip_code': '95476'},
    {'code': 'DFO2', 'address': '4000 WILBUR AVE', 'city': 'OAKLEY', 'state': 'CA', 'country': 'USA', 'zip_code': '94561'},
    {'code': 'DFO3', 'address': '400 LONGFELLOW COURT', 'city': 'LIVERMORE', 'state': 'CA', 'country': 'USA', 'zip_code': '94550'},
    {'code': 'DFS8', 'address': '2995 Atlas Rd.', 'city': 'Richmond', 'state': 'CA', 'country': 'USA', 'zip_code': '94806'},
    {'code': 'DFW1', 'address': '2700 Regent Blvd', 'city': 'DFW Airport', 'state': 'TX', 'country': 'USA', 'zip_code': '75261'},
    {'code': 'DFW6', 'address': '940 W Bethel Rd', 'city': 'Coppell', 'state': 'TX', 'country': 'USA', 'zip_code': '75019-4424'},
    {'code': 'DFW7', 'address': '700 WESTPORT PARKWAY', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76177-4513'},
    {'code': 'DFW8', 'address': '2700 Regent Blvd', 'city': 'Irving', 'state': 'TX', 'country': 'USA', 'zip_code': '75063'},
    {'code': 'DFW9', 'address': '2700 Regent Blvd', 'city': 'Irving', 'state': 'TX', 'country': 'USA', 'zip_code': '75063'},
    {'code': 'DGE4', 'address': '1500 CROSSGATE RD', 'city': 'PORT WENTWORTH', 'state': 'GA', 'country': 'USA', 'zip_code': '31407'},
    {'code': 'DGE9', 'address': '5000 LANIER ISLANDS PARKWAY', 'city': 'BUFORD', 'state': 'GA', 'country': 'USA', 'zip_code': '30518'},
    {'code': 'DGR3', 'address': '33600 Mound Rd', 'city': 'Sterling Heights', 'state': 'MI', 'country': 'USA', 'zip_code': '48310-6526'},
    {'code': 'DGR6', 'address': '3951 Trade Dr SE 1st Floor', 'city': 'Grand Rapids', 'state': 'MI', 'country': 'USA', 'zip_code': '49508-2499'},
    {'code': 'DHO4', 'address': '5615 WEST FUQUA ST', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77085'},
    {'code': 'DHO7', 'address': '28420 W Ten Blvd.', 'city': 'Katy', 'state': 'TX', 'country': 'USA', 'zip_code': '77494'},
    {'code': 'DHP1', 'address': '2 Eastman Way', 'city': 'Hemel Hempstead', 'state': 'Hertfordshire', 'country': 'United Kingdom', 'zip_code': 'HP2 7DU'},
    {'code': 'DHX1', 'address': '3031 S. SAM HOUSTON PARKWAY E', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77032'},
    {'code': 'DHX3', 'address': '12900 W AIRPORT BLVD', 'city': 'SUGAR LAND', 'state': 'TX', 'country': 'USA', 'zip_code': '77478'},
    {'code': 'DHX5', 'address': '1102 STATE HWY 161', 'city': 'Grand Prairie', 'state': 'TX', 'country': 'USA', 'zip_code': '75051'},
    {'code': 'DIA3', 'address': '1301 E Gateway Dr.', 'city': 'GRIMES', 'state': 'IA', 'country': 'USA', 'zip_code': '50111'},
    {'code': 'DIA4', 'address': '2500 HEINZ RD', 'city': 'IOWA', 'state': 'IA', 'country': 'USA', 'zip_code': '52240'},
    {'code': 'DIL3', 'address': '3507 W 51ST ST', 'city': 'CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60632'},
    {'code': 'DIL5', 'address': '808 DISCOVERY DRIVE', 'city': 'WEST CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60185'},
    {'code': 'DIN4', 'address': '1621 Collins Rd', 'city': 'Greenwood', 'state': 'IN', 'country': 'USA', 'zip_code': '46143-2114'},
    {'code': 'DIN6', 'address': '8610 AVIONICS DR', 'city': 'FORT WAYNE', 'state': 'IN', 'country': 'USA', 'zip_code': '46809'},
    {'code': 'DJA1', 'address': '11084 Cabot Commerce Circle', 'city': 'Jacksonville', 'state': 'FL', 'country': 'USA', 'zip_code': '32226'},
    {'code': 'DJE1', 'address': '8 B Court South', 'city': 'Edison', 'state': 'NJ', 'country': 'USA', 'zip_code': '8817'},
    {'code': 'DJE2', 'address': '1250 FOREST PKWY', 'city': 'PAULSBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '8066'},
    {'code': 'DJE3', 'address': '2320 Center Square Rd', 'city': 'Logan Township', 'state': 'NJ', 'country': 'USA', 'zip_code': '08085-1796'},
    {'code': 'DJE6', 'address': '79 THOMAS MCGOVERN DR', 'city': 'JERSEY CITY', 'state': 'NJ', 'country': 'USA', 'zip_code': '7305'},
    {'code': 'DJR6', 'address': '5 Logistics Dr', 'city': 'Kearny', 'state': 'NJ', 'country': 'USA', 'zip_code': '00732-6537'},
    {'code': 'DJX2', 'address': '4645 Blanding Blvd', 'city': 'Jacksonville', 'state': 'FL', 'country': 'USA', 'zip_code': '32210-7324'},
    {'code': 'DJX3', 'address': '250 BUSCH DR', 'city': 'JACKSONVILLE', 'state': 'FL', 'country': 'USA', 'zip_code': '32218'},
    {'code': 'DJZ1', 'address': '125 North St', 'city': 'Teterboro', 'state': 'NJ', 'country': 'USA', 'zip_code': '07608-1201'},
    {'code': 'DJZ2', 'address': '610 WASHINGTON AVE', 'city': 'CARLSTADT', 'state': 'NJ', 'country': 'USA', 'zip_code': '7072'},
    {'code': 'DJZ3', 'address': '377 ROOSEVELT AVE', 'city': 'CARTERET', 'state': 'NJ', 'country': 'USA', 'zip_code': '7008'},
    {'code': 'DJZ4', 'address': '50 CENTRAL AVE', 'city': 'KEARNY', 'state': 'NJ', 'country': 'USA', 'zip_code': '7032'},
    {'code': 'DJZ5', 'address': '429 DELANCY ST', 'city': 'NEWARK', 'state': 'NJ', 'country': 'USA', 'zip_code': '7105'},
    {'code': 'DJZ8', 'address': '1 Paddock St', 'city': 'Avenel', 'state': 'NJ', 'country': 'USA', 'zip_code': '07001-1856'},
    {'code': 'DKY4', 'address': '3191 RIVER RD', 'city': 'CINCINNATI', 'state': 'OH', 'country': 'USA', 'zip_code': '45204'},
    {'code': 'DLA1', 'address': '900 W Florence Ave.', 'city': 'Inglewood', 'state': 'CA', 'country': 'USA', 'zip_code': '90301'},
    {'code': 'DLA2', 'address': '5650 Dolly Ave.', 'city': 'Buena Park', 'state': 'CA', 'country': 'USA', 'zip_code': '90621'},
    {'code': 'DLA3', 'address': '5829 Smithway St.', 'city': 'Commerce', 'state': 'CA', 'country': 'USA', 'zip_code': '90040'},
    {'code': 'DLA4', 'address': '9031 Lurline Ave.', 'city': 'Chatsworth', 'state': 'CA', 'country': 'USA', 'zip_code': '91311'},
    {'code': 'DLA5', 'address': '6250 SYCAMORE CANYON BLVD.', 'city': 'RIVERSIDE', 'state': 'CA', 'country': 'USA', 'zip_code': '92507-0771'},
    {'code': 'DLA8', 'address': '2815 W. El Segundo Blvd.', 'city': 'Hawthorne', 'state': 'CA', 'country': 'USA', 'zip_code': '90250'},
    {'code': 'DLB2', 'address': '11100 Honore Lane', 'city': 'Baton Rouge', 'state': 'LA', 'country': 'USA', 'zip_code': '70809-3918'},
    {'code': 'DLD1', 'address': '7659 SOLLEY RD', 'city': 'GLEN BURNIE', 'state': 'MD', 'country': 'USA', 'zip_code': '21060'},
    {'code': 'DLD7', 'address': '10100 WILLOWDALE RD', 'city': 'LANHAM', 'state': 'MD', 'country': 'USA', 'zip_code': '20706'},
    {'code': 'DLI4', 'address': '3077 Gateway Commerce Center Dr S', 'city': 'Edwardsville', 'state': 'IL', 'country': 'USA', 'zip_code': '62025'},
    {'code': 'DLI5', 'address': '5106 STATE ROUTE 111', 'city': 'PANTOON BEACH', 'state': 'IL', 'country': 'USA', 'zip_code': '62040'},
    {'code': 'DLI6', 'address': '6201 AVIATOR DR', 'city': 'HAZELWOOD', 'state': 'MO', 'country': 'USA', 'zip_code': '63042'},
    {'code': 'DLN2', 'address': '1500 S LARAME AVE', 'city': 'CICERO', 'state': 'IL', 'country': 'USA', 'zip_code': '60804'},
    {'code': 'DLN3', 'address': '1455 W SHURE DR', 'city': 'ARLINGTON HEIGHTS', 'state': 'IL', 'country': 'USA', 'zip_code': '60004'},
    {'code': 'DLN4', 'address': '10500 S. WOODLAWN AVE', 'city': 'CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60628'},
    {'code': 'DLN8', 'address': '315 S HICKS RD', 'city': 'PALATINE', 'state': 'IL', 'country': 'USA', 'zip_code': '60067'},
    {'code': 'DLR2', 'address': '12401 I-30', 'city': 'LITTLE ROCK', 'state': 'AR', 'country': 'USA', 'zip_code': '72209'},
    {'code': 'DLT2', 'address': '7929 NATIONAL SERVICE RD', 'city': 'COLFAX', 'state': 'NC', 'country': 'USA', 'zip_code': '27235'},
    {'code': 'DLT3', 'address': '413 GOODMAN RD', 'city': 'CONCORD', 'state': 'NC', 'country': 'USA', 'zip_code': '28027'},
    {'code': 'DLT6', 'address': '1610 Old Greensboro Rd.', 'city': 'KERNERSVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '27284'},
    {'code': 'DLV3', 'address': '9740 N VIRGINIA ST', 'city': 'RENO', 'state': 'NV', 'country': 'USA', 'zip_code': '89506'},
    {'code': 'DLX8', 'address': '515 E DYER RD', 'city': 'SANTA ANA', 'state': 'CA', 'country': 'USA', 'zip_code': '92707'},
    {'code': 'DLX9', 'address': '5750 MESMER AVE', 'city': 'CULVER CITY', 'state': 'CA', 'country': 'USA', 'zip_code': '90230'},
    {'code': 'DM01', 'address': 'Tangelo Park', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32189'},
    {'code': 'DM11', 'address': '15600 NW 15th Ave.', 'city': 'Miami Gardens', 'state': 'FL', 'country': 'USA', 'zip_code': '33169'},
    {'code': 'DMC3', 'address': '4054 Powell Dr', 'city': 'Shawnee', 'state': 'KS', 'country': 'USA', 'zip_code': '66226'},
    {'code': 'DMD2', 'address': '2203 Lakeside Blvd', 'city': 'Edgewood', 'state': 'MD', 'country': 'USA', 'zip_code': '21040'},
    {'code': 'DMD4', 'address': '102 Fulfillment Dr', 'city': 'Edgewood', 'state': 'MD', 'country': 'USA', 'zip_code': '21040'},
    {'code': 'DMD8', 'address': '9 JAY GOULD COURT', 'city': 'WALDORF', 'state': 'MD', 'country': 'USA', 'zip_code': '20602'},
    {'code': 'DMD9', 'address': '1000 PRINCE GEORGES BLVD', 'city': 'UPPER MARLOBORO', 'state': 'MD', 'country': 'USA', 'zip_code': '20774'},
    {'code': 'DMF1', 'address': '5700 NW 37TH AVE', 'city': 'HIALEAH', 'state': 'FL', 'country': 'USA', 'zip_code': '33142'},
    {'code': 'DMF3', 'address': '2800 N ANDREWS AVE EXT', 'city': 'POMPANO BEACH', 'state': 'FL', 'country': 'USA', 'zip_code': '33064'},
    {'code': 'DMF5', 'address': '13450 NW 14th St', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33182-1418'},
    {'code': 'DMF8', 'address': '13133 34th St. N', 'city': 'Clearwater', 'state': 'FL', 'country': 'USA', 'zip_code': '33762'},
    {'code': 'DMH9', 'address': '135 AMERICAN LEGION HWY', 'city': 'REVERE', 'state': 'MA', 'country': 'USA', 'zip_code': '2151'},
    {'code': 'DMI2', 'address': '3200 Northwest 67th Avenue', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33122'},
    {'code': 'DML1', 'address': '3935 W. Mitchell St.', 'city': 'Milwaukee', 'state': 'WI', 'country': 'USA', 'zip_code': '53125'},
    {'code': 'DML3', 'address': '6331 LEVI DR', 'city': 'GREENVILLE', 'state': 'WI', 'country': 'USA', 'zip_code': '54942'},
    {'code': 'DML4', 'address': '4250 120th Ave', 'city': 'KENOSHA', 'state': 'WI', 'country': 'USA', 'zip_code': '53144'},
    {'code': 'DML5', 'address': '11201 ENTERPRISE WAY', 'city': 'STURTEVANT', 'state': 'WI', 'country': 'USA', 'zip_code': '53177'},
    {'code': 'DMN1', 'address': '2811 Beverly Drive', 'city': 'Eagen', 'state': 'MN', 'country': 'USA', 'zip_code': '55121'},
    {'code': 'DMO6', 'address': '700 BANYAN TRAIL', 'city': 'BOCA RATON', 'state': 'FL', 'country': 'USA', 'zip_code': '33431'},
    {'code': 'DMO7', 'address': '9775 AIR COMMERCE PKWY', 'city': 'ORLANDO', 'state': 'FL', 'country': 'USA', 'zip_code': '32827'},
    {'code': 'DNG1', 'address': 'Nottingham, Nottinghamshire', 'city': 'Nottingham', 'state': 'Nottinghamshir e', 'country': 'United Kingdom', 'zip_code': ''},
    {'code': 'DNJ1', 'address': '380 Middlesex Ave', 'city': 'Carteret', 'state': 'NJ', 'country': 'USA', 'zip_code': '07008-3446'},
    {'code': 'DNJ6', 'address': '118 MOONACHIE AVE', 'city': 'CARLSTADT', 'state': 'NJ', 'country': 'USA', 'zip_code': '7072'},
    {'code': 'DNJ7', 'address': '81 INTERNATIONAL DR S', 'city': 'BUDD LAKE', 'state': 'NJ', 'country': 'USA', 'zip_code': '7828'},
    {'code': 'DNO2', 'address': '5733 Citrus Blvd', 'city': 'NEW ORLEANS', 'state': 'LA', 'country': 'USA', 'zip_code': '70123'},
    {'code': 'DOB2', 'address': '425 S. CHERRY ST', 'city': 'WALLINGFORD', 'state': 'CT', 'country': 'USA', 'zip_code': '6492'},
    {'code': 'DOB4', 'address': '500 LONG BEACH BLVD', 'city': 'STRATFORD', 'state': 'CT', 'country': 'USA', 'zip_code': '6615'},
    {'code': 'DOK3', 'address': '6101 SW 44TH ST', 'city': 'OKLAHOMA CITY', 'state': 'OK', 'country': 'USA', 'zip_code': '73179'},
    {'code': 'DOK4', 'address': '6801 S AIR DEPOT BLVD', 'city': 'OKLAHOMA CITY', 'state': 'OK', 'country': 'USA', 'zip_code': '73135'},
    {'code': 'DOR2', 'address': '1400 SEWELLS POINT RD', 'city': 'NORFOLK', 'state': 'VA', 'country': 'USA', 'zip_code': '23502'},
    {'code': 'DP01', 'address': '', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '75234'},
    {'code': 'DPA7', 'address': '9851 9851 FALLBROOK PINES DR # 150', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77064'},
    {'code': 'DPD2', 'address': '9475 N Horseshoe Ave', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '97217-7505'},
    {'code': 'DPD4', 'address': '21504 SW 115th Ave.', 'city': 'Tualatin', 'state': 'OR', 'country': 'USA', 'zip_code': '97062'},
    {'code': 'DPD6', 'address': '5475 GAFFIN RD SE', 'city': 'SALEM', 'state': 'OR', 'country': 'USA', 'zip_code': '97317'},
    {'code': 'DPH1', 'address': '4219 Richmond Street', 'city': 'Philadelphia', 'state': 'PA', 'country': 'USA', 'zip_code': '19137'},
    {'code': 'DPH8', 'address': '7575 BREWSTER AVE', 'city': 'PHILADELPHIA', 'state': 'PA', 'country': 'USA', 'zip_code': '19153-3206'},
    {'code': 'DPP7', 'address': '177 MCCLAREN RD', 'city': 'CORAOPOLIS', 'state': 'PA', 'country': 'USA', 'zip_code': '15108'},
    {'code': 'DPS5', 'address': '28820 Chase Pl', 'city': 'Valencia', 'state': 'CA', 'country': 'USA', 'zip_code': '91355-5422'},
    {'code': 'DPS6', 'address': '1757 Tapo Canyon Rd', 'city': 'Simi Valley', 'state': 'CA', 'country': 'USA', 'zip_code': '93063-3390'},
    {'code': 'DPX1', 'address': '500 S. 48th Street', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85034'},
    {'code': 'DPX4', 'address': '1516 W 17TH ST', 'city': 'TEMPE', 'state': 'AZ', 'country': 'USA', 'zip_code': '85281'},
    {'code': 'DPX7', 'address': '3405 S. McQueen Rd', 'city': 'Chandler', 'state': 'AZ', 'country': 'USA', 'zip_code': '85286'},
    {'code': 'DPX8', 'address': '7875 W Buckeye Rd', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043-4213'},
    {'code': 'DRT4', 'address': '394 Fanning Fields Rd', 'city': 'Mills River', 'state': 'NC', 'country': 'USA', 'zip_code': '28759-4610'},
    {'code': 'DRT8', 'address': '1275 Person St', 'city': 'Durham', 'state': 'NC', 'country': 'USA', 'zip_code': '27703'},
    {'code': 'DRT9', 'address': '1200 INNOVATION AVE., #1000', 'city': 'MORRISVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '27560'},
    {'code': 'DSD1', 'address': '7130 Miramar Rd. 300A', 'city': 'San Diego', 'state': 'CA', 'country': 'USA', 'zip_code': '92121'},
    {'code': 'DSD2', 'address': '2777 Loker Ave W.', 'city': 'Carlsbad', 'state': 'CA', 'country': 'USA', 'zip_code': '92010'},
    {'code': 'DSD5', 'address': '3250 Business Park Dr', 'city': 'Vista', 'state': 'CA', 'country': 'USA', 'zip_code': '92081'},
    {'code': 'DSD8', 'address': '14400 KIRKHAM WAY, #1450', 'city': 'POWAY', 'state': 'CA', 'country': 'USA', 'zip_code': '92064'},
    {'code': 'DSE2', 'address': '6705 E Marginal Way', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98108'},
    {'code': 'DSE8', 'address': '7555 AIRPORT WAY SW', 'city': 'BREMERTON', 'state': 'WA', 'country': 'USA', 'zip_code': '98312'},
    {'code': 'DSF1', 'address': '990 Beecher St.', 'city': 'San Leandro', 'state': 'CA', 'country': 'USA', 'zip_code': '94577'},
    {'code': 'DSF3', 'address': '1700 Montague Expy.', 'city': 'San Jose', 'state': 'CA', 'country': 'USA', 'zip_code': '95131'},
    {'code': 'DSF5', 'address': '250 Utah Avenue', 'city': 'South San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94080'},
    {'code': 'DSF6', 'address': '6015 Giant Road', 'city': 'Richmond', 'state': 'CA', 'country': 'USA', 'zip_code': '94080'},
    {'code': 'DSF7', 'address': '807 N MCCARTHY BLVD.', 'city': 'MILPITAS', 'state': 'CA', 'country': 'USA', 'zip_code': '95035'},
    {'code': 'DSF8', 'address': '2995 Atlas Rd', 'city': 'Richmond', 'state': 'CA', 'country': 'USA', 'zip_code': '94806-1167'},
    {'code': 'DSJ7', 'address': '615 NORTH KING RD', 'city': 'SAN JOSE', 'state': 'CA', 'country': 'USA', 'zip_code': '95133'},
    {'code': 'DSM5', 'address': '500 SW 32ND ST', 'city': 'BONDURANT', 'state': 'IA', 'country': 'USA', 'zip_code': '50035'},
    {'code': 'DSM9', 'address': '2300 SHILOH ROSE PKWY SW', 'city': 'BONDURANT', 'state': 'IA', 'country': 'USA', 'zip_code': '50035'},
    {'code': 'DSR1', 'address': '2906 CORPORATE WAY', 'city': 'PALMETTO', 'state': 'FL', 'country': 'USA', 'zip_code': '34221'},
    {'code': 'DSR2', 'address': '7601 FOOTHILLS BLVD', 'city': 'ROSEVILLE', 'state': 'CA', 'country': 'USA', 'zip_code': '95747'},
    {'code': 'DSR4', 'address': '9051 Union Park Way', 'city': 'Elk Grove', 'state': 'CA', 'country': 'USA', 'zip_code': '95624'},
    {'code': 'DSR6', 'address': '2400 MCCLELLAN PARK DR', 'city': 'SACRAMENTO', 'state': 'CA', 'country': 'USA', 'zip_code': '95838'},
    {'code': 'DTL6', 'address': '1610 OLD GREENSBORO RD', 'city': 'KERNERSVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '27284'},
    {'code': 'DTM1', 'address': 'Westfalenhutte', 'city': 'Dortmund', 'state': 'North Rhine-Westphalia', 'country': 'Germany', 'zip_code': ''},
    {'code': 'DTN7', 'address': '242 MASON RD', 'city': 'LA VERGNE', 'state': 'TN', 'country': 'USA', 'zip_code': '37086'},
    {'code': 'DTP7', 'address': '1003 N TAYLOR RD', 'city': 'SEFFNER', 'state': 'FL', 'country': 'USA', 'zip_code': '33584'},
    {'code': 'DTU3', 'address': '2550 N Nevada St', 'city': 'Chandler', 'state': 'AZ', 'country': 'USA', 'zip_code': '85225-1015'},
    {'code': 'DTU8', 'address': '3003 S 38TH ST', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85040'},
    {'code': 'DTW1', 'address': '32801 ECORSE ROAD', 'city': 'ROMULUS', 'state': 'MI', 'country': 'USA', 'zip_code': '48174'},
    {'code': 'DTW3', 'address': '23 mile and mound roads', 'city': 'Shelby', 'state': 'MI', 'country': 'USA', 'zip_code': '48316'},
    {'code': 'DTW5', 'address': '19991 BROWNSTONE CENTER DRIVE', 'city': 'TRENTON', 'state': 'MI', 'country': 'USA', 'zip_code': '48183'},
    {'code': 'DTW8', 'address': '9075 N Haggerty Rd', 'city': 'Plymouth', 'state': 'MI', 'country': 'USA', 'zip_code': '48170-4630'},
    {'code': 'DTW9', 'address': '18000 VINING RD', 'city': 'NEW BOSTON', 'state': 'MI', 'country': 'USA', 'zip_code': '48164'},
    {'code': 'DUR1', 'address': '2995 N HOLLYWOOD WAY', 'city': 'BURBANK', 'state': 'CA', 'country': 'USA', 'zip_code': '91505'},
    {'code': 'DUS2', 'address': 'Amazonstrasse 1 / Alte Landstrasse', 'city': 'Rheinberg', 'state': 'North Rhine-Westphalia', 'country': 'Germany', 'zip_code': '47495'},
    {'code': 'DVA2', 'address': '1601 Bellwood Rd.', 'city': 'Richmond', 'state': 'VA', 'country': 'USA', 'zip_code': '23237'},
    {'code': 'DVA5', 'address': '11920 Balls Ford Rd', 'city': 'Manassas', 'state': 'VA', 'country': 'USA', 'zip_code': '20109-2484'},
    {'code': 'DWA6', 'address': '22001 84th Ave S', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032-1962'},
    {'code': 'DWA9', 'address': '3711 142ND AVE E', 'city': 'SUMNER', 'state': 'WA', 'country': 'USA', 'zip_code': '98390'},
    {'code': 'DWF9', 'address': '2700 Regent Blvd.', 'city': 'Irving', 'state': 'TX', 'country': 'USA', 'zip_code': '75063'},
    {'code': 'DWI4', 'address': '3650 MILWAUKEE ST', 'city': 'MADISON', 'state': 'WI', 'country': 'USA', 'zip_code': '53714'},
    {'code': 'DWS5', 'address': '6617 ASSOCIATED BLVD', 'city': 'EVERETT', 'state': 'WA', 'country': 'USA', 'zip_code': '98203'},
    {'code': 'DWX3', 'address': '6050 E. MARGINAL WAY S', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98108'},
    {'code': 'DXB1', 'address': 'Britania point, Patent Dr', 'city': 'Wednesbury', 'state': 'West Midlands', 'country': 'United Kingdom', 'zip_code': 'WS10 7XB'},
    {'code': 'DXC5', 'address': '44109 PACIFIC COMMONS BLVD', 'city': 'FREMONT', 'state': 'CA', 'country': 'USA', 'zip_code': '94538'},
    {'code': 'DXC8', 'address': '1710 LITTLE ORCHARD ST', 'city': 'SAN JOSE', 'state': 'CA', 'country': 'USA', 'zip_code': '95125'},
    {'code': 'DXH6', 'address': '3800 FINLEY RD', 'city': 'DOWNERS GROVE', 'state': 'IL', 'country': 'USA', 'zip_code': '60515'},
    {'code': 'DXY4', 'address': '200 Oritani Dr', 'city': 'Blauvelt', 'state': 'NY', 'country': 'USA', 'zip_code': '10913-1024'},
    {'code': 'DYN5', 'address': '10 Patton Dr', 'city': 'West Caldwell', 'state': 'NJ', 'country': 'USA', 'zip_code': '07006-6405'},
    {'code': 'DYO1', 'address': '500 Hudson Valley Ave', 'city': 'New Windsor', 'state': 'NY', 'country': 'USA', 'zip_code': '12553'},
    {'code': 'DYO2', 'address': '1055 BRONX RIVER AVE', 'city': 'BRONX', 'state': 'NY', 'country': 'USA', 'zip_code': '10472'},
    {'code': 'DYO5', 'address': '7120 Main St', 'city': 'Trumbull', 'state': 'CT', 'country': 'USA', 'zip_code': '06611-6315'},
    {'code': 'DYR7', 'address': '717 Broadway Ave', 'city': 'Holbrook', 'state': 'NY', 'country': 'USA', 'zip_code': '11741-4905'},
    {'code': 'DYX2', 'address': '526 Gulf Ave', 'city': 'Staten Island', 'state': 'NY', 'country': 'USA', 'zip_code': '10314-7120'},
    {'code': 'DZYO1', 'address': '3850 21st St', 'city': 'Long Island City', 'state': 'NY', 'country': 'USA', 'zip_code': '11101-3604'},
    {'code': 'EDE4', 'address': 'Wahrbrink 25', 'city': 'Werne/Lippe', 'state': 'North Rhine-Westphalia', 'country': 'Germany', 'zip_code': '58368'},
    {'code': 'EDE5', 'address': 'Wahrbrink 25', 'city': 'Werne/Lippe', 'state': 'North Rhine-Westphalia', 'country': 'Germany', 'zip_code': '59368'},
    {'code': 'EDE6', 'address': 'Werne, North Rhine-Westphalia', 'city': 'Werne', 'state': 'North Rhine-Westphalia', 'country': 'Germany', 'zip_code': '58368'},
    {'code': 'EDI4', 'address': 'Amazon Way', 'city': 'Dunfermline', 'state': 'Fife (Glenrothes)', 'country': 'United Kingdom', 'zip_code': 'KY11 8ST'},
    {'code': 'ELP1', 'address': '12101 EMERALD PASS DR', 'city': 'EL PASO', 'state': 'TX', 'country': 'USA', 'zip_code': '79928'},
    {'code': 'EMA1', 'address': 'Little Battleflat Farm', 'city': 'Ellistown, Coalville', 'state': 'Leicestershire', 'country': 'United Kingdom', 'zip_code': ''},
    {'code': 'EUG5', 'address': '1001 N SCHMEER RD', 'city': 'PORTLAND', 'state': 'OR', 'country': 'USA', 'zip_code': '97217'},
    {'code': 'EUK5', 'address': 'Phase 2. Kingston Park Flaxley Road', 'city': 'Peterborough', 'state': 'Cambridgeshire', 'country': 'United Kingdom', 'zip_code': 'PE29EN'},
    {'code': 'EWR1', 'address': '50 New Canton Way', 'city': 'Robinsville', 'state': 'NJ', 'country': 'USA', 'zip_code': '8691'},
    {'code': 'EWR4', 'address': '50 New Canton Way', 'city': 'ROBBINSVILLE', 'state': 'NJ', 'country': 'USA', 'zip_code': '08691-2350'},
    {'code': 'EWR5', 'address': '301 Blair Rd', 'city': 'Avenel', 'state': 'NJ', 'country': 'USA', 'zip_code': '07001-2225'},
    {'code': 'EWR6', 'address': '275 Omar Avenue', 'city': 'Avenel', 'state': 'NJ', 'country': 'USA', 'zip_code': '07001-2240'},
    {'code': 'EWR7', 'address': '275 Omar Ave', 'city': 'Avenel', 'state': 'NJ', 'country': 'USA', 'zip_code': '7001'},
    {'code': 'EWR8', 'address': '698 ROUTE 46', 'city': 'TETERBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '7608'},
    {'code': 'EWR9', 'address': '8003 INDUSTRIAL AVE', 'city': 'CARTERET', 'state': 'NJ', 'country': 'USA', 'zip_code': '07008-3529'},
    {'code': 'FAR1', 'address': '3701 40th Avenue N', 'city': 'Fargo', 'state': 'ND', 'country': 'USA', 'zip_code': '58102-7400'},
    {'code': 'FAT1', 'address': '3575 S Orange Ave', 'city': 'Fresno', 'state': 'CA', 'country': 'USA', 'zip_code': '93725-9366'},
    {'code': 'FAT2', 'address': '3315 N. KELSEY ST', 'city': 'VISALIA', 'state': 'CA', 'country': 'USA', 'zip_code': '93291'},
    {'code': 'FAT5', 'address': '3611 S Northpointe Dr', 'city': 'Fresno', 'state': 'CA', 'country': 'USA', 'zip_code': '93725-1962'},
    {'code': 'FDL3', 'address': '24208 SAN MICHELE RD', 'city': 'MORENO VALLEY', 'state': 'CA', 'country': 'USA', 'zip_code': '92551-9561'},
    {'code': 'FDN1', 'address': '80 Grumman Rd', 'city': 'BETHPAGE', 'state': 'NY', 'country': 'USA', 'zip_code': '11714'},
    {'code': 'FDP1', 'address': '4000 McClaren Woods Dr', 'city': 'CORAOPOLIS', 'state': 'PA', 'country': 'USA', 'zip_code': '15108'},
    {'code': 'FOE1', 'address': '9700 LEAVENWORTH RD', 'city': 'KANSAS CITY', 'state': 'KS', 'country': 'USA', 'zip_code': '66109'},
    {'code': 'FRA1', 'address': 'Am Schloss Eichhof 1, Bad Hersfeld -Schloss Eichhof', 'city': 'Bad Hersfeld', 'state': 'Hessen', 'country': 'Germany', 'zip_code': '36251'},
    {'code': 'FRA3', 'address': 'Amazonstrasse 1, Bad Hersfeld -Obere Kuehnbach', 'city': 'Bad Hersfeld', 'state': 'Hessen', 'country': 'Germany', 'zip_code': '36251'},
    {'code': 'FSE2', 'address': '5100 15th Ave NW', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98107'},
    {'code': 'FSE3', 'address': '76 South Lander Street', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98134'},
    {'code': 'FSZ1', 'address': '4-5-1 Ogi-cho', 'city': 'Odawara-shi', 'state': 'Kanagawa', 'country': 'Japan', 'zip_code': '250-0001'},
    {'code': 'FTW1', 'address': '33333 LYNDON B JOHNSON FREEWAY', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75241-7203'},
    {'code': 'FTW2', 'address': '2701 W Bethel Rd', 'city': 'DFW Airport', 'state': 'TX', 'country': 'USA', 'zip_code': '75261'},
    {'code': 'FTW3', 'address': '15201 Herritage Pkwy', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76177-2517'},
    {'code': 'FTW4', 'address': '4601 Gold Spike Drive', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76106'},
    {'code': 'FTW5', 'address': '1475 AKRON WAY', 'city': 'FORNEY', 'state': 'TX', 'country': 'USA', 'zip_code': '75126-3566'},
    {'code': 'FTW6', 'address': '2601 W. BETHEL RD.', 'city': 'DFW AIRPORT', 'state': 'TX', 'country': 'USA', 'zip_code': '75261-4015'},
    {'code': 'FTW7', 'address': '944 W. SANDY LAKE RD.', 'city': 'COPPELL', 'state': 'TX', 'country': 'USA', 'zip_code': '75019'},
    {'code': 'FTW8', 'address': '3351 BALMORHEA DR.', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75134-7304'},
    {'code': 'FTW9', 'address': '944 West Sandy Lake Road', 'city': 'COPPELL', 'state': 'TX', 'country': 'USA', 'zip_code': '75019-3989'},
    {'code': 'FWA4', 'address': '9800 SMITH RD', 'city': 'FORT WAYNE', 'state': 'IN', 'country': 'USA', 'zip_code': '46818'},
    {'code': 'GAT1', 'address': '86 5th St NW', 'city': 'Atlanta', 'state': 'GA', 'country': 'USA', 'zip_code': '30308'},
    {'code': 'GDL1', 'address': '123 Unknown', 'city': 'Guadaljara', 'state': 'MX', 'country': 'Mexico', 'zip_code': '0'},
    {'code': 'GEG1', 'address': '10010 W. GEIGER BLVD.', 'city': 'SPOKANE', 'state': 'WA', 'country': 'USA', 'zip_code': '99224'},
    {'code': 'GEG2', 'address': '18007 E Garland Ave', 'city': 'Spokane Valley', 'state': 'WA', 'country': 'USA', 'zip_code': '99216'},
    {'code': 'GEU1', 'address': '10205 W ROOSEVELT ST', 'city': 'AVONDALE', 'state': 'AZ', 'country': 'USA', 'zip_code': '85323'},
    {'code': 'GLA1', 'address': '2 Cloch Road', 'city': 'Faulds Park, Gourock', 'state': 'Inverclyde', 'country': 'United Kingdom', 'zip_code': 'PA19 1BQ'},
    {'code': 'GRR1', 'address': '6853 PATTERSON AVE SE #7161', 'city': 'CALEDONIA', 'state': 'MI', 'country': 'USA', 'zip_code': '49316'},
    {'code': 'GRU1', 'address': 'Estrada dos Alpes, 900', 'city': 'Bairro dos Altos, Barueri', 'state': 'Sao Paulo', 'country': 'Brazil', 'zip_code': '6423'},
    {'code': 'GRU5', 'address': 'Prologis III - Galpao - 3100', 'city': 'Cajamar', 'state': 'SP', 'country': 'Brazil', 'zip_code': '7776415'},
    {'code': 'GS01', 'address': '1656 OLD GREENSBORO RD', 'city': 'KERNERSVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '27284'},
    {'code': 'GSO1', 'address': '1656 Old Greensboro Rd.', 'city': 'Kernersville', 'state': 'NC', 'country': 'USA', 'zip_code': '27284'},
    {'code': 'GSP1', 'address': '402 JOHN DODD RD', 'city': 'SPARTANBURG', 'state': 'SC', 'country': 'USA', 'zip_code': '29303-6312'},
    {'code': 'GYR1', 'address': '580 S 143rd Ave', 'city': 'Goodyear', 'state': 'AZ', 'country': 'USA', 'zip_code': '85338'},
    {'code': 'GYR2', 'address': '17341 W MINNEZONA AVE', 'city': 'GOODYEAR', 'state': 'AZ', 'country': 'USA', 'zip_code': '85395'},
    {'code': 'GYR3', 'address': '8181 W ROOSEVELT ST', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'GYR4', 'address': '10205 W Roosevelt St', 'city': 'Avondale', 'state': 'AZ', 'country': 'USA', 'zip_code': '85323'},
    {'code': 'HAM1', 'address': 'Winsen, Lower Saxony', 'city': 'Winsen', 'state': 'Lower Saxony', 'country': 'Germany', 'zip_code': ''},
    {'code': 'HAT9', 'address': '2201 Thornton Road', 'city': 'Lithia Springs', 'state': 'GA', 'country': 'USA', 'zip_code': '30122'},
    {'code': 'HBA3', 'address': '817 N. POINT RD', 'city': 'BALTIMORE', 'state': 'MD', 'country': 'USA', 'zip_code': '21237'},
    {'code': 'HCA3', 'address': '3334 N San Fernando Rd Bldg E', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90065-1417'},
    {'code': 'HCA4', 'address': '1555 N CHRISMAN RD', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95304'},
    {'code': 'HCA6', 'address': '2727 Kurtz St', 'city': 'San Diego', 'state': 'CA', 'country': 'USA', 'zip_code': '92110'},
    {'code': 'HCA7', 'address': '10681 Production Ave', 'city': 'Fontana', 'state': 'CA', 'country': 'USA', 'zip_code': '92337'},
    {'code': 'HCA8', 'address': '1350 N. MacArthur Drive', 'city': 'Tracy', 'state': 'CA', 'country': 'USA', 'zip_code': '95304'},
    {'code': 'HCA9', 'address': '455 VALLEY DR', 'city': 'BRISBANE', 'state': 'CA', 'country': 'USA', 'zip_code': '94005-1209'},
    {'code': 'HCL9', 'address': '12220 Carolina Logistics Drive', 'city': 'PINEVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '28134'},
    {'code': 'HCM9', 'address': '3538 TRADEPORT CT', 'city': 'LOCKBOURNE', 'state': 'OH', 'country': 'USA', 'zip_code': '43137'},
    {'code': 'HDA1', 'address': '306 AIRLINE DR #300', 'city': 'COPPELL', 'state': 'TX', 'country': 'USA', 'zip_code': '75019'},
    {'code': 'HDA9', 'address': '2701 W. Bethel Rd.', 'city': 'COPPELL', 'state': 'TX', 'country': 'USA', 'zip_code': '75019'},
    {'code': 'HDS9', 'address': '200 SE 37TH ST', 'city': 'GRIMES', 'state': 'IA', 'country': 'USA', 'zip_code': '50111'},
    {'code': 'HDT9', 'address': '12795 Premier Ctr. Ct', 'city': 'PLYMOUTH', 'state': 'MN', 'country': 'USA', 'zip_code': '48170'},
    {'code': 'HEA1', 'address': '9 Livingstone St', 'city': 'DORCHESTER CENTER', 'state': 'MA', 'country': 'USA', 'zip_code': '2124'},
    {'code': 'HEA2', 'address': '311Ella St', 'city': 'PITTSBURGH', 'state': 'PA', 'country': 'USA', 'zip_code': '15224'},
    {'code': 'HEW9', 'address': 'HEW9 343 HALF ACRE RD', 'city': 'CRANBURY', 'state': 'NJ', 'country': 'USA', 'zip_code': '8512'},
    {'code': 'HFD5', 'address': '1339 Tolland Turnpike', 'city': 'Manchester', 'state': 'CT', 'country': 'USA', 'zip_code': '06042-8928'},
    {'code': 'HGA3', 'address': '2160 Breckenridge Blvd, Site 10', 'city': 'Lawrenceville', 'state': 'GA', 'country': 'USA', 'zip_code': '30043'},
    {'code': 'HGA6', 'address': '97 PEACHTREE ST SW', 'city': 'ATLANTA', 'state': 'GA', 'country': 'USA', 'zip_code': '30303'},
    {'code': 'HGR2', 'address': '1115 WESEL BLVD', 'city': 'HAGERSTOWN', 'state': 'MD', 'country': 'USA', 'zip_code': '21740'},
    {'code': 'HHO9', 'address': '16625 TOMBALL PKWY STE A', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77064'},
    {'code': 'HIL1', 'address': '1111 Cherry Street', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60642'},
    {'code': 'HIL2', 'address': '1111 N Cherry Ave', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60642-4204'},
    {'code': 'HIL3', 'address': '30260 Graaskamp Blvd', 'city': 'WILMINGTON', 'state': 'IL', 'country': 'USA', 'zip_code': '60481'},
    {'code': 'HIN9', 'address': '19 BOB GLIDDEN BLVD', 'city': 'WHITELAND', 'state': 'IN', 'country': 'USA', 'zip_code': '46184'},
    {'code': 'HIO9', 'address': '23677 NM Huffman St.', 'city': 'Hillsboro', 'state': 'OR', 'country': 'USA', 'zip_code': '97124'},
    {'code': 'HJX9', 'address': '2780 LLOYD RD', 'city': 'JACKSONVILLE', 'state': 'FL', 'country': 'USA', 'zip_code': '32254'},
    {'code': 'HLA9', 'address': '4375 N Perris Blvd.', 'city': 'PERRIS', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'HLU9', 'address': '3931 LAKEVIEW CORPORATE DR', 'city': 'EDWARDSVILLE', 'state': 'IL', 'country': 'USA', 'zip_code': '62025'},
    {'code': 'HMD3', 'address': '13905 Crayton Blvd', 'city': 'HAGERSTOWN', 'state': 'MD', 'country': 'USA', 'zip_code': '21742'},
    {'code': 'HME9', 'address': '4477 WINCHESTER RD', 'city': 'MEMPHIS', 'state': 'TN', 'country': 'USA', 'zip_code': '38118'},
    {'code': 'HMK4', 'address': '16555 W Small Rd', 'city': 'New Berlin', 'state': 'WI', 'country': 'USA', 'zip_code': '53151'},
    {'code': 'HMO3', 'address': '83307 Hermosillo', 'city': 'Hermosillo', 'state': 'Sonora', 'country': 'Mexico', 'zip_code': '83180'},
    {'code': 'HMS9', 'address': '9800 217TH ST W', 'city': 'LAKEVILLE', 'state': 'MN', 'country': 'USA', 'zip_code': '55044'},
    {'code': 'HMW1', 'address': '30260 GRAASKAMP BLVD', 'city': 'WILMINGTON', 'state': 'IL', 'country': 'USA', 'zip_code': '60481'},
    {'code': 'HMW3', 'address': '6651 Chippewa St', 'city': 'SAINT LOUIS', 'state': 'MO', 'country': 'USA', 'zip_code': '63109'},
    {'code': 'HMW4', 'address': '263 E Whittier St', 'city': 'COLUMBUS', 'state': 'OH', 'country': 'USA', 'zip_code': '43206'},
    {'code': 'HNC3', 'address': '1850 E 3RD ST', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28204'},
    {'code': 'HND2', 'address': '915 Aoyagi', 'city': 'Sayama-shi', 'state': 'Saitama', 'country': 'Japan', 'zip_code': '350-1301'},
    {'code': 'HND3', 'address': '2-1-1 2FL Kawashima', 'city': 'Kawajima-machi, Hiki-gun', 'state': 'Saitama', 'country': 'Japan', 'zip_code': '350-0168'},
    {'code': 'HNE1', 'address': '2205 STATE ROUTE 27', 'city': 'EDISON', 'state': 'NJ', 'country': 'USA', 'zip_code': '8817'},
    {'code': 'HNJ2', 'address': '940 Monroe Street', 'city': 'Hoboken', 'state': 'NJ', 'country': 'USA', 'zip_code': '7030'},
    {'code': 'HNW1', 'address': '20529 24th Ave S', 'city': 'SEATAC', 'state': 'WA', 'country': 'USA', 'zip_code': '98198'},
    {'code': 'HOU1', 'address': '8120 Humble Westfield Rd', 'city': 'Humble', 'state': 'TX', 'country': 'USA', 'zip_code': '77338-4142'},
    {'code': 'HOU2', 'address': '10550 Ella Blvd', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77038-2324'},
    {'code': 'HOU3', 'address': '778 Igloo Rd', 'city': 'Katy', 'state': 'TX', 'country': 'USA', 'zip_code': '77423-2769'},
    {'code': 'HOU5', 'address': '22525 Clay Rd', 'city': 'Katy', 'state': 'TX', 'country': 'USA', 'zip_code': '77449-8200'},
    {'code': 'HOU6', 'address': '10507 HARLEN BLVD', 'city': 'RICHMOND', 'state': 'TX', 'country': 'USA', 'zip_code': '77407'},
    {'code': 'HOU7', 'address': '16225 TOMBALL PKWY, BLDG 1', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77064'},
    {'code': 'HOU8', 'address': '2303 HURRICANE LANE', 'city': 'FRESNO', 'state': 'TX', 'country': 'USA', 'zip_code': '77545'},
    {'code': 'HOU9', 'address': '22525 CLAY RD', 'city': 'KATY', 'state': 'TX', 'country': 'USA', 'zip_code': '77449'},
    {'code': 'HOUX', 'address': '2701 W Bethel Road', 'city': 'Coppell', 'state': 'TX', 'country': 'USA', 'zip_code': '75261'},
    {'code': 'HPD9', 'address': '15000 N LOMBARD', 'city': 'PORTLAND', 'state': 'OR', 'country': 'USA', 'zip_code': '97203'},
    {'code': 'HPH9', 'address': '298 1ST AVE', 'city': 'GOULDSBORO', 'state': 'PA', 'country': 'USA', 'zip_code': '18424'},
    {'code': 'HPX9', 'address': '3333 S 59TH AVE', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'HRB1', 'address': 'Haerbin, Heilongjiang', 'city': 'Haerbin', 'state': 'Heilongjiang', 'country': 'China', 'zip_code': ''},
    {'code': 'HRC9', 'address': '4949 Commerce Rd.', 'city': 'RICHMOND', 'state': 'VA', 'country': 'USA', 'zip_code': '23234'},
    {'code': 'HSE1', 'address': '13905 CRAYTON BLVD', 'city': 'HAGERSTOWN', 'state': 'MD', 'country': 'USA', 'zip_code': '21742'},
    {'code': 'HSF6', 'address': '1401 GRIFFITH ST', 'city': 'SAN FRANCISCO', 'state': 'CA', 'country': 'USA', 'zip_code': '94124'},
    {'code': 'HSF9', 'address': '44051 OSGOOD RD', 'city': 'FREEMONT', 'state': 'CA', 'country': 'USA', 'zip_code': '94539'},
    {'code': 'HSG1', 'address': '3-1-3 Yayoigaoka', 'city': 'Tosu-shi', 'state': 'Saga', 'country': 'Japan', 'zip_code': '841-0005'},
    {'code': 'HSH1', 'address': '5801 NICCO WAY', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'HSL9', 'address': '355 N JOHN GLENN RD', 'city': 'SALT LAKE CITY', 'state': 'UT', 'country': 'USA', 'zip_code': '84116'},
    {'code': 'HSV1', 'address': '23366 BIBB GARRETT RD', 'city': 'TANNER', 'state': 'AL', 'country': 'USA', 'zip_code': '35671'},
    {'code': 'HTN3', 'address': '555 EXPRESSWAY PARK DR', 'city': 'NASHVILLE', 'state': 'TN', 'country': 'USA', 'zip_code': '37210'},
    {'code': 'HTP9', 'address': '3400 NW 35th Ave. Rd.', 'city': 'OCALA', 'state': 'FL', 'country': 'USA', 'zip_code': '34475'},
    {'code': 'HTX1', 'address': '4221 Way Out West Drive', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77092'},
    {'code': 'HTX2', 'address': '4221 Way Out West Drive', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77092-1455'},
    {'code': 'HTX3', 'address': '1755 FEDERAL RD', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77015'},
    {'code': 'HWA1', 'address': '11710 118th Ave NE, Building B', 'city': 'Kirkland', 'state': 'WA', 'country': 'USA', 'zip_code': '98034'},
    {'code': 'HWA2', 'address': '11710 118th Ave NE', 'city': 'Kirkland', 'state': 'WA', 'country': 'USA', 'zip_code': '98034'},
    {'code': 'HWA3', 'address': '20202 84th AVE S', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'HWA4', 'address': '3138 200TH ST E', 'city': 'SPANAWAY', 'state': 'WA', 'country': 'USA', 'zip_code': '98387'},
    {'code': 'HWE1', 'address': '14 S. Massachusetts st', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98134'},
    {'code': 'HWE2', 'address': '9830 SE Washington st', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98134'},
    {'code': 'HYD1', 'address': 'Penjrala. Mahbubnagar District', 'city': 'Kothur, Hyderabad', 'state': 'Telangana', 'country': 'India', 'zip_code': ''},
    {'code': 'IAH1', 'address': '9155 Southlink Dr', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75241-7510'},
    {'code': 'IAH2', 'address': '9155 SOUTHLINK DR', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75241'},
    {'code': 'IAH4', 'address': '11720 N GESSNER RD', 'city': 'HOUSTON', 'state': 'TX', 'country': 'USA', 'zip_code': '77064'},
    {'code': 'IAH5', 'address': '8903 WAREHOUSE CENTER DR', 'city': 'HUMBLE', 'state': 'TX', 'country': 'USA', 'zip_code': '77338'},
    {'code': 'IAH6', 'address': '8401 Fallbrook Drive', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77064'},
    {'code': 'IBF1', 'address': '1501 Boylston Ave', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98122'},
    {'code': 'IBF2', 'address': '320 108th Ave NE', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98004'},
    {'code': 'IBF3', 'address': '1920 Terry Ave N', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98101'},
    {'code': 'IBF4', 'address': '1423 4th Ave', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98101'},
    {'code': 'IBF5', 'address': '4321 Univ. Way NE', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98105'},
    {'code': 'IBF7', 'address': '15230 NE 24th St', 'city': 'Redmond', 'state': 'WA', 'country': 'USA', 'zip_code': '98052'},
    {'code': 'ICH1', 'address': '135 S LaSalle St.', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60603'},
    {'code': 'ICH2', 'address': '222 W Merchandise Mart Plaza', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60654'},
    {'code': 'ICH3', 'address': '500 W. Madison', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60661'},
    {'code': 'ICH4', 'address': '227 West Monroe St', 'city': 'CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60606'},
    {'code': 'ICH5', 'address': '111 E Wacker Dr', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60601'},
    {'code': 'ICH6', 'address': '130 E Randolph St', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60601'},
    {'code': 'ICSF', 'address': '2821 MARION DR STE 109', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'ICT1', 'address': '1250 N Mittel Blvd', 'city': 'Wood Dale', 'state': 'IL', 'country': 'USA', 'zip_code': '60191'},
    {'code': 'ICT2', 'address': '7130 N Broadway Ave', 'city': 'Park City', 'state': 'KS', 'country': 'USA', 'zip_code': '67219-1410'},
    {'code': 'IDC1', 'address': '1100 15th St NW', 'city': 'Washington', 'state': 'DC', 'country': 'USA', 'zip_code': '20005'},
    {'code': 'IDC4', 'address': '1733 14th St NW', 'city': 'WASHINGTON', 'state': 'DC', 'country': 'USA', 'zip_code': '20009'},
    {'code': 'IDC9', 'address': '750 9th St. NW', 'city': 'Washington', 'state': 'DC', 'country': 'USA', 'zip_code': '20001'},
    {'code': 'IDT1', 'address': '5617 Industrial Drive', 'city': 'SPRINGFIELD', 'state': 'VA', 'country': 'USA', 'zip_code': '22151-4410'},
    {'code': 'IGQ1', 'address': '15924 WESTERN AVE', 'city': 'MARKHAM', 'state': 'IL', 'country': 'USA', 'zip_code': '60428'},
    {'code': 'IGQ2', 'address': '23257 S Central Ave', 'city': 'University Park', 'state': 'IL', 'country': 'USA', 'zip_code': '60484'},
    {'code': 'ILG1', 'address': '780 S. DUPONT HIGHWAY', 'city': 'NEW CASTLE', 'state': 'DE', 'country': 'USA', 'zip_code': '19720'},
    {'code': 'ILG2', 'address': '405 Lexington Ave', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10174'},
    {'code': 'ILG8', 'address': '80 Pine St.', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10005'},
    {'code': 'ILG9', 'address': '111 E. 59th St.', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10022'},
    {'code': 'ILS1', 'address': '14249 Whittier Blvd', 'city': 'Whittier', 'state': 'CA', 'country': 'USA', 'zip_code': '90607'},
    {'code': 'ILS2', 'address': '22001 Ventura Blvd', 'city': 'Woodland HillsWoodland Hills', 'state': 'CA', 'country': 'USA', 'zip_code': '91364'},
    {'code': 'ILS3', 'address': '22135 Hawthorne Blvd', 'city': 'Torrance', 'state': 'CA', 'country': 'USA', 'zip_code': '90503'},
    {'code': 'ILS4', 'address': '13223 39th Ave SE', 'city': 'Mill Creek', 'state': 'WA', 'country': 'USA', 'zip_code': '98012'},
    {'code': 'IMXF', 'address': 'Parque Industrial Tres Rios, TR8 (Amazon), Carretera Mexico ? Queretaro km 41.5 Col. Ex Hacienda San Miguel', 'city': 'Cuautitlan Izcalli', 'state': 'Region : Estado de M?xico', 'country': 'Mexico', 'zip_code': '54715'},
    {'code': 'IMXH', 'address': 'EJE 140, Av. Central 108, Col. Zona industrial', 'city': 'San Luis Potosi', 'state': 'Region: S.L.P.', 'country': 'Mexico', 'zip_code': '78395'},
    {'code': 'IND1', 'address': '4255 Anson Blvd', 'city': 'Whitestown', 'state': 'IN', 'country': 'USA', 'zip_code': '46075-4412'},
    {'code': 'IND2', 'address': '715 Airtech Pkwy', 'city': 'Plainfield', 'state': 'IN', 'country': 'USA', 'zip_code': '46168-7442'},
    {'code': 'IND3', 'address': '717 Airtech Pkwy', 'city': 'Plainfield', 'state': 'IN', 'country': 'USA', 'zip_code': '46168-7442'},
    {'code': 'IND4', 'address': '710 S. GIRLS SCHOOL RD.', 'city': 'INDIANAPOLIS', 'state': 'IN', 'country': 'USA', 'zip_code': '46231'},
    {'code': 'IND5', 'address': '800 PERRY RD', 'city': 'PLAINFIELD', 'state': 'IN', 'country': 'USA', 'zip_code': '46168-7637'},
    {'code': 'IND6', 'address': '1453 10th Street', 'city': 'Jeffersonville', 'state': 'IN', 'country': 'USA', 'zip_code': '47130'},
    {'code': 'IND7', 'address': '9101 Orly Drive', 'city': 'Indianapolis', 'state': 'IN', 'country': 'USA', 'zip_code': '46241-9605'},
    {'code': 'IND8', 'address': '712 S. Girls School Rd.', 'city': 'Marion', 'state': 'IN', 'country': 'USA', 'zip_code': '46231'},
    {'code': 'IND9', 'address': '1151 S Graham Rd', 'city': 'Greenwood', 'state': 'IN', 'country': 'USA', 'zip_code': '46143-7830'},
    {'code': 'INT2', 'address': '275 Omar Avenue', 'city': 'AVENEL', 'state': 'NJ', 'country': 'USA', 'zip_code': '07001-2240'},
    {'code': 'INY1', 'address': '200 Vesey Street', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10281'},
    {'code': 'INY3', 'address': '300 Park Ave', 'city': 'NEW YORK', 'state': 'NY', 'country': 'USA', 'zip_code': '10022'},
    {'code': 'INY4', 'address': '150 E 53rd St', 'city': 'NEW YORK', 'state': 'NY', 'country': 'USA', 'zip_code': '10022'},
    {'code': 'INY5', 'address': '315 Park Ave S', 'city': 'NEW YORK', 'state': 'NY', 'country': 'USA', 'zip_code': '10010'},
    {'code': 'INY6', 'address': '30 Rockefeller Plaza', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10112'},
    {'code': 'INY7', 'address': '11 W. 42nd St.', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10036'},
    {'code': 'INY9', 'address': '165 Broadway', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10006'},
    {'code': 'IRV1', 'address': '4139 Campus Drive', 'city': 'Irvine', 'state': 'CA', 'country': 'USA', 'zip_code': '92612'},
    {'code': 'ISE1', 'address': '2131 7th Ave', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98121'},
    {'code': 'ISE2', 'address': '1227 124th Ave NE, Building 2, Suite A200', 'city': 'Bellevue', 'state': 'WA', 'country': 'USA', 'zip_code': '98004'},
    {'code': 'ISE5', 'address': '20202 84th Ave South', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'ISE6', 'address': '307 Fairview Avenue North', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'ISE7', 'address': '920 5th Avenue', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98104'},
    {'code': 'ISE8', 'address': '20202 84th Ave South', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'ISE9', 'address': '1122 Madison', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98104'},
    {'code': 'ISF1', 'address': '300 California St.', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94104'},
    {'code': 'ISF2', 'address': '98 Post St.', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94104'},
    {'code': 'ISF3', 'address': '845 Market St', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94103'},
    {'code': 'ISF4', 'address': '3 Embarcadero Center', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94111'},
    {'code': 'ISF5', 'address': '575 Market St', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94105'},
    {'code': 'ISM1', 'address': '2314 WAVERLY BARN RD', 'city': 'DAVENPORT', 'state': 'FL', 'country': 'USA', 'zip_code': '33897'},
    {'code': 'IST1', 'address': '1555 N. Chrisman Rd', 'city': 'Tracy', 'state': 'CA', 'country': 'USA', 'zip_code': '95304'},
    {'code': 'ITUS', 'address': '1926 6TH AVE S', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98134'},
    {'code': 'ITX1', 'address': '9851 Fallbrook Pines', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77064-3329'},
    {'code': 'ITX2', 'address': '6811 Fairbanks N Houston Road', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77040-1437'},
    {'code': 'IUSA', 'address': '1001 W Walnut St', 'city': 'Compton', 'state': 'CA', 'country': 'USA', 'zip_code': '90220-5111'},
    {'code': 'IUSE', 'address': '10 Sonny Perdue Drive', 'city': 'SAVANNAH', 'state': 'GA', 'country': 'USA', 'zip_code': '31408'},
    {'code': 'IUSK', 'address': '4501 Patterson Ave', 'city': 'PERRIS', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'IUSL', 'address': '600 PRINCIPIO PKWY W', 'city': 'NORTH EAST', 'state': 'MD', 'country': 'USA', 'zip_code': '21901'},
    {'code': 'IUSM', 'address': '4200 FERRY RD', 'city': 'NAPERVILLE', 'state': 'IL', 'country': 'USA', 'zip_code': '60563'},
    {'code': 'IVSA', 'address': '4620 OLYMPIC BLVD.', 'city': 'ERLANGER', 'state': 'KY', 'country': 'USA', 'zip_code': '41018'},
    {'code': 'IVSB', 'address': '3521 POINT PLEASANT RD.', 'city': 'HEBRON', 'state': 'KY', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'IVSC', 'address': '1225 Forest Parkway', 'city': 'West Deptford', 'state': 'NJ', 'country': 'USA', 'zip_code': '8066'},
    {'code': 'IVSD', 'address': '800 ARLINGTON BLVD', 'city': 'SWEDESBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'IVSE', 'address': '2951 MARION DR UNIT 101', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'IVSF', 'address': '2821 MARION DR', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'IWA2', 'address': '15518 Meridian Ave E', 'city': 'Puyallup', 'state': 'WA', 'country': 'USA', 'zip_code': '98375'},
    {'code': 'JAN1', 'address': '219 MADISON COUNTY PARKWAY', 'city': 'CANTON', 'state': 'MS', 'country': 'USA', 'zip_code': '39046'},
    {'code': 'JAX1', 'address': '12900 Pecan Park Road', 'city': 'Jacksonville', 'state': 'FL', 'country': 'USA', 'zip_code': '32218'},
    {'code': 'JAX2', 'address': '12900 Pecan Park Rd', 'city': 'Jacksonville', 'state': 'FL', 'country': 'USA', 'zip_code': '32218-2432'},
    {'code': 'JAX3', 'address': '13333 103rd St', 'city': 'Jacksonville', 'state': 'FL', 'country': 'USA', 'zip_code': '32210-8686'},
    {'code': 'JAX5', 'address': '4948 BULLS BAY HWY', 'city': 'JACKSONVILLE', 'state': 'FL', 'country': 'USA', 'zip_code': '32219'},
    {'code': 'JAX6', 'address': '2619 IGNITION DR', 'city': 'JACKSONVILLE', 'state': 'FL', 'country': 'USA', 'zip_code': '32218'},
    {'code': 'JAX7', 'address': '10501 COLD STORAGE RD', 'city': 'JACKSONVILLE', 'state': 'FL', 'country': 'USA', 'zip_code': '32218'},
    {'code': 'JFK2', 'address': '7 W 34th St', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10001'},
    {'code': 'JFK7', 'address': '7 W 34th St', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10001-8100'},
    {'code': 'JFK8', 'address': '546 Gulf Ave.', 'city': 'Staten Island', 'state': 'NY', 'country': 'USA', 'zip_code': '10314'},
    {'code': 'JFK9', 'address': '80 Grumman Rd W', 'city': 'Bethpage', 'state': 'NY', 'country': 'USA', 'zip_code': '11714-5000'},
    {'code': 'JHW1', 'address': '4333 INTEGRATION LOOP', 'city': 'COLORADO SPRINGS', 'state': 'CO', 'country': 'USA', 'zip_code': '80916'},
    {'code': 'JVL1', 'address': '1255 GATEWAY BLVD', 'city': 'BELOIT', 'state': 'WI', 'country': 'USA', 'zip_code': '53511'},
    {'code': 'KBWI', 'address': '27350 Mathison Way', 'city': 'Baltimore', 'state': 'MD', 'country': 'USA', 'zip_code': '21240'},
    {'code': 'KCA6', 'address': '1553 N Alder Ave', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'KCA8', 'address': '1553 N Alder Ave', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'KDC1', 'address': '1350 Connecticut Ave NW', 'city': 'Washington', 'state': 'DC', 'country': 'USA', 'zip_code': '20036'},
    {'code': 'KGA6', 'address': '3201 Centre Parkway', 'city': 'ATLANTA', 'state': 'GA', 'country': 'USA', 'zip_code': '30344'},
    {'code': 'KGA8', 'address': '3201 Centre Parkway', 'city': 'ATLANTA', 'state': 'GA', 'country': 'USA', 'zip_code': '30344'},
    {'code': 'KIL1', 'address': '3900 S Brandon Rd', 'city': 'Elwood', 'state': 'IL', 'country': 'USA', 'zip_code': '60421'},
    {'code': 'KIL6', 'address': '3900 S Brandon Rd', 'city': 'ELWOOD', 'state': 'IL', 'country': 'USA', 'zip_code': '60421'},
    {'code': 'KIL8', 'address': '3900 S Brandon Rd', 'city': 'ELWOOD', 'state': 'IL', 'country': 'USA', 'zip_code': '60421'},
    {'code': 'KILN', 'address': '150 RUANE DR', 'city': 'WILMINGTON', 'state': 'OH', 'country': 'USA', 'zip_code': '45177-7709'},
    {'code': 'KIX1', 'address': '138-7 Chikkoyawata-machi', 'city': 'Sakai-Ku, Sakai-shi', 'state': 'Osaka', 'country': 'Japan', 'zip_code': '590-0901'},
    {'code': 'KIX2', 'address': '2-1-1 Midorigaoka', 'city': 'Daito-shi', 'state': 'Osaka', 'country': 'Japan', 'zip_code': '574-8531'},
    {'code': 'KLAL', 'address': '4145 Kidron Rd', 'city': 'Lakeland', 'state': 'FL', 'country': 'USA', 'zip_code': '33811-1275'},
    {'code': 'KMA6', 'address': '400 ARLINGTON BLVD', 'city': 'SWEDESBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'KMA8', 'address': '400 ARLINGTON BLVD', 'city': 'SWEDESBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'KNJ2', 'address': '400 ARLINGTON BLVD', 'city': 'SWEDESBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'KOH1', 'address': '1001 Logistics Way', 'city': 'Monroe', 'state': 'OH', 'country': 'USA', 'zip_code': '45044'},
    {'code': 'KOH2', 'address': '1001 Logistics Way', 'city': 'MONROE', 'state': 'OH', 'country': 'USA', 'zip_code': '45044'},
    {'code': 'KOH6', 'address': '1001 LOGISTICS WAY', 'city': 'MONROE', 'state': 'OH', 'country': 'USA', 'zip_code': '45044'},
    {'code': 'KOH8', 'address': '1001 LOGISTICS WAY', 'city': 'MONROE', 'state': 'OH', 'country': 'USA', 'zip_code': '45044'},
    {'code': 'KPA1', 'address': '200 W STEWART HUSTON DR', 'city': 'COATESVILLE', 'state': 'PA', 'country': 'USA', 'zip_code': '19320'},
    {'code': 'KRB1', 'address': '555 E. ORANGE SHOW RD.', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'KRB2', 'address': '7000 Hardware Dr', 'city': 'Prince George', 'state': 'VA', 'country': 'USA', 'zip_code': '23875-3041'},
    {'code': 'KRB3', 'address': '8181 W ROOSEVELT ST', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'KRB4', 'address': '4501 PATTERSON AVE', 'city': 'PERRIS', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'KRB5', 'address': '600 PRINCIPIO PKWY W', 'city': 'NORTH EAST', 'state': 'MD', 'country': 'USA', 'zip_code': '21901'},
    {'code': 'KRB6', 'address': '4200 FERRY RD', 'city': 'Aurora', 'state': 'IL', 'country': 'USA', 'zip_code': '60563'},
    {'code': 'KRFD', 'address': '5824 Kishwaukee Rd.', 'city': 'Rockford', 'state': 'IL', 'country': 'USA', 'zip_code': '61109'},
    {'code': 'KRIV', 'address': '17101 Heacock St.', 'city': 'Moreno Valley', 'state': 'CA', 'country': 'USA', 'zip_code': '92551'},
    {'code': 'KSBD', 'address': '2535 EAST 3RD STREET', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'KTO2', 'address': '2480 Meadowvale Blvd Unit 3 Mississauga', 'city': 'Ontario', 'state': 'ON', 'country': 'Canada', 'zip_code': 'ON L5N 8M6'},
    {'code': 'KTO7', 'address': '2480 Meadowvale Blvd, Unit 3', 'city': 'Mississauga', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L5N 8M6'},
    {'code': 'KTX1', 'address': '15716 WOLF XING BLDG E', 'city': 'JUSTIN', 'state': 'TX', 'country': 'USA', 'zip_code': '76247'},
    {'code': 'KTX2', 'address': '15716 WOLF XING BLDG E', 'city': 'JUSTIN', 'state': 'TX', 'country': 'USA', 'zip_code': '76247'},
    {'code': 'KTX6', 'address': '1901 W AIRFIELD DR', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75261'},
    {'code': 'KTX8', 'address': '1901 W AIRFIELD DR', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '72561'},
    {'code': 'KUS1', 'address': '639 Huigang Road, Yangshan Free Trade Port Area, Lingang New City, Pudong New District', 'city': 'Shanghai', 'state': 'Zhejiang', 'country': 'China', 'zip_code': '201306'},
    {'code': 'KUS2', 'address': '2nd Floor. A57 Building B. North Modern Logistics Center. Yantian Integrated Bonded Zone. Mingzhu Ave', 'city': 'Shenzhen', 'state': 'Guangdong Province', 'country': 'China', 'zip_code': '518083'},
    {'code': 'KUS3', 'address': 'No.1, Gangtong Road, Meishan Free Trade Port Area', 'city': 'Ningbo', 'state': 'US', 'country': 'USA', 'zip_code': '315832'},
    {'code': 'LAL1', 'address': '1760 County Line Rd.', 'city': 'Lakeland', 'state': 'FL', 'country': 'USA', 'zip_code': '33811'},
    {'code': 'LAL4', 'address': '16581 DOMESTIC AVE', 'city': 'FORT MYERS', 'state': 'FL', 'country': 'USA', 'zip_code': '33912'},
    {'code': 'LAS1', 'address': '12300 BERMUDA RD', 'city': 'HENDERSON', 'state': 'NV', 'country': 'USA', 'zip_code': '89044'},
    {'code': 'LAS2', 'address': '3837 BAY LAKE TRAIL, SUITE #111N', 'city': 'NORTH LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89030-4428'},
    {'code': 'LAS5', 'address': '4410 NEXUS WAY', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'LAS6', 'address': '4550 NEXUS WAY', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'LAS7', 'address': '6001 East Tropical Parkway', 'city': 'North Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'LAS8', 'address': '5801 N Nicco Way', 'city': 'Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'LAS9', 'address': '5801 N Nico Way', 'city': 'Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'LASX', 'address': 'North Lamb Blvd and Tropical Parkway', 'city': 'North Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89081'},
    {'code': 'LAX2', 'address': '5650 DOLLY AVE.', 'city': 'BUENA PARK', 'state': 'CA', 'country': 'USA', 'zip_code': '90621'},
    {'code': 'LAX5', 'address': '6400 VALLEY VIEW ST.', 'city': 'BUENA PARK', 'state': 'CA', 'country': 'USA', 'zip_code': '90620'},
    {'code': 'LAX6', 'address': '5119 District Blvd', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90058'},
    {'code': 'LAX8', 'address': '30142 Avenida De Las Banderas', 'city': 'Rancho Santa Margarita', 'state': 'CA', 'country': 'USA', 'zip_code': '92688-2116'},
    {'code': 'LAX9', 'address': '11263 Oleander Ave', 'city': 'Fontana', 'state': 'CA', 'country': 'USA', 'zip_code': '92337'},
    {'code': 'LB A', 'address': 'Iport Development', 'city': 'Rossington, Doncaster', 'state': 'South Yorkshire', 'country': 'United Kingdom', 'zip_code': ''},
    {'code': 'LBA1', 'address': 'Firstpoint Business Park, Unit 1, Balby Carr Bank,', 'city': 'Doncaster', 'state': 'South Yorkshire', 'country': 'United Kingdom', 'zip_code': 'DN4 5JS'},
    {'code': 'LBA2', 'address': 'Water Vole Way, Firstpoint Logistic Park', 'city': 'Doncaster', 'state': 'South Yorkshire', 'country': 'United Kingdom', 'zip_code': 'DN48DP'},
    {'code': 'LBB1', 'address': '2407 9th Street, Suite 400', 'city': 'Lubbock', 'state': 'TX', 'country': 'USA', 'zip_code': '79401'},
    {'code': 'LBB5', 'address': '1110 E. HUNTER ST', 'city': 'LUBBOCK', 'state': 'TX', 'country': 'USA', 'zip_code': '79403'},
    {'code': 'LCK1', 'address': '3880 Groveport Road', 'city': 'Obetz', 'state': 'OH', 'country': 'USA', 'zip_code': '43207'},
    {'code': 'LCY1', 'address': 'Dock Road & Gaylor Road', 'city': 'Tilbury', 'state': 'Essex', 'country': 'United Kingdom', 'zip_code': 'RM17 6HH'},
    {'code': 'LDJ5', 'address': '526 GULF AVE', 'city': 'STATEN ISLAND', 'state': 'NY', 'country': 'USA', 'zip_code': '10314'},
    {'code': 'LEJ1', 'address': 'Amazonstrasse 1', 'city': 'Leipzig', 'state': 'Saxony', 'country': 'Germany', 'zip_code': '4347'},
    {'code': 'LEX', 'address': '3070 LAKECREST CIR STE 400 PMB 280', 'city': 'LEXINGTON', 'state': 'KY', 'country': 'USA', 'zip_code': '40513'},
    {'code': 'LEX1', 'address': '1850 Mercer Drive, Attn: Receiving', 'city': 'Lexington', 'state': 'KY', 'country': 'USA', 'zip_code': '40511-1013'},
    {'code': 'LEX2', 'address': '172 Trade St.', 'city': 'Lexington', 'state': 'KY', 'country': 'USA', 'zip_code': '40511-2607'},
    {'code': 'LEX3', 'address': '1850 Mercer Rd', 'city': 'Lexington', 'state': 'KY', 'country': 'USA', 'zip_code': '40511'},
    {'code': 'LEX5', 'address': '4600 Olympic Blvd', 'city': 'Erlanger', 'state': 'KY', 'country': 'USA', 'zip_code': '41018'},
    {'code': 'LFT1', 'address': '3620 NE Evangeline Throughway', 'city': 'Carencro', 'state': 'LA', 'country': 'USA', 'zip_code': '70520-5948'},
    {'code': 'LGA5', 'address': '2205 Route 27', 'city': 'Edison', 'state': 'NJ', 'country': 'USA', 'zip_code': '08817-3313'},
    {'code': 'LGA6', 'address': '8003 Industrial Avenue', 'city': 'Cartaret', 'state': 'NJ', 'country': 'USA', 'zip_code': '07008-3529'},
    {'code': 'LGA7', 'address': '380 Middlesex Ave', 'city': 'Carteret', 'state': 'NJ', 'country': 'USA', 'zip_code': '07008-3446'},
    {'code': 'LGA8', 'address': '380 Middlesex Avenue', 'city': 'Carteret', 'state': 'NJ', 'country': 'USA', 'zip_code': '7008'},
    {'code': 'LGA9', 'address': '2170 State Route 27', 'city': 'Edison', 'state': 'NJ', 'country': 'USA', 'zip_code': '08817-3332'},
    {'code': 'LGB1', 'address': '2417 E. Carson, St., Long Beach 3PL Import Crossdock', 'city': 'Long Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '90810'},
    {'code': 'LGB2', 'address': '6049 E 7th St', 'city': 'Long Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '90840'},
    {'code': 'LGB3', 'address': '4950 Goodman Way Bldg 1', 'city': 'Eastvale', 'state': 'CA', 'country': 'USA', 'zip_code': '91752-5087'},
    {'code': 'LGB4', 'address': '27517 PIONEER AVE', 'city': 'REDLANDS', 'state': 'CA', 'country': 'USA', 'zip_code': '92374-1501'},
    {'code': 'LGB5', 'address': '555 E Orange Show Rd', 'city': 'San Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408-2453'},
    {'code': 'LGB6', 'address': '20901 Krameria Ave', 'city': 'Riverside', 'state': 'CA', 'country': 'USA', 'zip_code': '92508'},
    {'code': 'LGB7', 'address': '1660 N. LOCUST AVE.', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'LGB8', 'address': '1568 N LINDEN AVE', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'LGB9', 'address': '4375 N Perris Blvd', 'city': 'Perris', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'LIL1', 'address': 'Rue de la Plaine 59553', 'city': 'Nord-Pas-de-Calais', 'state': 'Nord-Pas-de-Calais', 'country': 'France', 'zip_code': '59553'},
    {'code': 'LIT1', 'address': '7001 Zeuber Rd', 'city': 'Little Rock', 'state': 'AR', 'country': 'USA', 'zip_code': '72206-5039'},
    {'code': 'LIT2', 'address': '13001 Highway 70', 'city': 'N Little Rock', 'state': 'AR', 'country': 'USA', 'zip_code': '72117-5026'},
    {'code': 'LTN1', 'address': 'Ridgmont, Marston Gate', 'city': 'Ridgmont, Marston Gate', 'state': 'Bedfordshire', 'country': 'United Kingdom', 'zip_code': 'MK43 0ZA'},
    {'code': 'LTN2', 'address': 'Boundary Way', 'city': 'Hemel Hempsted', 'state': 'Hertfordshire', 'country': 'United Kingdom', 'zip_code': 'HP2 7LF'},
    {'code': 'LTN3', 'address': 'Boscombe Road, DC1, Prologis Park Dunstable', 'city': 'Dunstable', 'state': 'Bedfordshire', 'country': 'United Kingdom', 'zip_code': 'LU5 4RW'},
    {'code': 'LUH1', 'address': 'Doraha. Ludhiana', 'city': 'Doraha. Ludhiana', 'state': 'Punjab', 'country': 'India', 'zip_code': ''},
    {'code': 'LUK2', 'address': '10791 DOG LEG RD', 'city': 'VANDALIA', 'state': 'OH', 'country': 'USA', 'zip_code': '45377'},
    {'code': 'LUK5', 'address': '560 Erlanger Rd', 'city': 'Erlanger', 'state': 'KY', 'country': 'USA', 'zip_code': '41018-1242'},
    {'code': 'LUK7', 'address': '649 Omega Prkwy', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165-8501'},
    {'code': 'LYS1', 'address': 'Distripole Chalon, ZAC du Parc dActivite du Val de Bourgogne, 1 Rue Ama', 'city': 'Sevrey, Saone-et-Loire', 'state': 'Burgundy', 'country': 'France', 'zip_code': '71100'},
    {'code': 'MAB1', 'address': '6245 Topanga Canyon Blvd', 'city': 'Woodland Hills', 'state': 'CA', 'country': 'USA', 'zip_code': '91367'},
    {'code': 'MAB2', 'address': '3903 Factoria Blvd', 'city': 'Bellevue', 'state': 'WA', 'country': 'USA', 'zip_code': '98006'},
    {'code': 'MAB3', 'address': '10354 Fairfax Blvd', 'city': 'Fairfax', 'state': 'VA', 'country': 'USA', 'zip_code': '22030'},
    {'code': 'MAB4', 'address': '5101 Lankershim Blvd.', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '91601'},
    {'code': 'MAB5', 'address': '19340 Rinaldi St.', 'city': 'Northridge', 'state': 'CA', 'country': 'USA', 'zip_code': '91326'},
    {'code': 'MAB6', 'address': '2309 S. Jackson St', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98144'},
    {'code': 'MAB7', 'address': '13201 Aurora Ave. N.', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98133'},
    {'code': 'MAB9', 'address': '13752 Jamboree Rd', 'city': 'Irvine', 'state': 'CA', 'country': 'USA', 'zip_code': '92602'},
    {'code': 'MAC1', 'address': '3116 S. Rt. 59, suite #104', 'city': 'Naperville', 'state': 'IL', 'country': 'USA', 'zip_code': '60564'},
    {'code': 'MAC2', 'address': '1100 S Harbor Blvd', 'city': 'Fullerton', 'state': 'CA', 'country': 'USA', 'zip_code': '92832'},
    {'code': 'MAC4', 'address': '1610 W Imperial Hwy', 'city': 'La Habra', 'state': 'CA', 'country': 'USA', 'zip_code': '90631'},
    {'code': 'MAC7', 'address': '16 E Golf Rd', 'city': 'Schaumburg', 'state': 'CA', 'country': 'USA', 'zip_code': '91367'},
    {'code': 'MAC9', 'address': '6235 E Spring St', 'city': 'Long Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '90808'},
    {'code': 'MAD4', 'address': 'Avenida de la Astronomia 24, Madrid Puerta de San Fernando', 'city': 'San Fernando de Henares', 'state': 'Madrid', 'country': 'Spain', 'zip_code': '28830'},
    {'code': 'MAE1', 'address': '399 Fairview Ave North', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'MAE3', 'address': '6939 Dempster St', 'city': 'MORTON GROVE', 'state': 'IL', 'country': 'USA', 'zip_code': '60053'},
    {'code': 'MAE4', 'address': '4101 W 95th St', 'city': 'Oak Lawn', 'state': 'IL', 'country': 'USA', 'zip_code': '60453'},
    {'code': 'MAE6', 'address': '15225 Whittier Blvd', 'city': 'Whittier', 'state': 'CA', 'country': 'USA', 'zip_code': '90603'},
    {'code': 'MAF1', 'address': '5463 Wisconsin Ave', 'city': 'Chevy Chase Village', 'state': 'MD', 'country': 'USA', 'zip_code': '20815'},
    {'code': 'MAF4', 'address': '140 Promenade Way CA', 'city': 'Westlake Village', 'state': 'CA', 'country': 'USA', 'zip_code': '91362'},
    {'code': 'MAF6', 'address': '1837 Street Rd', 'city': 'Bensalem', 'state': 'PA', 'country': 'USA', 'zip_code': '19020'},
    {'code': 'MAF7', 'address': '389 Easton Road', 'city': 'WARRINGTON', 'state': 'PA', 'country': 'USA', 'zip_code': '18976'},
    {'code': 'MAF9', 'address': '11340 South Street', 'city': 'CERRITOS', 'state': 'CA', 'country': 'USA', 'zip_code': '90701'},
    {'code': 'MAG', 'address': '3404 W Army Trail Rd', 'city': 'Bloomingdale', 'state': 'IL', 'country': 'USA', 'zip_code': '60188'},
    {'code': 'MAG1', 'address': '6855 S La Cienega Blvd', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90045'},
    {'code': 'MAG3', 'address': '404 W Army Trail Rd', 'city': 'BLOOMINGDALE', 'state': 'IL', 'country': 'USA', 'zip_code': '60188'},
    {'code': 'MAG4', 'address': '30 W 63rd St', 'city': 'Westmont', 'state': 'IL', 'country': 'USA', 'zip_code': '60559'},
    {'code': 'MAG6', 'address': '7005 Manchester Blvd', 'city': 'Franconia', 'state': 'VA', 'country': 'USA', 'zip_code': '22310'},
    {'code': 'MAH8', 'address': '40481 Murrieta Hot Springs Rd', 'city': 'MURRIETA', 'state': 'WA', 'country': 'USA', 'zip_code': '92563'},
    {'code': 'MAJ2', 'address': '7201 W 24th ST', 'city': 'RIVERSIDE', 'state': 'IL', 'country': 'USA', 'zip_code': '60546'},
    {'code': 'MAJ5', 'address': '1351 E Ogden Ave', 'city': 'NAPERVILLE', 'state': 'IL', 'country': 'USA', 'zip_code': '60563'},
    {'code': 'MAK3', 'address': '3620 Long Beach Rd', 'city': 'Oceanside', 'state': 'NY', 'country': 'USA', 'zip_code': '11572'},
    {'code': 'MAM7', 'address': '742 Los Angeles Ave', 'city': 'MOORPARK', 'state': 'CA', 'country': 'USA', 'zip_code': '93021'},
    {'code': 'MAN1', 'address': 'Wythenshawes Airport City, Manchester', 'city': 'Airport City', 'state': 'Manchester', 'country': 'United Kingdom', 'zip_code': ''},
    {'code': 'Mar1', 'address': '4200 Guilford Dr, Suite B1', 'city': 'College Park', 'state': 'MD', 'country': 'USA', 'zip_code': '20740'},
    {'code': 'MAS1', 'address': '220 Campus Center, 1 Campus Center Way', 'city': 'Amherst', 'state': 'MA', 'country': 'USA', 'zip_code': '1003'},
    {'code': 'MC05', 'address': '305 Deen Still Road', 'city': 'Davenport', 'state': 'FL', 'country': 'USA', 'zip_code': '33897'},
    {'code': 'MCE1', 'address': 'FULKERTH RD', 'city': 'TURLOCK', 'state': 'CA', 'country': 'USA', 'zip_code': '95380'},
    {'code': 'MCI1', 'address': '16851 W 113th St', 'city': 'Lenexa', 'state': 'KS', 'country': 'USA', 'zip_code': '66219'},
    {'code': 'MCI2', 'address': '14500 BOTTS RD', 'city': 'KANSAS CITY', 'state': 'MO', 'country': 'USA', 'zip_code': '64147'},
    {'code': 'MCI5', 'address': '16851 W 113th St', 'city': 'Lenexa', 'state': 'KS', 'country': 'USA', 'zip_code': '66219'},
    {'code': 'MCI7', 'address': '27200 W. 157TH ST.', 'city': 'NEW CENTURY', 'state': 'KS', 'country': 'USA', 'zip_code': '66031-1114'},
    {'code': 'MCIX', 'address': '113th Street and Renner Boulevard', 'city': 'Lenexa', 'state': 'KS', 'country': 'USA', 'zip_code': '66219'},
    {'code': 'MCO1', 'address': '12340 Boggy Creek Rd', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32824-6902'},
    {'code': 'MCO2', 'address': '2600 N NORMANDY BLVD', 'city': 'DELTONA', 'state': 'FL', 'country': 'USA', 'zip_code': '32725'},
    {'code': 'MCO3', 'address': '8825 BOGGY CREEK RD', 'city': 'ORLANDO', 'state': 'FL', 'country': 'USA', 'zip_code': '32824'},
    {'code': 'MCO4', 'address': '2314 Waverly Barn Rd Ste 150', 'city': 'Davenport', 'state': 'FL', 'country': 'USA', 'zip_code': '33897-8601'},
    {'code': 'MCO5', 'address': '305 Deen Still Rd', 'city': 'Davenport', 'state': 'FL', 'country': 'USA', 'zip_code': '33897-9409'},
    {'code': 'MCO6', 'address': '7469 Kingspointe Parkway', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32819'},
    {'code': 'MCO9', 'address': '2841 Access Rd NW', 'city': 'Davenport', 'state': 'FL', 'country': 'USA', 'zip_code': '33897'},
    {'code': 'MDT1', 'address': '2 Ames Dr', 'city': 'Carlisle', 'state': 'PA', 'country': 'USA', 'zip_code': '17015'},
    {'code': 'MDT2', 'address': '600 PRINCIPIO PKWY W', 'city': 'NORTH EAST', 'state': 'MD', 'country': 'USA', 'zip_code': '21901'},
    {'code': 'MDT3', 'address': '460 Research Drive', 'city': 'PITTISON', 'state': 'PA', 'country': 'USA', 'zip_code': '18640-6152'},
    {'code': 'MDT5', 'address': '200 Goodman Dr', 'city': 'Lewisberry', 'state': 'PA', 'country': 'USA', 'zip_code': '17339'},
    {'code': 'MDW1', 'address': 'Greater Chicago Area', 'city': 'Joliet', 'state': 'IL', 'country': 'USA', 'zip_code': '60433'},
    {'code': 'MDW2', 'address': '401 E LARAWAY ROAD', 'city': 'JOLIET', 'state': 'IL', 'country': 'USA', 'zip_code': '60433-9642'},
    {'code': 'MDW4', 'address': '201 EMERALD DRIVE', 'city': 'JOILET', 'state': 'IL', 'country': 'USA', 'zip_code': '60433-3281'},
    {'code': 'MDW5', 'address': '16824 ENTERPRISE BLVD', 'city': 'CREST HILL', 'state': 'IL', 'country': 'USA', 'zip_code': '60435'},
    {'code': 'MDW6', 'address': '1125 REMINGTON BLVD', 'city': 'ROMEOVILLE', 'state': 'IL', 'country': 'USA', 'zip_code': '60446-6529'},
    {'code': 'MDW7', 'address': '6521 Monee Manhattan Rd', 'city': 'Monee', 'state': 'IL', 'country': 'USA', 'zip_code': '60449-9668'},
    {'code': 'MDW8', 'address': '1750 BRIDGE DR', 'city': 'WAUKEGAN', 'state': 'IL', 'country': 'USA', 'zip_code': '60085'},
    {'code': 'MDW9', 'address': '2865 DUKE PKWY', 'city': 'AURORA', 'state': 'IL', 'country': 'USA', 'zip_code': '60502-8200'},
    {'code': 'MDWX', 'address': '2801 S. Western Ave', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60608'},
    {'code': 'MDWY', 'address': 'Route 59', 'city': 'Aurora', 'state': 'IL', 'country': 'USA', 'zip_code': '60563'},
    {'code': 'MDWZ', 'address': 'Route 59', 'city': 'Aurora', 'state': 'IL', 'country': 'USA', 'zip_code': '60563'},
    {'code': 'MEM1', 'address': '3292 E Holmes Rd', 'city': 'Memphis', 'state': 'TN', 'country': 'USA', 'zip_code': '38118-8102'},
    {'code': 'MEM2', 'address': '191 Norfolk Southern Way', 'city': 'Byhalia', 'state': 'MS', 'country': 'USA', 'zip_code': '38611-2306'},
    {'code': 'MEM3', 'address': '1615 COMMERCE PKWY, BLDG B', 'city': 'HORN LAKE', 'state': 'MS', 'country': 'USA', 'zip_code': '38637'},
    {'code': 'MEM4', 'address': '4055 New Allen Rd', 'city': 'Memphis', 'state': 'TN', 'country': 'USA', 'zip_code': '38128-2718'},
    {'code': 'MEM5', 'address': '5155 CITATION DR.', 'city': 'MEMPHIS', 'state': 'TN', 'country': 'USA', 'zip_code': '38118'},
    {'code': 'MEM6', 'address': '11505 PROGRESS WAY', 'city': 'OLIVE BRANCH', 'state': 'MS', 'country': 'USA', 'zip_code': '38654'},
    {'code': 'MEM8', 'address': '850 GATEWAY GLOBAL DRIVE', 'city': 'BYHALIA', 'state': 'MS', 'country': 'USA', 'zip_code': '38611'},
    {'code': 'MEX', 'address': 'Autopista Champa-Lecheria KM 2.5, San Martin Obispo', 'city': 'Cuautitlan Izcalli', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '54769'},
    {'code': 'MEX1', 'address': 'Prologis Park, Tres Rios, Edificio TR8, Av. Jorge Jimenez Cantu, Col. Exhacienda San Miguel', 'city': 'Cuautitlan Izcalli', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '54715'},
    {'code': 'MEX2', 'address': 'Autopista Chamapa-Lecheria KM 2.5, San Martin Obispo Cuautitlan Izcalli', 'city': 'Cuautitlan Izcalli', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '54769'},
    {'code': 'MEX3', 'address': 'Prologis Park Grande, Edificio 1 ,, Carretera a Coyotepec Lote 2 S/N Fraccion A Poniente', 'city': 'La Teja', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '54607'},
    {'code': 'MEX6', 'address': 'Camino a Coyotepec, Fraccion B de la Fraccion 1 Ext SN, Exhacienda San Jose la Teja, CP 54607', 'city': 'Tepotzatian', 'state': 'MX', 'country': 'Mexico', 'zip_code': '54607'},
    {'code': 'MGE1', 'address': '650 BROADWAY AVE.', 'city': 'BRASELTON', 'state': 'GA', 'country': 'USA', 'zip_code': '30517-3002'},
    {'code': 'MGE3', 'address': '808 HOG MOUNTAIN RD.', 'city': 'JEFFERSON', 'state': 'GA', 'country': 'USA', 'zip_code': '30549-2010'},
    {'code': 'MGE5', 'address': '235 HOG MOUNTAIN RD', 'city': 'JEFFERSON', 'state': 'GA', 'country': 'USA', 'zip_code': '30549-2009'},
    {'code': 'MGE7', 'address': '650 Braselton Avenue', 'city': 'Braselton', 'state': 'GA', 'country': 'USA', 'zip_code': '30517'},
    {'code': 'MGE8', 'address': '4905 Derrick Rd', 'city': 'Atlanta', 'state': 'GA', 'country': 'USA', 'zip_code': '30349-1608'},
    {'code': 'MGE9', 'address': '6400 BUFFINGTON RD', 'city': 'UNION CITY', 'state': 'GA', 'country': 'USA', 'zip_code': '30291'},
    {'code': 'MHG1', 'address': 'Frankenthal. Rhineland-Palatinate', 'city': 'Frankenthal', 'state': 'Rhineland-Palatinate', 'country': 'Germany', 'zip_code': ''},
    {'code': 'MIA1', 'address': '14000 NW 37TH AVE.', 'city': 'OPA- LOCKA', 'state': 'FL', 'country': 'USA', 'zip_code': '33054'},
    {'code': 'MIA2', 'address': '14250 AVIATION DR', 'city': 'OPA LOCKA', 'state': 'FL', 'country': 'USA', 'zip_code': '33054'},
    {'code': 'MIA5', 'address': '1900 NW 132nd Pl', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33182-1920'},
    {'code': 'MIA6', 'address': '3200 NW 67th Avenue', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33122'},
    {'code': 'MIA7', 'address': '1900 NW 132nd Place', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33182'},
    {'code': 'MID1', 'address': 'C. Mariano Galván Rivera', 'city': 'Ttepotzotlan', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '54605'},
    {'code': 'MIN1', 'address': '311 SE Harvard Street', 'city': 'Minneapolis', 'state': 'MN', 'country': 'USA', 'zip_code': '55414'},
    {'code': 'MKC4', 'address': '19645 Waverly Rd', 'city': 'Gardner', 'state': 'KS', 'country': 'USA', 'zip_code': '66030'},
    {'code': 'MKC6', 'address': '6925 Riverview Ave', 'city': 'Kansas City', 'state': 'KS', 'country': 'USA', 'zip_code': '66102-3047'},
    {'code': 'MKE1', 'address': '3501 120th Ave', 'city': 'Kenosha', 'state': 'WI', 'country': 'USA', 'zip_code': '53144-7502'},
    {'code': 'MKE2', 'address': '9700 S 13TH ST', 'city': 'OAK CREEK', 'state': 'WI', 'country': 'USA', 'zip_code': '53154'},
    {'code': 'MKE5', 'address': '11121 Burlington Rd', 'city': 'Kenosha', 'state': 'WI', 'country': 'USA', 'zip_code': '53144-7449'},
    {'code': 'MKE6', 'address': '3940 S LAKESIDE DR', 'city': 'WAUKEGAN', 'state': 'IL', 'country': 'USA', 'zip_code': '60085'},
    {'code': 'MKE9', 'address': '11211 Burlington Road', 'city': 'Kenosha', 'state': 'WI', 'country': 'USA', 'zip_code': '53144'},
    {'code': 'MLI1', 'address': 'N DIVISION ST', 'city': 'DAVENPORT', 'state': 'IA', 'country': 'USA', 'zip_code': '52806'},
    {'code': 'MMU9', 'address': '698 Rte. 46 W.', 'city': 'TETERBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '7608'},
    {'code': 'MOB5', 'address': '6735 TRIPPEL RD.', 'city': 'MOBILE', 'state': 'AL', 'country': 'USA', 'zip_code': '36619'},
    {'code': 'MOB9', 'address': '6735 Trippel Rd.', 'city': 'Theodore', 'state': 'AL', 'country': 'USA', 'zip_code': '36582'},
    {'code': 'MQJ1', 'address': '4412 W CR 300 N', 'city': 'GREENFIELD', 'state': 'IN', 'country': 'USA', 'zip_code': '46140'},
    {'code': 'MQJ2', 'address': '19 Bob Glidden Blvd.', 'city': 'Whiteland', 'state': 'IN', 'country': 'USA', 'zip_code': '46184'},
    {'code': 'MQJ5', 'address': '1800 SMITH RD', 'city': 'PLAINFIELD', 'state': 'IN', 'country': 'USA', 'zip_code': '46168'},
    {'code': 'MQJ9', 'address': '120 JIM BLACK RD', 'city': 'FRANKLIN', 'state': 'IN', 'country': 'USA', 'zip_code': '46131'},
    {'code': 'MQY1', 'address': '6060 GOLDEN BEAR GATEWAY', 'city': 'MOUNT JULIET', 'state': 'TN', 'country': 'USA', 'zip_code': '37122'},
    {'code': 'MRS1', 'address': 'Building 2, Rue Joseph Garde. ZAC Les Portes de Provence', 'city': 'Montelimar', 'state': 'Drome', 'country': 'France', 'zip_code': 'F-26200'},
    {'code': 'MSP1', 'address': '2601 4th Ave E', 'city': 'Shakopee', 'state': 'MN', 'country': 'USA', 'zip_code': '55379-1726'},
    {'code': 'MSP4', 'address': '10608 HUDSON RD', 'city': 'WOODBURY', 'state': 'MN', 'country': 'USA', 'zip_code': '55129-9113'},
    {'code': 'MSP5', 'address': '5825 11TH AVENUE EAST', 'city': 'SHAKOPEE', 'state': 'MN', 'country': 'USA', 'zip_code': '55379-3810'},
    {'code': 'MSP6', 'address': '9800 217TH ST W', 'city': 'Lakeville', 'state': 'MN', 'country': 'USA', 'zip_code': '55044-5076'},
    {'code': 'MSP7', 'address': '10655 County Road 81', 'city': 'Maple Grove', 'state': 'MN', 'country': 'USA', 'zip_code': '55369-4016'},
    {'code': 'MSP9', 'address': '9001 Wyoming Ave. North', 'city': 'Brooklyn Park', 'state': 'MN', 'country': 'USA', 'zip_code': '55445'},
    {'code': 'MSPS', 'address': '5825 11TH AVENUE EAST', 'city': 'SHAKOPEE', 'state': 'MN', 'country': 'USA', 'zip_code': '55379-3810'},
    {'code': 'MTN1', 'address': '1025 BOXWOOD RD', 'city': 'WILMINGTON', 'state': 'DE', 'country': 'USA', 'zip_code': '19804'},
    {'code': 'MTN2', 'address': '913 OLD PHILADELPHIA RD', 'city': 'ABERDEEN', 'state': 'MD', 'country': 'USA', 'zip_code': '21001'},
    {'code': 'MTN3', 'address': '1701 Finishing Mill Road', 'city': 'SPARROWSPOINT', 'state': 'MD', 'country': 'USA', 'zip_code': '21219'},
    {'code': 'MTN5', 'address': '5300 HOLABIRD AVE.', 'city': 'BALTIMORE', 'state': 'MD', 'country': 'USA', 'zip_code': '21224'},
    {'code': 'MTN6', 'address': '1701 Finishing Mills rd', 'city': 'Sparrows Point', 'state': 'MD', 'country': 'USA', 'zip_code': '21219-1057'},
    {'code': 'MTN7', 'address': '913 OLD PHILADELPHIA RD', 'city': 'ABERDEEN', 'state': 'MD', 'country': 'USA', 'zip_code': '21001'},
    {'code': 'MTN8', 'address': '811 Wesel Blvd', 'city': 'Hagerstown', 'state': 'MD', 'country': 'USA', 'zip_code': '21740-8124'},
    {'code': 'MTN9', 'address': '5300 NOTTINGHAM DRIVE', 'city': 'WHITE MARSH', 'state': 'MD', 'country': 'USA', 'zip_code': '21236'},
    {'code': 'MTY1', 'address': 'Ciudad Apodaca', 'city': 'Nuevo Leon', 'state': 'MX', 'country': 'Mexico', 'zip_code': '0'},
    {'code': 'MUC3', 'address': 'Amazonstrasse 1 / Zeppelinstrasse 2', 'city': 'Graben', 'state': 'Bavaria', 'country': 'Germany', 'zip_code': '86836'},
    {'code': 'MXP5', 'address': 'Amazon Italia Logistica S.r.L, Strada Dogana Po 2 U', 'city': 'Castel San Giovanni', 'state': 'Piacenza', 'country': 'Italy', 'zip_code': '29015'},
    {'code': 'NG02', 'address': '10-6 Asahigaoka', 'city': 'Tajimi-shi', 'state': 'Gifu', 'country': 'Japan', 'zip_code': '507-0071'},
    {'code': 'NGO2', 'address': '10-chome Gifu Prefecture Tajimi Asahigaoka', 'city': 'Gifu Prefecture Tajimi Asahigaoka', 'state': '', 'country': 'Japan', 'zip_code': ''},
    {'code': 'NNG1', 'address': 'Beibu Gulf Technopark', 'city': 'Nanning', 'state': 'Guangxi', 'country': 'China', 'zip_code': ''},
    {'code': 'NRT1', 'address': 'Amazon Ichikawa FC, 2-13-1 Shiohama', 'city': 'Ichikawa-shi', 'state': 'Chiba', 'country': 'Japan', 'zip_code': '272-0127'},
    {'code': 'NRT2', 'address': '2036 Kamikoya', 'city': 'Yachiyo-shi', 'state': 'Chiba', 'country': 'Japan', 'zip_code': '276-0022'},
    {'code': 'NRT5', 'address': '1-10-15 Minamidai', 'city': 'Kawagoe-shi', 'state': 'Saitama', 'country': 'Japan', 'zip_code': '350-1165'},
    {'code': 'OAK3', 'address': '255 Park Center Dr', 'city': 'Patterson', 'state': 'CA', 'country': 'USA', 'zip_code': '95363-8876'},
    {'code': 'OAK4', 'address': '1555 N Chrisman Rd', 'city': 'Tracy', 'state': 'CA', 'country': 'USA', 'zip_code': '95304-9370'},
    {'code': 'OAK5', 'address': '38811 Cherry St', 'city': 'Newark', 'state': 'CA', 'country': 'USA', 'zip_code': '94560-4939'},
    {'code': 'OAK6', 'address': '1350 N. MacArthur Drive', 'city': 'Tracy', 'state': 'CA', 'country': 'USA', 'zip_code': '95304-9370'},
    {'code': 'OAK7', 'address': '38811 Cherry St', 'city': 'Newark', 'state': 'CA', 'country': 'USA', 'zip_code': '94560'},
    {'code': 'OAK8', 'address': '1 Middleton Way', 'city': 'American Canyon', 'state': 'CA', 'country': 'USA', 'zip_code': '94503'},
    {'code': 'OAK9', 'address': '6250 PROMONTORY PKWY', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95377'},
    {'code': 'OGD1', 'address': '770S GLADIOLA ST', 'city': 'SALT LAKE CITY', 'state': 'UT', 'country': 'USA', 'zip_code': '84104'},
    {'code': 'OKC1', 'address': '9201 S. Portland Ave.', 'city': 'OKLAHOMA CITY', 'state': 'OK', 'country': 'USA', 'zip_code': '73159'},
    {'code': 'OKC2', 'address': '8991 S PORTLAND AVE', 'city': 'OKLAHOMA CITY', 'state': 'OK', 'country': 'USA', 'zip_code': '73159'},
    {'code': 'OKC5', 'address': '1414 S. COUNCIL RD.', 'city': 'OKLAHOMA CITY', 'state': 'OK', 'country': 'USA', 'zip_code': '73128'},
    {'code': 'OKC9', 'address': '1155 Babbitt Rd.', 'city': 'Euclid', 'state': 'OH', 'country': 'USA', 'zip_code': '44132'},
    {'code': 'OLM1', 'address': '3300 HOGUM BAY ROAD NE', 'city': 'LACEY', 'state': 'WA', 'country': 'USA', 'zip_code': '98516'},
    {'code': 'OMA2', 'address': '10809 S 144 St', 'city': 'Omaha', 'state': 'NE', 'country': 'USA', 'zip_code': '68138-3849'},
    {'code': 'ONT1', 'address': '11200 Iberia St', 'city': 'Jurupa Valley', 'state': 'CA', 'country': 'USA', 'zip_code': '91752-3265'},
    {'code': 'ONT2', 'address': '1910 E CENTRAL AVE', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'ONT3', 'address': '1910 E. Central Ave.', 'city': 'San Bernadino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'ONT4', 'address': '1910 E Central Ave', 'city': 'San Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408-0123'},
    {'code': 'ONT5', 'address': '2020 E. Central Ave. Bldg. 4', 'city': 'San Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'ONT6', 'address': '24208 San Michelle Rd', 'city': 'Moreno Valley', 'state': 'CA', 'country': 'USA', 'zip_code': '92551-9561'},
    {'code': 'ONT7', 'address': '8601 MERRILL AVE', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91710'},
    {'code': 'ONT8', 'address': '24300 NANDINA AVENUE', 'city': 'MORENO VALLEY', 'state': 'CA', 'country': 'USA', 'zip_code': '92553'},
    {'code': 'ONT9', 'address': '2125 W San Bernardino Ave', 'city': 'Redlands', 'state': 'CA', 'country': 'USA', 'zip_code': '92374-5005'},
    {'code': 'ORD2', 'address': '23714 W. AMOCO RD', 'city': 'CHANNAHON', 'state': 'IL', 'country': 'USA', 'zip_code': '60410'},
    {'code': 'ORD3', 'address': '24101 S Frontage Rd W', 'city': 'CHANNAHON', 'state': 'IL', 'country': 'USA', 'zip_code': '60410'},
    {'code': 'ORD4', 'address': '25810 S. Ridgeland Ave.', 'city': 'Monee', 'state': 'IL', 'country': 'USA', 'zip_code': '60449'},
    {'code': 'ORD5', 'address': '7001 VOLLMER RD', 'city': 'MATTESON', 'state': 'IL', 'country': 'USA', 'zip_code': '60443'},
    {'code': 'ORD6', 'address': '1250 N. MITTEL BLVD', 'city': 'WOOD DALE', 'state': 'IL', 'country': 'USA', 'zip_code': '60191'},
    {'code': 'ORF1', 'address': '3516 South Military Hwy., Norfolk 3PL Import Crossdock', 'city': 'Chesapeake', 'state': 'VA', 'country': 'USA', 'zip_code': '23323'},
    {'code': 'ORF2', 'address': '5045 PORTSMOUTH BLVD', 'city': 'CHESAPEAKE', 'state': 'VA', 'country': 'USA', 'zip_code': '23321'},
    {'code': 'ORF3', 'address': '2020 NORTHGATE COMMERCE PKWY', 'city': 'SUFFOLK', 'state': 'VA', 'country': 'USA', 'zip_code': '23435'},
    {'code': 'ORY1', 'address': 'Pole 45 1401 Rue Champ Rouge', 'city': 'Saran', 'state': 'Loiret', 'country': 'France', 'zip_code': '45770'},
    {'code': 'OSU1', 'address': '2114 N. High Street', 'city': 'Columbus', 'state': 'OH', 'country': 'USA', 'zip_code': '43201'},
    {'code': 'OWD5', 'address': '330 BARTLETT ST', 'city': 'NORTHBOROUGH', 'state': 'MA', 'country': 'USA', 'zip_code': '1532'},
    {'code': 'OWD9', 'address': '350 BARTLETT ST', 'city': 'NORTHBOROUGH', 'state': 'MA', 'country': 'USA', 'zip_code': '1532'},
    {'code': 'OXR1', 'address': '3100 Sakioka Dr', 'city': 'Oxnard', 'state': 'CA', 'country': 'USA', 'zip_code': '93030'},
    {'code': 'P0Z1', 'address': 'ul. Jezynowa. 62-080', 'city': 'Sady', 'state': 'Poznan', 'country': 'Poland', 'zip_code': ''},
    {'code': 'PAE2', 'address': '4620 172ND ST NE', 'city': 'ARLINGTON', 'state': 'WA', 'country': 'USA', 'zip_code': '98223'},
    {'code': 'PAE3', 'address': '6611 ASSOCIATED BLVD', 'city': 'EVERETT', 'state': 'WA', 'country': 'USA', 'zip_code': '98203'},
    {'code': 'PBI2', 'address': '14490 CORPORATE ROAD NORTH', 'city': 'JUPITER', 'state': 'FL', 'country': 'USA', 'zip_code': '33478'},
    {'code': 'PCA1', 'address': '1565 N MacArthur Drive', 'city': 'Tracy', 'state': 'CA', 'country': 'USA', 'zip_code': '95376-2846'},
    {'code': 'PCA2', 'address': '4502 Patterson Ave', 'city': 'Perris', 'state': 'CA', 'country': 'USA', 'zip_code': '92571-9722'},
    {'code': 'PCA3', 'address': '10681 PRODUCTION AVE', 'city': 'FONTANA', 'state': 'CA', 'country': 'USA', 'zip_code': '92337'},
    {'code': 'PCW1', 'address': '27400 CROSSROADS PKWY', 'city': 'ROSSFORD', 'state': 'OH', 'country': 'USA', 'zip_code': '43460'},
    {'code': 'PDK2', 'address': '4905 Derrick Rd', 'city': 'ATLANTA', 'state': 'GA', 'country': 'USA', 'zip_code': '30349'},
    {'code': 'PDX5', 'address': '5647 NW HUFFMAN ST.', 'city': 'HILLSBORO', 'state': 'OR', 'country': 'USA', 'zip_code': '97124-5848'},
    {'code': 'PDX6', 'address': '15000 N Lombard St', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '97203-6814'},
    {'code': 'PDX7', 'address': '4775 Depot Ct SE', 'city': 'Salem', 'state': 'OR', 'country': 'USA', 'zip_code': '97317-8983'},
    {'code': 'PDX9', 'address': '1250 NW SWIGERT WAY', 'city': 'TROUTDALE', 'state': 'OR', 'country': 'USA', 'zip_code': '97060-9614'},
    {'code': 'PEK3', 'address': 'Yizhuang. Daxing. Beijing', 'city': 'Yizhuang. Daxing', 'state': 'Beijing', 'country': 'China', 'zip_code': ''},
    {'code': 'PEK5', 'address': 'Tongzhou. Beijing', 'city': 'Tongzhou', 'state': 'Beijing', 'country': 'China', 'zip_code': ''},
    {'code': 'PEN1', 'address': '3800 Locust Walk, Class of 1920 Commons', 'city': 'Philadelphia', 'state': 'PA', 'country': 'USA', 'zip_code': '19104'},
    {'code': 'PFL1', 'address': '1001 13th Avenue East', 'city': 'Bradenton', 'state': 'FL', 'country': 'USA', 'zip_code': '34208-2656'},
    {'code': 'PFL2', 'address': '8060 State Rd 33 North', 'city': 'Lakeland', 'state': 'FL', 'country': 'USA', 'zip_code': '33809-1704'},
    {'code': 'PFL3', 'address': '8054 STATE ROAD 33 N', 'city': 'LAKELAND', 'state': 'FL', 'country': 'USA', 'zip_code': '33809'},
    {'code': 'PGA1', 'address': '429 Toy Wright Rd', 'city': 'Pendergrass', 'state': 'GA', 'country': 'USA', 'zip_code': '30567'},
    {'code': 'PHL1', 'address': '1 Centerpoint Blvd', 'city': 'New Castle', 'state': 'DE', 'country': 'USA', 'zip_code': '19720-4172'},
    {'code': 'PHL3', 'address': '1600 Johnson W ay, Attn: Receiving', 'city': 'New Castle', 'state': 'DE', 'country': 'USA', 'zip_code': '19720-8111'},
    {'code': 'PHL4', 'address': '21 ROADWAY DR.', 'city': 'CARLISLE', 'state': 'PA', 'country': 'USA', 'zip_code': '17015-8806'},
    {'code': 'PHL5', 'address': '500 MCCARTHY DR', 'city': 'LEWISBERRY', 'state': 'PA', 'country': 'USA', 'zip_code': '17339-8725'},
    {'code': 'PHL6', 'address': '675 Allen Rd', 'city': 'Carlisle', 'state': 'PA', 'country': 'USA', 'zip_code': '17015-7788'},
    {'code': 'PHL7', 'address': '560 MERRIMAC AVE', 'city': 'MIDDLETOWN', 'state': 'DE', 'country': 'USA', 'zip_code': '19709-4652'},
    {'code': 'PHL8', 'address': '727 N. Broad Street', 'city': 'Middletown', 'state': 'DE', 'country': 'USA', 'zip_code': '19709'},
    {'code': 'PHL9', 'address': '2 Ames Drive', 'city': 'Carlisle', 'state': 'PA', 'country': 'USA', 'zip_code': '17015'},
    {'code': 'PHX3', 'address': '6835 W BUCKEYE RD', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043-4428'},
    {'code': 'PHX5', 'address': '16920 W. COMMERCE DR.', 'city': 'GOODYEAR', 'state': 'AZ', 'country': 'USA', 'zip_code': '85338-3620'},
    {'code': 'PHX6', 'address': '4750 W MOHAVE ST', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043-8305'},
    {'code': 'PHX7', 'address': '800 NORTH 75TH AVE.', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'PHX8', 'address': '800 N 75th Ave', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'PHX9', 'address': '777 S 79th Ave', 'city': 'Tolleson', 'state': 'AZ', 'country': 'USA', 'zip_code': '85353-3140'},
    {'code': 'PICV', 'address': '1155 Worldwide Blvd', 'city': 'Hebron', 'state': 'KY', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'PIL1', 'address': '1615 Commerce Pkwy N Building B', 'city': 'Horn Lake', 'state': 'MS', 'country': 'USA', 'zip_code': '38637-2313'},
    {'code': 'PIN1', 'address': '10 Patton Dr', 'city': '5510 Exploration Dr', 'state': 'IN', 'country': 'USA', 'zip_code': '46241-9007'},
    {'code': 'PIN2', 'address': '3620 PLAINSFIELD RD', 'city': 'INDIANAPOLIS', 'state': 'IN', 'country': 'USA', 'zip_code': '46231'},
    {'code': 'PISA', 'address': '900 Patrol Rd', 'city': 'Jeffersonville', 'state': 'IN', 'country': 'USA', 'zip_code': '47130-7716'},
    {'code': 'PISB', 'address': '376 Zappos.com Blvd', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165'},
    {'code': 'PISC', 'address': '271 Omega Parkway', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165'},
    {'code': 'PIT2', 'address': '101 N Campus Dr', 'city': 'Imperial', 'state': 'PA', 'country': 'USA', 'zip_code': '15125-2402'},
    {'code': 'PIT5', 'address': '2250 Roswell Dr', 'city': 'Pittsburgh', 'state': 'PA', 'country': 'USA', 'zip_code': '15205-1800'},
    {'code': 'PIT9', 'address': '3400 POTATO GARDEN RUN RD', 'city': 'IMPERIAL', 'state': 'PA', 'country': 'USA', 'zip_code': '15126'},
    {'code': 'PKC1', 'address': '30901 W 185th St', 'city': 'EDGERTON', 'state': 'KS', 'country': 'USA', 'zip_code': '66021'},
    {'code': 'PMD1', 'address': 'COLUMBIA AVE', 'city': 'PALMDALE', 'state': 'CA', 'country': 'USA', 'zip_code': '98550'},
    {'code': 'PNE1', 'address': '2455 BOULEVARD OF THE GENERALS', 'city': 'NORRISTOWN', 'state': 'PA', 'country': 'USA', 'zip_code': '19403'},
    {'code': 'PNE2', 'address': '18 Applegate Dr.', 'city': 'Robbinsville', 'state': 'NJ', 'country': 'USA', 'zip_code': '08691-2342'},
    {'code': 'PNE5', 'address': '18 APPLEGATE DR.', 'city': 'ROBBINSVILLE', 'state': 'NJ', 'country': 'USA', 'zip_code': '8691'},
    {'code': 'POD1', 'address': '560 Merrimac Avenue', 'city': 'MIDDLETOWN', 'state': 'DE', 'country': 'USA', 'zip_code': '19709'},
    {'code': 'POD4', 'address': '14601 Grant Street', 'city': 'THORNTON', 'state': 'CO', 'country': 'USA', 'zip_code': '80023'},
    {'code': 'POH1', 'address': '1901 Beggrow St', 'city': 'Lockbourne', 'state': 'OH', 'country': 'USA', 'zip_code': '43137-7566'},
    {'code': 'POH2', 'address': '1901 Beggrow St', 'city': 'Lockbourne', 'state': 'OH', 'country': 'USA', 'zip_code': '43137-7566'},
    {'code': 'POR1', 'address': '1131 SW Jefferson', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '97201'},
    {'code': 'POZ1', 'address': 'Near Sady by Expressway S11 and the A2 Motorway', 'city': 'Pozna', 'state': '', 'country': 'Poland', 'zip_code': ''},
    {'code': 'PPA1', 'address': '545 Oak Hill Road', 'city': 'Mountaintop', 'state': 'PA', 'country': 'USA', 'zip_code': '18707-2141'},
    {'code': 'PPA2', 'address': '1057 HANOVER ST', 'city': 'HANOVERTOWNS HIP', 'state': 'PA', 'country': 'USA', 'zip_code': '18706'},
    {'code': 'PPH3', 'address': '2306 South Street', 'city': 'PHILADELPHIA', 'state': 'PA', 'country': 'USA', 'zip_code': '19146-1122'},
    {'code': 'PPX2', 'address': '3809 E. WATKINS ST', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85034'},
    {'code': 'PRG1', 'address': 'Amazon Logistic Prague s.r.o. U Trati 216', 'city': 'Dobrovfz', 'state': '', 'country': 'Czech Republic', 'zip_code': '25261'},
    {'code': 'PRG2', 'address': 'K Amazonu 256', 'city': 'Dobrovfz', 'state': '', 'country': 'Czech Republic', 'zip_code': '25261'},
    {'code': 'PRTO', 'address': '6110 Cantay Rd., c/o Assured Logistics, Inc', 'city': 'Mississauga', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L5R 3W'},
    {'code': 'PSP1', 'address': '1010 W. Fourth St.', 'city': 'BEAUMONT', 'state': 'CA', 'country': 'USA', 'zip_code': '92223'},
    {'code': 'PTX1', 'address': '2101 Danieldale Road', 'city': 'Lancaster', 'state': 'TX', 'country': 'USA', 'zip_code': '75134-1551'},
    {'code': 'PUR1', 'address': '1198 Third Street, Krach Leadership Center Room 169', 'city': 'West Lafayette', 'state': 'IN', 'country': 'USA', 'zip_code': '47907'},
    {'code': 'PWA1', 'address': '2309 Milwaukee Way', 'city': 'Tacoma', 'state': 'WA', 'country': 'USA', 'zip_code': '98421-2709'},
    {'code': 'QAE1', 'address': '2121 7th Ave.', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98121'},
    {'code': 'R1C1', 'address': '5000 COMMERCE WAY', 'city': 'PETERSBURG', 'state': 'VA', 'country': 'USA', 'zip_code': '23803-6917'},
    {'code': 'RAC2', 'address': '3940 S. Lakeside Dr.', 'city': 'WAUKEGAN', 'state': 'IL', 'country': 'USA', 'zip_code': '60085'},
    {'code': 'RAD1', 'address': '3818 Logistics Way', 'city': 'Antioch', 'state': 'TN', 'country': 'USA', 'zip_code': '37013'},
    {'code': 'RBD5', 'address': '3500 S. AIRFIELD DR', 'city': 'IRVING', 'state': 'TX', 'country': 'USA', 'zip_code': '75261'},
    {'code': 'RCLJ', 'address': '3540 BIRTCHER DR', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89119'},
    {'code': 'RDG1', 'address': '3563 Mountin Rd', 'city': 'Hamburg', 'state': 'PA', 'country': 'USA', 'zip_code': '19526-7947'},
    {'code': 'RDG2', 'address': '270 MIDWAY RD', 'city': 'BETHEL', 'state': 'PA', 'country': 'USA', 'zip_code': '19507'},
    {'code': 'RDU1', 'address': '4851 JONES SAUSAGE ROAD', 'city': 'GARNER', 'state': 'NC', 'country': 'USA', 'zip_code': '27529'},
    {'code': 'RDU2', 'address': '2095 West Market Street', 'city': 'SMITHFIELD', 'state': 'NC', 'country': 'USA', 'zip_code': '27577'},
    {'code': 'RDU5', 'address': '1805 TW ALEXANDER DRIVE', 'city': 'DURHAM', 'state': 'NC', 'country': 'USA', 'zip_code': '27703-8389'},
    {'code': 'RDU9', 'address': '13875 Senator Ralph Scott Prkwy', 'city': 'Mebane', 'state': 'NC', 'country': 'USA', 'zip_code': '27302'},
    {'code': 'RELO', 'address': '201 Spear St', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94105-1630'},
    {'code': 'RFD1', 'address': '4650 SHEPARD TRAIL, SUITE A', 'city': 'ROCKFORD', 'state': 'IL', 'country': 'USA', 'zip_code': '61103'},
    {'code': 'RFD2', 'address': '41W368 Freeman Road', 'city': 'HUNTLEY', 'state': 'IL', 'country': 'USA', 'zip_code': '60142'},
    {'code': 'RGA1', 'address': '4600 OLYMPIC BLVD', 'city': 'ERLANGER', 'state': 'KY', 'country': 'USA', 'zip_code': '41018'},
    {'code': 'RHA1', 'address': '635 Elliott Ave W', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98119'},
    {'code': 'RIC1', 'address': '5000 Commerce Way', 'city': 'Petersburg', 'state': 'VA', 'country': 'USA', 'zip_code': '23803-6917'},
    {'code': 'RIC2', 'address': '1901 MEADOWVILLE TECHNOLOGY PKWY', 'city': 'CHESTER', 'state': 'VA', 'country': 'USA', 'zip_code': '23836-2841'},
    {'code': 'RIC3', 'address': '4949 Commerce Rd.', 'city': 'Richmond', 'state': 'VA', 'country': 'USA', 'zip_code': '23234'},
    {'code': 'RIC4', 'address': '5901 RICHMOND HENRICO TPKE', 'city': 'RICHMOND', 'state': 'VA', 'country': 'USA', 'zip_code': '23227'},
    {'code': 'RIC5', 'address': '11600 N. LAKERIDGE PARKWAY', 'city': 'ASHLAND', 'state': 'VA', 'country': 'USA', 'zip_code': '23005'},
    {'code': 'RIC9', 'address': '11600 N Lakeridge Pkwy', 'city': 'Ashland', 'state': 'VA', 'country': 'USA', 'zip_code': '23005'},
    {'code': 'RIM2', 'address': '777 Freeport Pkwy.', 'city': 'COPPELL', 'state': 'TX', 'country': 'USA', 'zip_code': '75019'},
    {'code': 'RIM3', 'address': '4545 Spring Valley Rd.', 'city': 'DALLAS', 'state': 'TX', 'country': 'USA', 'zip_code': '75224'},
    {'code': 'RJY1', 'address': '3301 Wayne Trace', 'city': 'FORT WAYNE', 'state': 'IN', 'country': 'USA', 'zip_code': '46806'},
    {'code': 'RJY2', 'address': '1450 Atlantic Ave', 'city': 'ROCKY MOUNT', 'state': 'NC', 'country': 'USA', 'zip_code': '27801'},
    {'code': 'RJY3', 'address': '1 General Way', 'city': 'MAYFIELD', 'state': 'KY', 'country': 'USA', 'zip_code': '42066'},
    {'code': 'RJY4', 'address': '4501 Mitchell St.', 'city': 'NORTH LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89081'},
    {'code': 'RNM9', 'address': '1075 Aviation Blvd', 'city': 'HEBRON', 'state': 'KY', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'RNO1', 'address': '1600 E NEWLANDS DR', 'city': 'FERNLEY', 'state': 'NV', 'country': 'USA', 'zip_code': '89408-8903'},
    {'code': 'RNO2', 'address': '8000 North Virginia Street Reno', 'city': 'Reno', 'state': 'NV', 'country': 'USA', 'zip_code': '85906'},
    {'code': 'RNO3', 'address': '555 MILAN DRIVE', 'city': 'SPARKS', 'state': 'NV', 'country': 'USA', 'zip_code': '89434-5606'},
    {'code': 'RNO4', 'address': '8000 N Virginia St', 'city': 'Reno', 'state': 'NV', 'country': 'USA', 'zip_code': '89506'},
    {'code': 'RNT9', 'address': '7449 45th St CTE', 'city': 'Fife', 'state': 'WA', 'country': 'USA', 'zip_code': '98424-3775'},
    {'code': 'ROC1', 'address': '2600 MANITOU RD', 'city': 'ROCHESTER', 'state': 'NY', 'country': 'USA', 'zip_code': '14653'},
    {'code': 'RPNC', 'address': '165 One Genesis Way', 'city': 'SPRUCE PINE', 'state': 'NC', 'country': 'USA', 'zip_code': '28777'},
    {'code': 'RPNV', 'address': '4950 Joule St.', 'city': 'RENO', 'state': 'NV', 'country': 'USA', 'zip_code': '89502'},
    {'code': 'RRPR', 'address': '1910 International Way', 'city': 'HEBRON', 'state': 'KT', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'RSC1', 'address': '1651 California St', 'city': 'Redlands', 'state': 'CA', 'country': 'USA', 'zip_code': '92374'},
    {'code': 'RSW5', 'address': '16581 Domestic Ave', 'city': 'Fort Myers', 'state': 'FL', 'country': 'USA', 'zip_code': '33912'},
    {'code': 'RTPX', 'address': '2700 Story Road West', 'city': 'IRVING', 'state': 'TX', 'country': 'USA', 'zip_code': '75038'},
    {'code': 'SAC5', 'address': '8040 METRO AIR PKWY', 'city': 'SACRAMENTO', 'state': 'CA', 'country': 'USA', 'zip_code': '95836'},
    {'code': 'SAMA', 'address': 'Ahmadabad. Gujarat', 'city': 'Ahmadabad', 'state': 'Gujarat', 'country': 'India', 'zip_code': ''},
    {'code': 'SAN3', 'address': '6971 OTAY MESA RD', 'city': 'SAN DIEGO', 'state': 'CA', 'country': 'USA', 'zip_code': '92154'},
    {'code': 'SAT1', 'address': '6000 Enterprise Ave', 'city': 'Schertz', 'state': 'TX', 'country': 'USA', 'zip_code': '78154-1461'},
    {'code': 'SAT2', 'address': '1401 E McCarty Ln', 'city': 'San Marcos', 'state': 'TX', 'country': 'USA', 'zip_code': '78666-8969'},
    {'code': 'SAT3', 'address': '6806 CAL TURNER DR', 'city': 'SAN ANTONIO', 'state': 'TX', 'country': 'USA', 'zip_code': '78220'},
    {'code': 'SAT4', 'address': '10390 US 90 E', 'city': 'San Antonio', 'state': 'TX', 'country': 'USA', 'zip_code': '78245'},
    {'code': 'SAT5', 'address': '1410 SOUTH CALLAGHAN RD', 'city': 'SAN ANTONIO', 'state': 'TX', 'country': 'USA', 'zip_code': '78227-2204'},
    {'code': 'SAT6', 'address': '1346 FORTUNA RD', 'city': 'SAN MARCOS', 'state': 'TX', 'country': 'USA', 'zip_code': '78666'},
    {'code': 'SAT9', 'address': '1214 N FOSTER RD', 'city': 'SAN ANTONIO', 'state': 'TX', 'country': 'USA', 'zip_code': '78220'},
    {'code': 'SAV1', 'address': 'Georgia Ports Authority, Garden City Terminal, Building CFS #2', 'city': 'Garden City', 'state': 'GA', 'country': 'USA', 'zip_code': '31408'},
    {'code': 'SAV3', 'address': '7001 Skipper Rd', 'city': 'Macon', 'state': 'GA', 'country': 'USA', 'zip_code': '31216-6427'},
    {'code': 'SAV4', 'address': '800 PINE MEADOW DR', 'city': 'POOLER', 'state': 'GA', 'country': 'USA', 'zip_code': '31322'},
    {'code': 'SAX1', 'address': '4041 PECK RD', 'city': 'EL MONTE', 'state': 'CA', 'country': 'USA', 'zip_code': '91732-2246'},
    {'code': 'SAX2', 'address': '2246 S GRAND AVE', 'city': 'SANTA ANA', 'state': 'CA', 'country': 'USA', 'zip_code': '92705-5210'},
    {'code': 'SAX3', 'address': '1245 N SPRING ST', 'city': 'LOS ANGELES', 'state': 'CA', 'country': 'USA', 'zip_code': '90012'},
    {'code': 'SAX4', 'address': '5239 N FIGUEROA ST', 'city': 'LOS ANGELES', 'state': 'CA', 'country': 'USA', 'zip_code': '90042'},
    {'code': 'SAX5', 'address': '725 CROCKER ST', 'city': 'LOS ANGELES', 'state': 'CA', 'country': 'USA', 'zip_code': '90021'},
    {'code': 'SAZ1', 'address': '3333 S. 7th St.', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85040'},
    {'code': 'SBD1', 'address': '3388 S Cactus Ave', 'city': 'Bloomington', 'state': 'CA', 'country': 'USA', 'zip_code': '92316-3819'},
    {'code': 'SBD2', 'address': '1494 S Waterman Ave', 'city': 'SAn Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '94208-2805'},
    {'code': 'SBD3', 'address': '5990 N. CAJON BLVD', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92407'},
    {'code': 'SBD5', 'address': '11100 IBERIA ST', 'city': 'JURUPA VALLEY', 'state': 'CA', 'country': 'USA', 'zip_code': '91752'},
    {'code': 'SBD6', 'address': 'EUCALYPTUS AVE', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'SBOA', 'address': 'Mumbai. Maharashtra', 'city': 'Mumbai', 'state': 'Maharashtra', 'country': 'India', 'zip_code': ''},
    {'code': 'SBPX', 'address': '', 'city': 'Somerset', 'state': 'NJ', 'country': 'USA', 'zip_code': '8873'},
    {'code': 'SBU1', 'address': '100 Nicolas Road, Frank Melville Jr. Library, Room E0319', 'city': 'Stony Brook', 'state': 'NY', 'country': 'USA', 'zip_code': '11794'},
    {'code': 'SBX2', 'address': '4718 Helgesen Drive, Suite 1', 'city': 'Madison', 'state': 'WI', 'country': 'USA', 'zip_code': '53718-6740'},
    {'code': 'SCA2', 'address': '12453 SAN PABLO AVE', 'city': 'RICHMOND', 'state': 'CA', 'country': 'USA', 'zip_code': '94805-1954'},
    {'code': 'SCA3', 'address': '10 N MAIN ST', 'city': 'MILPITAS', 'state': 'CA', 'country': 'USA', 'zip_code': '95035-4342'},
    {'code': 'SCA4', 'address': '16915 Via Del Campo', 'city': 'San Diego', 'state': 'CA', 'country': 'USA', 'zip_code': '92127'},
    {'code': 'SCA5', 'address': '1120 EXPOSITION BLVD', 'city': 'SACRAMENTO', 'state': 'CA', 'country': 'USA', 'zip_code': '95815-4328'},
    {'code': 'SCA6', 'address': '3096 MCCLINTOCK AVE', 'city': 'LOS ANGELES', 'state': 'CA', 'country': 'USA', 'zip_code': '90089-3504'},
    {'code': 'SCE1', 'address': '134 South Allen St', 'city': 'State College', 'state': 'PA', 'country': 'USA', 'zip_code': '16801'},
    {'code': 'SCK1', 'address': '4611 Newcastle Rd', 'city': 'Stockton', 'state': 'CA', 'country': 'USA', 'zip_code': '95215-9446'},
    {'code': 'SCK3', 'address': '3565 N Airport Way', 'city': 'Maneca', 'state': 'CA', 'country': 'USA', 'zip_code': '95336-8696'},
    {'code': 'SCK4', 'address': '6001 S. AUSTIN RD', 'city': 'STOCKTON', 'state': 'CA', 'country': 'USA', 'zip_code': '95215'},
    {'code': 'SCK6', 'address': 'Grant Line Road, N Chrisman Road', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95304'},
    {'code': 'SCK9', 'address': '4601 NEWCASTLE RD', 'city': 'STOCKTON', 'state': 'CA', 'country': 'USA', 'zip_code': '95215'},
    {'code': 'SCO1', 'address': '6050 Washington St', 'city': 'Denver', 'state': 'CO', 'country': 'USA', 'zip_code': '80216-1285'},
    {'code': 'SDC1', 'address': '6885 Commercial Dr.', 'city': 'Springfield', 'state': 'VA', 'country': 'USA', 'zip_code': '22151'},
    {'code': 'SDC2', 'address': '2 UNIVERSITY BLVD W', 'city': 'SILVER SPRING', 'state': 'MD', 'country': 'USA', 'zip_code': '20901-2438'},
    {'code': 'SDEA', 'address': 'A-43, Ground Floor, Mohan Cooperative Industrial Estate, Main Mathura Ro', 'city': 'Badarpur, South Delhi', 'state': 'Delhii', 'country': 'India', 'zip_code': ''},
    {'code': 'SDF1', 'address': '1048 S COLUMBIA AVE', 'city': 'CAMPBELLSVILLE', 'state': 'KY', 'country': 'USA', 'zip_code': '42718'},
    {'code': 'SDF2', 'address': '4360 Robards Ln, Attn: Receiving', 'city': 'Louisville', 'state': 'KY', 'country': 'USA', 'zip_code': '40218-4512'},
    {'code': 'SDF4', 'address': '376 Zappos.com Blvd', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165'},
    {'code': 'SDF6', 'address': '271 Omega Pkwy', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165-8505'},
    {'code': 'SDF7', 'address': '300 Omicron Court', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165'},
    {'code': 'SDF8', 'address': '900 PATROL RD', 'city': 'JEFFERSONVILLE', 'state': 'IN', 'country': 'USA', 'zip_code': '47130-7761'},
    {'code': 'SDF9', 'address': '100 W Thomas P Echols Ln', 'city': 'Shepherdsville', 'state': 'KY', 'country': 'USA', 'zip_code': '40165-7594'},
    {'code': 'SDL2', 'address': '6395 N. Sarival Road', 'city': 'LITCHFIELD PARK', 'state': 'AZ', 'country': 'USA', 'zip_code': '85340'},
    {'code': 'SEA6', 'address': '2646 Rainier Ave. South, Product Imaging Receiving', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98144-5331'},
    {'code': 'SEA8', 'address': '1227 124TH AVE NE', 'city': 'BELLEVUE', 'state': 'WA', 'country': 'USA', 'zip_code': '98005-2111'},
    {'code': 'SFBG', 'address': '', 'city': 'Lakewood', 'state': 'NJ', 'country': 'USA', 'zip_code': '8701'},
    {'code': 'SFL1', 'address': '7469 Kingspointe Pkwy', 'city': 'ORLANDO', 'state': 'FL', 'country': 'USA', 'zip_code': '32819'},
    {'code': 'SFL2', 'address': '7004 E Broadway Ave', 'city': 'Tampa', 'state': 'FL', 'country': 'USA', 'zip_code': '33619-1831'},
    {'code': 'SFL3', 'address': '6901 N Hiatus Rd', 'city': 'Tamarac', 'state': 'FL', 'country': 'USA', 'zip_code': '33321-6433'},
    {'code': 'SFL4', 'address': '6337 Country Road 579', 'city': 'Seffner', 'state': 'FL', 'country': 'USA', 'zip_code': '33584'},
    {'code': 'SFO21', 'address': '26464 Corporate Ave', 'city': 'Hayward', 'state': 'CA', 'country': 'USA', 'zip_code': '94545-3914'},
    {'code': 'SFO3', 'address': '5250 NEWCASTLE RD', 'city': 'STOCKTON', 'state': 'CA', 'country': 'USA', 'zip_code': '95215-8345'},
    {'code': 'SGA1', 'address': '4925 Avalon Ridge Prkwy', 'city': 'Norcross', 'state': 'GA', 'country': 'USA', 'zip_code': '30071-1571'},
    {'code': 'SGA2', 'address': '1707 BLAIRS BRIDGE RD', 'city': 'LITHIA SPRINGS', 'state': 'GA', 'country': 'USA', 'zip_code': '30122'},
    {'code': 'SHA1', 'address': 'GLP Park Suzhou Industrial Park', 'city': 'Suzhou', 'state': 'Jiangsu', 'country': 'China', 'zip_code': ''},
    {'code': 'SHA2', 'address': 'HuaQiao Near Shanghai', 'city': 'Kunshan', 'state': 'Jiangsu', 'country': 'China', 'zip_code': ''},
    {'code': 'SHA3', 'address': 'China (Shanghai) Pilot Free-Trade Zone', 'city': 'Shanghai', 'state': '', 'country': 'China', 'zip_code': ''},
    {'code': 'SHE1', 'address': 'Shenyang. Liaoning', 'city': 'Shenyang', 'state': 'Liaoning', 'country': 'China', 'zip_code': ''},
    {'code': 'SHV1', 'address': '1625 CORPORATE DR', 'city': 'SHREVEPORT', 'state': 'LA', 'country': 'USA', 'zip_code': '71107'},
    {'code': 'SIL1', 'address': '2379 Davey Rd.', 'city': 'Woodridge', 'state': 'IL', 'country': 'USA', 'zip_code': '60517'},
    {'code': 'SIL2', 'address': '7555 LINDER AVE', 'city': 'SKOKIE', 'state': 'IL', 'country': 'USA', 'zip_code': '60077'},
    {'code': 'SIL3', 'address': '27W501 NORTH AVE, SUITE 100', 'city': 'WEST CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60185'},
    {'code': 'SIN9', 'address': '305 Chaney Ave', 'city': 'Greenwood', 'state': 'IN', 'country': 'USA', 'zip_code': '46143-0116'},
    {'code': 'SJAA', 'address': 'Jaipur, Rajasthan', 'city': 'Jaipur', 'state': 'Rajasthan', 'country': 'India', 'zip_code': ''},
    {'code': 'SJC7', 'address': '188 MOUNTAIN HOUSE PKWY', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95377-8906'},
    {'code': 'SJC9', 'address': '1455 valley drive', 'city': 'Brisbane', 'state': 'CA', 'country': 'USA', 'zip_code': '94005'},
    {'code': 'SJWV', 'address': '', 'city': 'Murfreesboro', 'state': 'TN', 'country': 'USA', 'zip_code': '37129'},
    {'code': 'SKPN', 'address': '', 'city': 'Mundelein', 'state': 'IL', 'country': 'USA', 'zip_code': '60060'},
    {'code': 'SKTB', 'address': '', 'city': 'Montgomeryville', 'state': 'PA', 'country': 'USA', 'zip_code': '18936'},
    {'code': 'SLA5', 'address': '5250 Goodman Way', 'city': 'Eastvale', 'state': 'CA', 'country': 'USA', 'zip_code': '91752-5088'},
    {'code': 'SLA6', 'address': '5250 GOODMAN WAY', 'city': 'EASTVALE', 'state': 'CA', 'country': 'USA', 'zip_code': '91752'},
    {'code': 'SLC1', 'address': '777 N. 5600 W', 'city': 'SALT LAKE CITY', 'state': 'UT', 'country': 'USA', 'zip_code': '84116-3707'},
    {'code': 'SLC2', 'address': '6802 W OLD BINGHAM HWY', 'city': 'WEST JORDAN', 'state': 'UT', 'country': 'USA', 'zip_code': '84095'},
    {'code': 'SLC3', 'address': '355 N. JOHN GLENN RD.', 'city': 'SALT LAKE CITY', 'state': 'UT', 'country': 'USA', 'zip_code': '84116'},
    {'code': 'SLC4', 'address': '770 SOUTH GLADIOLA , STE 500', 'city': 'SALT LAKE CITY', 'state': 'UT', 'country': 'USA', 'zip_code': '84104'},
    {'code': 'SLC9', 'address': '308 N 6550 W', 'city': 'Salt Lake City', 'state': 'UT', 'country': 'USA', 'zip_code': '84116-2844'},
    {'code': 'SLT7', 'address': '3931 Lakeview Corporate Dr.', 'city': 'Edwarsville', 'state': 'IL', 'country': 'USA', 'zip_code': '62025'},
    {'code': 'SMA1', 'address': '5 5TH ST', 'city': 'PEABODY', 'state': 'MA', 'country': 'USA', 'zip_code': '01960-4915'},
    {'code': 'SMA2', 'address': '1025 ELM ST', 'city': 'BRIDGEWATER', 'state': 'MA', 'country': 'USA', 'zip_code': '2324'},
    {'code': 'SMAA', 'address': 'Chennai, Tamil Nadu', 'city': 'Chennai', 'state': 'Tamil Nadu', 'country': 'India', 'zip_code': ''},
    {'code': 'SMD1', 'address': '7200 DORSET RUN ROAD', 'city': 'ELKRIDGE', 'state': 'MD', 'country': 'USA', 'zip_code': '21075'},
    {'code': 'SMF1', 'address': '4900 W Elkhorn Blvd', 'city': 'Sacramento', 'state': 'CA', 'country': 'USA', 'zip_code': '95835-9505'},
    {'code': 'SMF2', 'address': '2935 Ramco St.', 'city': 'West Sacramento', 'state': 'CA', 'country': 'USA', 'zip_code': '95691'},
    {'code': 'SMF3', 'address': '1540 Zephyr St', 'city': 'Stockton', 'state': 'CA', 'country': 'USA', 'zip_code': '95206-8201'},
    {'code': 'SMF5', 'address': '300 CROCKER DR', 'city': 'VACAVILLE', 'state': 'CA', 'country': 'USA', 'zip_code': '95688'},
    {'code': 'SMF6', 'address': '4930 Allbaugh Dr', 'city': 'Sacramento', 'state': 'CA', 'country': 'USA', 'zip_code': '95837-9109'},
    {'code': 'SMF7', 'address': '4800 Midway Rd', 'city': 'Vacaville', 'state': 'CA', 'country': 'USA', 'zip_code': '95688'},
    {'code': 'SMF9', 'address': '300 Crocker Dr', 'city': 'Vacaville', 'state': 'CA', 'country': 'USA', 'zip_code': '95688'},
    {'code': 'SMI1', 'address': '1400 E. TEN MILE RD', 'city': 'HAZEK PARK', 'state': 'MI', 'country': 'USA', 'zip_code': '48030'},
    {'code': 'SMN1', 'address': '7500 Setzler Prkwy N', 'city': 'Brooklyn Park', 'state': 'MN', 'country': 'USA', 'zip_code': '55445-1879'},
    {'code': 'SMO2', 'address': '1659 SAUGET BUSINESS BLVD', 'city': 'EAST SAINT LOUIS', 'state': 'IL', 'country': 'USA', 'zip_code': '62206'},
    {'code': 'SMOA', 'address': 'Av. Jesus Reyes Heroles 69, col. San Juan Ixtacala', 'city': 'Tlalnepantla', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '38108'},
    {'code': 'SMSA', 'address': 'San Andres Atoto 21B col. San Esteban', 'city': 'Naucalpan', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '53550'},
    {'code': 'SNA4', 'address': '2496 W WALNUT', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376-3009'},
    {'code': 'SNA6', 'address': '5250 Goodman Way', 'city': 'Eastvale', 'state': 'CA', 'country': 'USA', 'zip_code': '91752-5088'},
    {'code': 'SNA7', 'address': '555 E Orange Show Rd', 'city': 'San Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408-2453'},
    {'code': 'SNA8', 'address': '555 East Orange Show Rd', 'city': 'San Bernadino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'SNA9', 'address': '5250 Goodman Road', 'city': 'Eastvale', 'state': 'CA', 'country': 'USA', 'zip_code': '92880'},
    {'code': 'SNC2', 'address': '10622 BRYTON CORPORATE CENTER DR', 'city': 'HUNTERSVILLE', 'state': 'NC', 'country': 'USA', 'zip_code': '28078'},
    {'code': 'SNC3', 'address': '5 NATIONAL DR', 'city': 'DURHAM', 'state': 'NC', 'country': 'USA', 'zip_code': '27703'},
    {'code': 'SNCT', 'address': '', 'city': 'Paterson', 'state': 'NJ', 'country': 'USA', 'zip_code': '7503'},
    {'code': 'SNJ1', 'address': '5 Dedrick Place', 'city': 'West Caldwell', 'state': 'NJ', 'country': 'USA', 'zip_code': '7006'},
    {'code': 'SNJ2', 'address': '344 Hurffville Crosskeys rd', 'city': 'SEWELL', 'state': 'NJ', 'country': 'USA', 'zip_code': '8080'},
    {'code': 'SNJ3', 'address': '1798 Rte. 130 N', 'city': 'BURLINGTON', 'state': 'NJ', 'country': 'USA', 'zip_code': '8016'},
    {'code': 'SNV1', 'address': '7970 S VALLEY VIEW BLVD STE 130', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89139'},
    {'code': 'SNY1', 'address': '2294 ADAM CLAYTON POWELL JR BLVD', 'city': 'NEW YORK', 'state': 'NY', 'country': 'USA', 'zip_code': '10030'},
    {'code': 'SNY2', 'address': '9210 ATLANTIC AVE', 'city': 'OZONE PARK', 'state': 'NY', 'country': 'USA', 'zip_code': '11416'},
    {'code': 'SNY3', 'address': '153 NOTCH RD', 'city': 'CLIFTON', 'state': 'NJ', 'country': 'USA', 'zip_code': '7013'},
    {'code': 'SNY4', 'address': '274 36TH ST', 'city': 'BROOKLYN', 'state': 'NY', 'country': 'USA', 'zip_code': '11232'},
    {'code': 'SNY5', 'address': '4-09 47TH RD', 'city': 'LONG ISLAND CITY', 'state': 'NY', 'country': 'USA', 'zip_code': '10007'},
    {'code': 'SOH1', 'address': '6895 ENGLE RD', 'city': 'CLEVELAND', 'state': 'OH', 'country': 'USA', 'zip_code': '44130'},
    {'code': 'SOH2', 'address': '1120 STRATEGIC PARKWAY, BLDG 2', 'city': 'SPRINGFIELD', 'state': 'OH', 'country': 'USA', 'zip_code': '45246'},
    {'code': 'SOH3', 'address': '6322 COLLINGS DR', 'city': 'LOCKBOURNE', 'state': 'OH', 'country': 'USA', 'zip_code': '43137'},
    {'code': 'SOR3', 'address': '701 NE Columbia Blvd', 'city': 'PORTLAND', 'state': 'OR', 'country': 'USA', 'zip_code': '97211'},
    {'code': 'SPA1', 'address': '1300 N BROAD ST', 'city': 'PHILADELPHIA', 'state': 'PA', 'country': 'USA', 'zip_code': '19121'},
    {'code': 'SQGH', 'address': '', 'city': 'Carnation', 'state': 'WA', 'country': 'USA', 'zip_code': '98014'},
    {'code': 'STC2', 'address': '2811 BEVERLY RD STE 200', 'city': 'EAGAN', 'state': 'MN', 'country': 'USA', 'zip_code': '55121'},
    {'code': 'STL3', 'address': '3200 E. SAWYER RD', 'city': 'REPUBLIC', 'state': 'MO', 'country': 'USA', 'zip_code': '65738'},
    {'code': 'STL4', 'address': '3050 GATEWAY COMMERCE CENTER DRIVE S', 'city': 'EDWARDSVILLE', 'state': 'IL', 'country': 'USA', 'zip_code': '62025-2815'},
    {'code': 'STL5', 'address': '462 HAZELWOOD LOGISTICS CENTER DR.', 'city': 'HAZELWOOD', 'state': 'MO', 'country': 'USA', 'zip_code': '63042'},
    {'code': 'STL6', 'address': '3931 Lakeview Corporate Dr', 'city': 'Edwardsville', 'state': 'IL', 'country': 'USA', 'zip_code': '62025-2801'},
    {'code': 'STL7', 'address': '3931 Lakeview Corporate Drive', 'city': 'Edwardsville', 'state': 'IL', 'country': 'USA', 'zip_code': '62025'},
    {'code': 'STL8', 'address': '4000 PREMIER PKWY', 'city': 'SAINT PETERS', 'state': 'MO', 'country': 'USA', 'zip_code': '63376'},
    {'code': 'STL9', 'address': '8850 Springdale Ave', 'city': 'Berkeley', 'state': 'MO', 'country': 'USA', 'zip_code': '63114-2403'},
    {'code': 'STN1', 'address': '2 Dell Pkwy', 'city': 'Nashville', 'state': 'TN', 'country': 'USA', 'zip_code': '37217'},
    {'code': 'STP2', 'address': '10655 COUNTY ROAD 81', 'city': 'MAPLEGROVE', 'state': 'MN', 'country': 'USA', 'zip_code': '55369'},
    {'code': 'STR1', 'address': 'Amazonstrasse 1 / Bauschlotter Strasse', 'city': 'Pforzheim', 'state': 'Baden-Wurttemberg', 'country': 'Germany', 'zip_code': '75177'},
    {'code': 'STX2', 'address': '1625 Hutton Dr.', 'city': 'Carrollton', 'state': 'TX', 'country': 'USA', 'zip_code': '75006'},
    {'code': 'STX3', 'address': '4445 Rock Quarry Rd', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75211-1409'},
    {'code': 'STX4', 'address': '10611 RED BLUFF RD', 'city': 'PASADENA', 'state': 'TX', 'country': 'USA', 'zip_code': '77507'},
    {'code': 'STX5', 'address': '5216 Campbell Rd', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77041'},
    {'code': 'STX6', 'address': '18625 SCHULTZ LN', 'city': 'PFLUGERVILLE', 'state': 'TX', 'country': 'USA', 'zip_code': '78660'},
    {'code': 'STX7', 'address': '2214 CORNER RIDGE', 'city': 'SAN ANTONIO', 'state': 'TX', 'country': 'USA', 'zip_code': '78219'},
    {'code': 'SU2A', 'address': '1201 Aviation Blvd', 'city': 'Hebron', 'state': 'KY', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'SUAA', 'address': '1201 Aviation Blvd', 'city': 'Hebron', 'state': 'KY', 'country': 'USA', 'zip_code': '41048'},
    {'code': 'SUAB', 'address': '2800 CORPORATE EXCHANGE DRIVE', 'city': 'Columbus', 'state': 'OH', 'country': 'USA', 'zip_code': '43231'},
    {'code': 'SUAC', 'address': '100 S Wineville Ave', 'city': 'Ontario', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'SUAD', 'address': '100 Syble Jean Dr.', 'city': 'Burleson', 'state': 'TX', 'country': 'USA', 'zip_code': '76028'},
    {'code': 'SUAG', 'address': '150 Leo Taylor Ln', 'city': 'Ball Ground', 'state': 'GA', 'country': 'USA', 'zip_code': '30107'},
    {'code': 'SUAH', 'address': '2901 Grant Ave', 'city': 'Philadelphia', 'state': 'PA', 'country': 'USA', 'zip_code': '19114'},
    {'code': 'SUAK', 'address': '1170 Centre Drive, SUITE A', 'city': 'Walnut', 'state': 'CA', 'country': 'USA', 'zip_code': '91789'},
    {'code': 'SUAM', 'address': '5400 Ontario Mills Parkway, Unit 400', 'city': 'Ontario', 'state': 'CA', 'country': 'USA', 'zip_code': '91764'},
    {'code': 'SUAP', 'address': '23824 W. Andrew Rd.', 'city': 'Plainfield', 'state': 'IL', 'country': 'USA', 'zip_code': '60585'},
    {'code': 'SUAQ', 'address': '8870 Boggy Creek Rd', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32824'},
    {'code': 'SUAR', 'address': '9207 Eton Avenue Unit B', 'city': 'Chatsworth', 'state': 'CA', 'country': 'USA', 'zip_code': '91311'},
    {'code': 'SUAS', 'address': '2800 Corporate Exchange Drive', 'city': 'Columbus', 'state': 'OH', 'country': 'USA', 'zip_code': '43231'},
    {'code': 'SUAV', 'address': '8870 Boggy Creek Rd', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32824'},
    {'code': 'SUAW', 'address': '8870 Boggy Creek Rd', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32824'},
    {'code': 'SUAX', 'address': '394 COMMERCE BLVD', 'city': 'Athens', 'state': 'GA', 'country': 'USA', 'zip_code': '30606'},
    {'code': 'SUAY', 'address': '10020 S Gibson Rd', 'city': 'Molalla', 'state': 'OR', 'country': 'USA', 'zip_code': '97038'},
    {'code': 'SUAZ', 'address': '1189 McDonald Ave', 'city': 'Brooklyn', 'state': 'NY', 'country': 'USA', 'zip_code': '11230'},
    {'code': 'SUBA', 'address': '2215 Paseo De Las Americas, 30D', 'city': 'San Diego', 'state': 'CA', 'country': 'USA', 'zip_code': '92154'},
    {'code': 'SUBD', 'address': '81 Christopher St', 'city': 'Staten Island', 'state': 'NY', 'country': 'USA', 'zip_code': '10303'},
    {'code': 'SUBE', 'address': '921 E. Tolna Rd.', 'city': 'New Freedom', 'state': 'PA', 'country': 'USA', 'zip_code': '17349'},
    {'code': 'SUBG', 'address': '28651 Cranford Sage Ln', 'city': 'Katy', 'state': 'TX', 'country': 'USA', 'zip_code': '77494'},
    {'code': 'SUBH', 'address': '817 Winchester Rd, Suite 130', 'city': 'Lexington', 'state': 'KY', 'country': 'USA', 'zip_code': '40505'},
    {'code': 'SUBI', 'address': '2213 VISTA PKWY, suite 8', 'city': 'West Palm Beach', 'state': 'FL', 'country': 'USA', 'zip_code': '33411'},
    {'code': 'SUBJ', 'address': '1104 W Geneva Dr', 'city': 'Tempe', 'state': 'AZ', 'country': 'USA', 'zip_code': '85281'},
    {'code': 'SUBL', 'address': '582 S 1100 W', 'city': 'Woods Cross', 'state': 'UT', 'country': 'USA', 'zip_code': '84087'},
    {'code': 'SUBT', 'address': '7070 NW 75th St', 'city': 'Parkland', 'state': 'FL', 'country': 'USA', 'zip_code': '33067'},
    {'code': 'SUBU', 'address': '2213 VISTA PKWY, Suite 8', 'city': 'West Palm Beach', 'state': 'FL', 'country': 'USA', 'zip_code': '33411'},
    {'code': 'SUBV', 'address': '810 E 8th St', 'city': 'Oakland', 'state': 'CA', 'country': 'USA', 'zip_code': '94606'},
    {'code': 'SUBW', 'address': '1104 W Geneva Dr', 'city': 'Tempe', 'state': 'AZ', 'country': 'USA', 'zip_code': '85281'},
    {'code': 'SUCD', 'address': '80 Carter Dr.', 'city': 'Edison', 'state': 'NJ', 'country': 'USA', 'zip_code': '8817'},
    {'code': 'SUCE', 'address': '8427 S. Old Bingham Hwy', 'city': 'West Jordan', 'state': 'UT', 'country': 'USA', 'zip_code': '84088'},
    {'code': 'SUDA', 'address': '8179 Dixie Hwy, Suite 200', 'city': 'Florence', 'state': 'KY', 'country': 'USA', 'zip_code': '41042'},
    {'code': 'SUDB', 'address': '8179 Dixie Highway, Suite 200', 'city': 'Florence', 'state': 'KY', 'country': 'USA', 'zip_code': '41042'},
    {'code': 'SUEA', 'address': '1821 Lefthand Circle, Unit D', 'city': 'Longmont', 'state': 'CO', 'country': 'USA', 'zip_code': '80501'},
    {'code': 'SUEB', 'address': '135 West 36th Street FL 13', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10018'},
    {'code': 'SUED', 'address': '229 N Ella Rd', 'city': 'Spokane Valley', 'state': 'WA', 'country': 'USA', 'zip_code': '99212'},
    {'code': 'SUEG', 'address': '86 Mayfield Ave', 'city': 'Edison', 'state': 'NJ', 'country': 'USA', 'zip_code': '8837'},
    {'code': 'SUEH', 'address': '1760 West Terra Lane', 'city': 'OFallon', 'state': 'MT', 'country': 'USA', 'zip_code': '63366'},
    {'code': 'SUEI', 'address': '8 GALAXY WAY', 'city': 'Woodstock', 'state': 'IL', 'country': 'USA', 'zip_code': '60098'},
    {'code': 'SUEJ', 'address': '9462 Franklin Avenue', 'city': 'Franklin Park', 'state': 'IL', 'country': 'USA', 'zip_code': '60131'},
    {'code': 'SUFA', 'address': '8246 W. Mineral King Ave.', 'city': 'Visalia', 'state': 'CA', 'country': 'USA', 'zip_code': '93291'},
    {'code': 'SUFC', 'address': '587 Apollo St', 'city': 'Brea', 'state': 'CA', 'country': 'USA', 'zip_code': '92821'},
    {'code': 'SUFD', 'address': '587 Apollo St', 'city': 'Brea', 'state': 'CA', 'country': 'USA', 'zip_code': '92821'},
    {'code': 'SUGA', 'address': '4060 Hylan Blvd', 'city': 'Staten Island', 'state': 'NY', 'country': 'USA', 'zip_code': '10308'},
    {'code': 'SUGB', 'address': '5283 N State Hwy 6', 'city': 'Woodway', 'state': 'TX', 'country': 'USA', 'zip_code': '76712'},
    {'code': 'SUGC', 'address': '175 Van Dyke St.', 'city': 'Brooklyn', 'state': 'NY', 'country': 'USA', 'zip_code': '11231-1079'},
    {'code': 'SUGD', 'address': '6033 N Sheridan Rd', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60660'},
    {'code': 'SUGE', 'address': '5975 Shiloh Road, Suite 104', 'city': 'Alpharetta', 'state': 'GA', 'country': 'USA', 'zip_code': '30005'},
    {'code': 'SUHA', 'address': '9203 J Street', 'city': 'Omaha', 'state': 'NE', 'country': 'USA', 'zip_code': '68127'},
    {'code': 'SUHB', 'address': '4675 Appaloosa Dr', 'city': 'Irondale', 'state': 'AL', 'country': 'USA', 'zip_code': '35210'},
    {'code': 'SUHC', 'address': '18 Dixon St', 'city': 'Selbyville', 'state': 'DE', 'country': 'USA', 'zip_code': '19975'},
    {'code': 'SUHD', 'address': '4675 Appaloosa Drive', 'city': 'Irondale', 'state': 'AL', 'country': 'USA', 'zip_code': '35210'},
    {'code': 'SUHE', 'address': '239 Old New Brunswick Road Dock 7&8', 'city': 'Piscataway', 'state': 'NJ', 'country': 'USA', 'zip_code': '8854'},
    {'code': 'SUHH', 'address': '45410 Van Dyke', 'city': 'Utica', 'state': 'MI', 'country': 'USA', 'zip_code': '48314'},
    {'code': 'SUHI', 'address': '870 S. 16th St.', 'city': 'Aurora', 'state': 'NE', 'country': 'USA', 'zip_code': '68818'},
    {'code': 'SUHL', 'address': '1213 Maple Avenue', 'city': 'Burlington', 'state': 'NC', 'country': 'USA', 'zip_code': '27215'},
    {'code': 'SUHM', 'address': '142 Franklin St', 'city': 'Melrose', 'state': 'MA', 'country': 'USA', 'zip_code': '1276'},
    {'code': 'SUHO', 'address': '355 Tomahawk Drive Suite3', 'city': 'Maumee', 'state': 'OH', 'country': 'USA', 'zip_code': '43537'},
    {'code': 'SUHP', 'address': '45 Leone Lane', 'city': 'CHESTER', 'state': 'NY', 'country': 'USA', 'zip_code': '10918'},
    {'code': 'SUHQ', 'address': '4635 NAUTILUS CT S, STE D', 'city': 'Boulder', 'state': 'CO', 'country': 'USA', 'zip_code': '80301'},
    {'code': 'SUHS', 'address': '18 Dixon St', 'city': 'Selbyville', 'state': 'DE', 'country': 'USA', 'zip_code': '19975'},
    {'code': 'SUHT', 'address': '1809 W. Frankford Rd, Suite 160', 'city': 'Carrollton', 'state': 'TX', 'country': 'USA', 'zip_code': '75007'},
    {'code': 'SUHV', 'address': '10335 Naples ST NE', 'city': 'Blaine', 'state': 'MN', 'country': 'USA', 'zip_code': '55449'},
    {'code': 'SUHW', 'address': '2325 Raymer Ave', 'city': 'Fullerton', 'state': 'CA', 'country': 'USA', 'zip_code': '92833'},
    {'code': 'SUHX', 'address': '104A GLENN ST', 'city': 'LAWRENCE', 'state': 'ME', 'country': 'USA', 'zip_code': '1843'},
    {'code': 'SUJA', 'address': '325 NW 28TH ST', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33127'},
    {'code': 'SUJB', 'address': '706 North Diamond Bar Blvd, Unit A', 'city': 'Diamond Bar', 'state': 'CA', 'country': 'USA', 'zip_code': '91765'},
    {'code': 'SUJC', 'address': '325 NW 28TH ST', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33127'},
    {'code': 'SUJD', 'address': '47 Industrial Park Rd', 'city': 'Centerbrook', 'state': 'CT', 'country': 'USA', 'zip_code': '6409'},
    {'code': 'SUJE', 'address': '5124 Cleveland Rd', 'city': 'Wooster', 'state': 'OH', 'country': 'USA', 'zip_code': '44691'},
    {'code': 'SUJF', 'address': '100 S Wineville Ave', 'city': 'Ontario', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'SULA', 'address': '1380 Stonegate Way', 'city': 'Ferndale', 'state': 'WA', 'country': 'USA', 'zip_code': '98248'},
    {'code': 'SULC', 'address': '1345 Taylor Farms Road, Suite 112', 'city': 'Virginia Beach', 'state': 'VA', 'country': 'USA', 'zip_code': '23453'},
    {'code': 'SULD', 'address': '2020 Prairie Ln', 'city': 'Eau Claire', 'state': 'WI', 'country': 'USA', 'zip_code': '54703'},
    {'code': 'SULE', 'address': '100 Solutions Parkway', 'city': 'Thomaston', 'state': 'GA', 'country': 'USA', 'zip_code': '30286'},
    {'code': 'SULF', 'address': '170 Longs Pond Rd', 'city': 'Lexington', 'state': 'SC', 'country': 'USA', 'zip_code': '29072'},
    {'code': 'SULU', 'address': '582 S 1100 W', 'city': 'Woods Cross', 'state': 'UT', 'country': 'USA', 'zip_code': '84087'},
    {'code': 'SULX', 'address': '1728 Smallman St.', 'city': 'Pittsburgh', 'state': 'PA', 'country': 'USA', 'zip_code': '15222'},
    {'code': 'SUMA', 'address': '1201 Jersey Avenue', 'city': 'North Brunswick', 'state': 'NJ', 'country': 'USA', 'zip_code': '8902'},
    {'code': 'SUNA', 'address': '4179 70th Ave East, Suite A', 'city': 'Fife', 'state': 'WA', 'country': 'USA', 'zip_code': '98424'},
    {'code': 'SUNB', 'address': '320 Telfair Rd', 'city': 'Savannah', 'state': 'GA', 'country': 'USA', 'zip_code': '31415'},
    {'code': 'SUNC', 'address': '1113 E 230th Street', 'city': 'Carson', 'state': 'CA', 'country': 'USA', 'zip_code': '90745'},
    {'code': 'SUOC', 'address': '8750 Larkin Rd', 'city': 'Savage', 'state': 'MD', 'country': 'USA', 'zip_code': '20763-3200'},
    {'code': 'SUOD', 'address': '121 Kelsey Ln', 'city': 'Tampa', 'state': 'FL', 'country': 'USA', 'zip_code': '33619-4348'},
    {'code': 'SUOE', 'address': '74 Kenny Pl', 'city': 'Saddle Brook', 'state': 'NJ', 'country': 'USA', 'zip_code': '07663-5916'},
    {'code': 'SUOF', 'address': '6605 Roxburgh Dr. Suite 400', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77041'},
    {'code': 'SUOG', 'address': '19 Robert Pitt Drive, Ste 103', 'city': 'Monsey', 'state': 'NY', 'country': 'USA', 'zip_code': '10952'},
    {'code': 'SUOI', 'address': '870 North 100 East', 'city': 'Lehi', 'state': 'UT', 'country': 'USA', 'zip_code': '84043'},
    {'code': 'SUOJ', 'address': '1615 Fletcher Ave', 'city': 'FORT WAYNE', 'state': 'IN', 'country': 'USA', 'zip_code': '46803'},
    {'code': 'SUOK', 'address': '437 Baldwin Park Blvd', 'city': 'City of Industry', 'state': 'CA', 'country': 'USA', 'zip_code': '91746'},
    {'code': 'SUOL', 'address': '305 Bucknell Court', 'city': 'Atlanta', 'state': 'GA', 'country': 'USA', 'zip_code': '30336'},
    {'code': 'SUOM', 'address': '1230 Highway 34', 'city': 'Aberdeen', 'state': 'NJ', 'country': 'USA', 'zip_code': '7747'},
    {'code': 'SUON', 'address': '1703 S Veterans Pkwy', 'city': 'Bloomington', 'state': 'IL', 'country': 'USA', 'zip_code': '61701'},
    {'code': 'SUOO', 'address': '16792 Burke Lane', 'city': 'Huntington Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '92647'},
    {'code': 'SUOP', 'address': '1673 NY-17M', 'city': 'Chester', 'state': 'NY', 'country': 'USA', 'zip_code': '10918'},
    {'code': 'SUOQ', 'address': '3700 Cover St', 'city': 'Long Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '90808'},
    {'code': 'SUOR', 'address': '3820 Hempland Rd', 'city': 'Mountville', 'state': 'PA', 'country': 'USA', 'zip_code': '17544'},
    {'code': 'SUOS', 'address': '9655 SW SUNSHINE CT, SUITE 300', 'city': 'BEAVERTON', 'state': 'OR', 'country': 'USA', 'zip_code': '97005'},
    {'code': 'SUOT', 'address': '3820 Hempland Rd', 'city': 'Mountville', 'state': 'PA', 'country': 'USA', 'zip_code': '17544'},
    {'code': 'SUOW', 'address': '9655 SW Sunshine CT', 'city': 'Beaverton', 'state': 'OR', 'country': 'USA', 'zip_code': '97005'},
    {'code': 'SUOX', 'address': '19 Robert Pitt Drive STE 103', 'city': 'Monsey', 'state': 'NY', 'country': 'USA', 'zip_code': '10952'},
    {'code': 'SUOY', 'address': '1728 Smallman St.', 'city': 'Pittsburgh', 'state': 'PA', 'country': 'USA', 'zip_code': '15222'},
    {'code': 'SUOZ', 'address': '359 Pike Court, Suite 500', 'city': 'La Porte', 'state': 'TX', 'country': 'USA', 'zip_code': '77571'},
    {'code': 'SUPA', 'address': '412 Technology Drive E.', 'city': 'Menomonie', 'state': 'WI', 'country': 'USA', 'zip_code': '54571'},
    {'code': 'SUPB', 'address': '412 Technology Drive E.', 'city': 'Menomonie', 'state': 'WI', 'country': 'USA', 'zip_code': '54751'},
    {'code': 'SUPC', 'address': '503 West High St', 'city': 'Hicksville', 'state': 'OH', 'country': 'USA', 'zip_code': '43526'},
    {'code': 'SUPD', 'address': '8320 Baycenter Rd', 'city': 'Jacksonville', 'state': 'FL', 'country': 'USA', 'zip_code': '32256'},
    {'code': 'SUPE', 'address': '7886 Deering Ave.', 'city': 'Canoga Park', 'state': 'CA', 'country': 'USA', 'zip_code': '91304'},
    {'code': 'SUPG', 'address': '3725 Swenson Rd', 'city': 'St Charles', 'state': 'IL', 'country': 'USA', 'zip_code': '60174'},
    {'code': 'SUPH', 'address': '4201 tonelle ave', 'city': 'North Bergen', 'state': 'NJ', 'country': 'USA', 'zip_code': '7047'},
    {'code': 'SUPI', 'address': '2325 Raymer Avenue', 'city': 'Fullerton', 'state': 'CA', 'country': 'USA', 'zip_code': '92833'},
    {'code': 'SUPJ', 'address': '4737 van dam street', 'city': 'Long island City', 'state': 'NY', 'country': 'USA', 'zip_code': '11101'},
    {'code': 'SUPK', 'address': '9851 Owensmouth Ave', 'city': 'Chatsworth', 'state': 'CA', 'country': 'USA', 'zip_code': '91311'},
    {'code': 'SUPL', 'address': '587 Apollo St', 'city': 'Brea', 'state': 'CA', 'country': 'USA', 'zip_code': '92821'},
    {'code': 'SUPM', 'address': '1-AB Terminal Way', 'city': 'Avenel', 'state': 'NJ', 'country': 'USA', 'zip_code': '7001'},
    {'code': 'SUPN', 'address': '4201 tonelle ave', 'city': 'North Bergen', 'state': 'NJ', 'country': 'USA', 'zip_code': '7047'},
    {'code': 'SUPP', 'address': '230 Centerpoint BLVD', 'city': 'New Castle', 'state': 'DE', 'country': 'USA', 'zip_code': '19720'},
    {'code': 'SUPQ', 'address': '230 Centerpoint BLVD', 'city': 'New Castle', 'state': 'DE', 'country': 'USA', 'zip_code': '19720'},
    {'code': 'SUPR', 'address': '9414 E San Salvador Dr', 'city': 'Scottsdale', 'state': 'AZ', 'country': 'USA', 'zip_code': '85258'},
    {'code': 'SUSA', 'address': '7201 Intermodal Dr, Suite C', 'city': 'Louisville', 'state': 'KY', 'country': 'USA', 'zip_code': '40258'},
    {'code': 'SUSE', 'address': '188 County Road 4226', 'city': 'Decatur', 'state': 'TX', 'country': 'USA', 'zip_code': '76234'},
    {'code': 'SUSF', 'address': '840 Wheeling Rd', 'city': 'Wheeling', 'state': 'IL', 'country': 'USA', 'zip_code': '60090'},
    {'code': 'SUSG', 'address': '500 S Main Street', 'city': 'Mooresville', 'state': 'NC', 'country': 'USA', 'zip_code': '28117'},
    {'code': 'SUSH', 'address': '16792 Burke Lane', 'city': 'Huntington Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '92647'},
    {'code': 'SUSI', 'address': '7194 Big Sky Drive Suite 5', 'city': 'Holly', 'state': 'MI', 'country': 'USA', 'zip_code': '48442'},
    {'code': 'SUSJ', 'address': '8427 South Old Bingham Hwy', 'city': 'West Jordan', 'state': 'UT', 'country': 'USA', 'zip_code': '84088'},
    {'code': 'SUSK', 'address': '153 Washington St, 1st Floor', 'city': 'East Walpole', 'state': 'MA', 'country': 'USA', 'zip_code': '2032'},
    {'code': 'SUSL', 'address': '153 Washington St, 1st Floor', 'city': 'East Walpole', 'state': 'MA', 'country': 'USA', 'zip_code': '2032'},
    {'code': 'SUT1', 'address': '6338 West 700 North', 'city': 'SALT LAKE CITY', 'state': 'UT', 'country': 'USA', 'zip_code': '84116'},
    {'code': 'SUTA', 'address': '4503 Airwest DR SE', 'city': 'Kentwood', 'state': 'MI', 'country': 'USA', 'zip_code': '49512'},
    {'code': 'SUVA', 'address': '8933 Lyndale Ave S', 'city': 'Bloomington', 'state': 'MN', 'country': 'USA', 'zip_code': '55420'},
    {'code': 'SUWB', 'address': '150 Ethel Road West', 'city': 'Piscataway', 'state': 'NJ', 'country': 'USA', 'zip_code': '8854'},
    {'code': 'SUXA', 'address': '345 Boren Ave N', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'SUXC', 'address': '345 Boren Ave N', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'SUZA', 'address': '345 Boren Ave N', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'SUZB', 'address': '345 Boren Ave N', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'SUZC', 'address': '345 Boren Ave N', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98109'},
    {'code': 'SVA1', 'address': '99 S 6TH ST', 'city': 'RICHMOND', 'state': 'VA', 'country': 'USA', 'zip_code': '23219'},
    {'code': 'SVRH', 'address': '', 'city': 'Fort Lauderdale', 'state': 'FL', 'country': 'USA', 'zip_code': '33315'},
    {'code': 'SWA1', 'address': '607 RIVERSIDE ROAD', 'city': 'EVERETT', 'state': 'WA', 'country': 'USA', 'zip_code': '98201'},
    {'code': 'SWA2', 'address': '3610 S. EDMUNDS ST.', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98118'},
    {'code': 'SWF1', 'address': '635 INTERNATIONAL BLVD', 'city': 'ROCK TAVERN', 'state': 'NY', 'country': 'USA', 'zip_code': '12575-5150'},
    {'code': 'SWF2', 'address': '1940 ROUTE 52', 'city': 'EAST FISHKILL', 'state': 'NY', 'country': 'USA', 'zip_code': '12533'},
    {'code': 'SWI1', 'address': 'W232 N2950 Roundy Circle E', 'city': 'PEWAUKEE', 'state': 'WI', 'country': 'USA', 'zip_code': '53072'},
    {'code': 'SXWL', 'address': '', 'city': 'Rockaway', 'state': 'NJ', 'country': 'USA', 'zip_code': '7866'},
    {'code': 'SYR1', 'address': '7211 MORGAN RD', 'city': 'CLAY', 'state': 'NY', 'country': 'USA', 'zip_code': '13090'},
    {'code': 'SZBV', 'address': '', 'city': 'Copiague', 'state': 'NY', 'country': 'USA', 'zip_code': '11726'},
    {'code': 'TAM1', 'address': '2800 South Texas Avenue, Suite 401', 'city': 'Bryan', 'state': 'TX', 'country': 'USA', 'zip_code': '77802'},
    {'code': 'TAZ1', 'address': '500 S 48th St', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85034'},
    {'code': 'TBD', 'address': 'Boscombe Road', 'city': 'Prologis Park', 'state': 'Dunstable', 'country': 'United Kingdom', 'zip_code': 'LU5 4SB'},
    {'code': 'TBD2', 'address': '1111 N Cherry Ave', 'city': 'Goose Island', 'state': 'IL', 'country': 'USA', 'zip_code': '60642'},
    {'code': 'TBD3', 'address': '401 E Laraway Road', 'city': 'Joliet', 'state': 'IL', 'country': 'USA', 'zip_code': '40433'},
    {'code': 'TBD5', 'address': '8003 Industrial Ave, Building A', 'city': 'Carteret', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'TBD6', 'address': '4800 LBJ Freeway', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75241'},
    {'code': 'TBD7', 'address': '2801 S. Western Ave', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60608'},
    {'code': 'TBD8', 'address': 'Etna Township Park', 'city': 'Etna', 'state': 'OH', 'country': 'USA', 'zip_code': '43062'},
    {'code': 'TBD9', 'address': 'Alum Creek Drive', 'city': 'Obetz', 'state': 'OH', 'country': 'USA', 'zip_code': '43207'},
    {'code': 'TBDA', 'address': '1300 East McCarty Lane', 'city': 'San Marcos', 'state': 'TX', 'country': 'USA', 'zip_code': '78666'},
    {'code': 'TBDB', 'address': '2 Empire Boulevard', 'city': 'Moonachie', 'state': 'NJ', 'country': 'USA', 'zip_code': '7074'},
    {'code': 'TCA0', 'address': '455 Valley Drive', 'city': 'Brisbane', 'state': 'CA', 'country': 'USA', 'zip_code': '94005'},
    {'code': 'TCA1', 'address': '888 Tennessee St', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94107'},
    {'code': 'TCA2', 'address': '2400 Marine Avenue', 'city': 'Redondo Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '90278'},
    {'code': 'TCA4', 'address': '2006 McGaw Avenue', 'city': 'Irvine', 'state': 'CA', 'country': 'USA', 'zip_code': '92614'},
    {'code': 'TCA5', 'address': '3334 N San Fernando Rd Bldg E', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90065'},
    {'code': 'TCA6', 'address': '2727 Kurtz St', 'city': 'San Diego', 'state': 'CA', 'country': 'USA', 'zip_code': '92110'},
    {'code': 'TCA7', 'address': '222 Commercial St', 'city': 'Sunnyvale', 'state': 'CA', 'country': 'USA', 'zip_code': '94085'},
    {'code': 'TCA9', 'address': '2934 Ramona Ave', 'city': 'Sacramento', 'state': 'CA', 'country': 'USA', 'zip_code': '95826'},
    {'code': 'TCO1', 'address': '480 E 55th Avenue, Suite 100', 'city': 'Denver', 'state': 'CO', 'country': 'USA', 'zip_code': '80216'},
    {'code': 'TCY5', 'address': '6250 PROMONTORY PKWY', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95377-8883'},
    {'code': 'TCY9', 'address': '4500 WILBUR AVE', 'city': 'OAKLEY', 'state': 'CA', 'country': 'USA', 'zip_code': '94561'},
    {'code': 'TEB3', 'address': '2651 OLDMANS CREEK RD.', 'city': 'SWEDESBORO', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'TEB4', 'address': '742 Courses Landing Rd', 'city': 'Penns Grove', 'state': 'NJ', 'country': 'USA', 'zip_code': '08069-2956'},
    {'code': 'TEB6', 'address': '22 HIGHTSTOWN CRANBURY STATION RD', 'city': 'CRANBURY', 'state': 'NJ', 'country': 'USA', 'zip_code': '8512'},
    {'code': 'TEB9', 'address': '601 RANDOLPH RD', 'city': 'SOMERSET', 'state': 'NJ', 'country': 'USA', 'zip_code': '8873'},
    {'code': 'TEN1', 'address': '1002 Patriot Parkway', 'city': 'Reading', 'state': 'PA', 'country': 'USA', 'zip_code': '19605-2874'},
    {'code': 'TEN2', 'address': '1590 Tamarind Ave', 'city': 'Rialto', 'state': 'CA', 'country': 'USA', 'zip_code': '92376-3008'},
    {'code': 'TEN3', 'address': '800 N 75TH AVE', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'TEX1', 'address': 'Gregory Gym, 2101 Speedway', 'city': 'Austin', 'state': 'TX', 'country': 'USA', 'zip_code': '78712'},
    {'code': 'TFC1', 'address': '5050 West Mohave St, Attn: Receiving', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043-8305'},
    {'code': 'TFL2', 'address': '101 NE 23rd Street', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33137'},
    {'code': 'TFL3', 'address': '4430 E ADAMO DR, STE 305', 'city': 'Tampa', 'state': 'FL', 'country': 'USA', 'zip_code': '33605'},
    {'code': 'TFL4', 'address': '7469 Kingspointe Parkway', 'city': 'ORLANDO', 'state': 'FL', 'country': 'USA', 'zip_code': '32819'},
    {'code': 'TFL5', 'address': '8792 Ely Rd', 'city': 'PENSACOLA', 'state': 'FL', 'country': 'USA', 'zip_code': '32514'},
    {'code': 'TIJ1', 'address': 'Cañón del Padre', 'city': 'Tijuana', 'state': 'BC', 'country': 'Mexico', 'zip_code': '22203'},
    {'code': 'TIL1', 'address': '1111 N Cherry Ave', 'city': 'Chicago', 'state': 'IL', 'country': 'USA', 'zip_code': '60642'},
    {'code': 'TIN1', 'address': '710 S. Girls School Road', 'city': 'Indianapolis', 'state': 'IN', 'country': 'USA', 'zip_code': '46231'},
    {'code': 'TIW1', 'address': 'One Sitcum Plaza', 'city': 'Tacoma', 'state': 'WA', 'country': 'USA', 'zip_code': '98421'},
    {'code': 'TJA2', 'address': '2302 MARIETTA BLVD NW', 'city': 'Atlanta', 'state': 'GA', 'country': 'USA', 'zip_code': '30318'},
    {'code': 'TMA3', 'address': '30 Northampton Street', 'city': 'Boston', 'state': 'MA', 'country': 'USA', 'zip_code': '2118'},
    {'code': 'TMB8', 'address': '13720 SW 272ND ST', 'city': 'HOMESTEAD', 'state': 'FL', 'country': 'USA', 'zip_code': '33032'},
    {'code': 'TMD1', 'address': '5501 Holabird Ave', 'city': 'Baltimore', 'state': 'MD', 'country': 'USA', 'zip_code': '21224'},
    {'code': 'TMI1', 'address': '900 Oakwood St.', 'city': 'YPSILANTI', 'state': 'MI', 'country': 'USA', 'zip_code': '48197'},
    {'code': 'TMN1', 'address': '763 Kasota Ave', 'city': 'Minneapolis', 'state': 'MN', 'country': 'USA', 'zip_code': '55414'},
    {'code': 'TNC1', 'address': '300 Dalton Ave.', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28206-3118'},
    {'code': 'TNV2', 'address': '1945 E. Russell Rd', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89119-2706'},
    {'code': 'TNY1', 'address': '850 3rd Ave.', 'city': 'Brooklyn', 'state': 'NY', 'country': 'USA', 'zip_code': '11232'},
    {'code': 'TNYA', 'address': '7 W 34th Street', 'city': 'New York', 'state': 'NY', 'country': 'USA', 'zip_code': '10001'},
    {'code': 'TOH1', 'address': '5845 Highland Ridge Drive', 'city': 'Cincinnati', 'state': 'OH', 'country': 'USA', 'zip_code': '45232'},
    {'code': 'TON3', 'address': '5540 Mino Lane', 'city': 'LOUISVILLE', 'state': 'KY', 'country': 'USA', 'zip_code': '40219'},
    {'code': 'TOR1', 'address': '2104 NW York Street', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '97210'},
    {'code': 'TPA1', 'address': '3350 Laurel Ridge Ave', 'city': 'Ruskin', 'state': 'FL', 'country': 'USA', 'zip_code': '33570-5526'},
    {'code': 'TPA2', 'address': '1760 County Line Rd', 'city': 'Lakeland', 'state': 'FL', 'country': 'USA', 'zip_code': '33811-1808'},
    {'code': 'TPA3', 'address': '576 C Fred Jones Blvd', 'city': 'Auburndale', 'state': 'FL', 'country': 'USA', 'zip_code': '33823'},
    {'code': 'TPA4', 'address': '8706 HARNEY RD', 'city': 'TEMPLE TERRACE', 'state': 'FL', 'country': 'USA', 'zip_code': '33637'},
    {'code': 'TPA6', 'address': '3400 NW 35TH AVE RD', 'city': 'OCALA', 'state': 'FL', 'country': 'USA', 'zip_code': '33475'},
    {'code': 'TPAA', 'address': '4101 Sansom St', 'city': 'Philadelphia', 'state': 'PA', 'country': 'USA', 'zip_code': '19104'},
    {'code': 'TSN2', 'address': 'Wuqing. Tianjin', 'city': 'Wuqing', 'state': 'Tianjin', 'country': 'China', 'zip_code': ''},
    {'code': 'TTN1', 'address': '410 Harding Industrial Dr.', 'city': 'Nashville', 'state': 'TN', 'country': 'USA', 'zip_code': '37211'},
    {'code': 'TTN2', 'address': '343 Half Acre Rd', 'city': 'Cranbury', 'state': 'NJ', 'country': 'USA', 'zip_code': '08512-3253'},
    {'code': 'TTN6', 'address': '942 MEMORIAL PKWY', 'city': 'PHILLIPSBURG', 'state': 'NJ', 'country': 'USA', 'zip_code': '8865'},
    {'code': 'TTNA', 'address': '410 Harding Industrial Dr.', 'city': 'Nashville', 'state': 'TN', 'country': 'USA', 'zip_code': '37211'},
    {'code': 'TTX2', 'address': '2209 Rutland Dr, Suite B110', 'city': 'Austin', 'state': 'TX', 'country': 'USA', 'zip_code': '78758'},
    {'code': 'TTX3', 'address': '4221 Way Out West Drive', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77092'},
    {'code': 'TTX4', 'address': '6627 Maple Avenue', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75235'},
    {'code': 'TTX5', 'address': '4848 Perrin Creek 680', 'city': 'San Antonio', 'state': 'TX', 'country': 'USA', 'zip_code': '78217'},
    {'code': 'TUL1', 'address': '2674 N HIGHWAY 169', 'city': 'COFFEYVILLE', 'state': 'KS', 'country': 'USA', 'zip_code': '67337-9254'},
    {'code': 'TUL2', 'address': '11700 E 43rd St N', 'city': 'Tusla', 'state': 'OK', 'country': 'USA', 'zip_code': '74106'},
    {'code': 'TUL5', 'address': '3400 N MINGO RD', 'city': 'TULSA', 'state': 'OK', 'country': 'USA', 'zip_code': '74116'},
    {'code': 'TUS1', 'address': '5333 W. LOWER BUCKEYE RD.', 'city': 'PHOENIX', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043'},
    {'code': 'TUS2', 'address': '6701 S. KOLB RD.', 'city': 'TUCSON', 'state': 'AZ', 'country': 'USA', 'zip_code': '85756'},
    {'code': 'TUS5', 'address': '3590 E CORONA RD', 'city': 'TUCSON', 'state': 'AZ', 'country': 'USA', 'zip_code': '85756'},
    {'code': 'TWA0', 'address': '13537 Aurora Ave N', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98133'},
    {'code': 'TYS1', 'address': '4101 S SINGLETON STATION RD', 'city': 'ROCKFORD', 'state': 'TN', 'country': 'USA', 'zip_code': '37853'},
    {'code': 'UAZ1', 'address': '500 S 48th St', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85034-3101'},
    {'code': 'UBC1', 'address': '8155 N Fraser Way', 'city': 'Burnaby', 'state': 'BC', 'country': 'Canada', 'zip_code': 'BC V5J 5M8'},
    {'code': 'UCA1', 'address': '888 Tennessee St', 'city': 'San Francisco', 'state': 'CA', 'country': 'USA', 'zip_code': '94107'},
    {'code': 'UCA2', 'address': '', 'city': 'Redondo Beach', 'state': 'CA', 'country': 'USA', 'zip_code': '90277'},
    {'code': 'UCA3', 'address': '11800 W Olympic Blvd.', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90064'},
    {'code': 'UCA4', 'address': '2006 McGaw Avenue', 'city': 'Irvine', 'state': 'CA', 'country': 'USA', 'zip_code': '92614'},
    {'code': 'UCA5', 'address': '3334 N. San Fernando Road', 'city': 'Los Angeles', 'state': 'CA', 'country': 'USA', 'zip_code': '90065'},
    {'code': 'UCA6', 'address': '2727 Kurtz St', 'city': 'San Diego', 'state': 'CA', 'country': 'USA', 'zip_code': '92110-3109'},
    {'code': 'UCA7', 'address': '222 Commercial Street', 'city': 'Sunnyvale', 'state': 'CA', 'country': 'USA', 'zip_code': '94085'},
    {'code': 'UCA8', 'address': '3100 San Pablo Ave. Ste 120', 'city': 'West Berkley', 'state': 'CA', 'country': 'USA', 'zip_code': '94702'},
    {'code': 'UCA9', 'address': '2934 Ramona Avenue', 'city': 'Sacramento', 'state': 'CA', 'country': 'USA', 'zip_code': '95826'},
    {'code': 'UCO1', 'address': '480 E. 55th Avenue, Suite 100', 'city': 'Denver', 'state': 'CO', 'country': 'USA', 'zip_code': '80216'},
    {'code': 'UCO2', 'address': '3434 47th Street, Suite 220', 'city': 'Boulder', 'state': 'CO', 'country': 'USA', 'zip_code': '80301'},
    {'code': 'UDA1', 'address': '4150 Kellway Circle', 'city': 'ADDISON', 'state': 'TX', 'country': 'USA', 'zip_code': '75001'},
    {'code': 'UFL1', 'address': '15600 NW 15th Ave', 'city': 'Miami Gardens', 'state': 'FL', 'country': 'USA', 'zip_code': '33169'},
    {'code': 'UFL2', 'address': '101 NE 23rd Street', 'city': 'Miami', 'state': 'FL', 'country': 'USA', 'zip_code': '33137'},
    {'code': 'UFL3', 'address': '4430 East Adamo, Suite 305', 'city': 'Tampa', 'state': 'FL', 'country': 'USA', 'zip_code': '33605'},
    {'code': 'UFL4', 'address': '7469 Kingspointe Parkway', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32819'},
    {'code': 'UFL5', 'address': '4769 Oak Fair Blvd', 'city': 'TAMPA', 'state': 'FL', 'country': 'USA', 'zip_code': '33610'},
    {'code': 'UFL6', 'address': '3200 NW 67th Avenue', 'city': 'MIAMI', 'state': 'FL', 'country': 'USA', 'zip_code': '33122'},
    {'code': 'UFL7', 'address': '6843 S Conway Rd', 'city': 'ORLANDO', 'state': 'FL', 'country': 'USA', 'zip_code': '32812'},
    {'code': 'UGA1', 'address': '', 'city': 'Atlanta', 'state': 'GA', 'country': 'USA', 'zip_code': '30318'},
    {'code': 'UGA2', 'address': '2302 MARIETTA BLVD NW', 'city': 'ATLANTA', 'state': 'GA', 'country': 'USA', 'zip_code': '30318-1327'},
    {'code': 'UGA3', 'address': '2160 Breckinridge Blvd Bldg 100, Suite 100', 'city': 'Lawrenceville', 'state': 'GA', 'country': 'USA', 'zip_code': '30043'},
    {'code': 'UGA4', 'address': '2232 Northmont Parkway', 'city': 'DULUTH', 'state': 'GA', 'country': 'USA', 'zip_code': '30096'},
    {'code': 'UIL1', 'address': '1111 N CHERRY AVE', 'city': 'CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60642'},
    {'code': 'UIL2', 'address': '1250 N Mittel Blvd', 'city': 'Wood Dale', 'state': 'IL', 'country': 'USA', 'zip_code': '60191'},
    {'code': 'UIN1', 'address': '710 S. Girls School Road', 'city': 'Indianapolis', 'state': 'IN', 'country': 'USA', 'zip_code': '46231-1132'},
    {'code': 'ULA1', 'address': '635 8th St', 'city': 'SAN FERNANDO', 'state': 'CA', 'country': 'USA', 'zip_code': '91340'},
    {'code': 'ULA2', 'address': '4278 N. Harbor Blvd.', 'city': 'FULLERTON', 'state': 'CA', 'country': 'USA', 'zip_code': '92835'},
    {'code': 'ULA6', 'address': '5119 District Blvd', 'city': 'LOS ANGELES', 'state': 'CA', 'country': 'USA', 'zip_code': '90058'},
    {'code': 'UMA3', 'address': '30 Northampton Street', 'city': 'Boston', 'state': 'MA', 'country': 'USA', 'zip_code': '2118'},
    {'code': 'UMA4', 'address': '201 Beacham St', 'city': 'Chelsea', 'state': 'MA', 'country': 'USA', 'zip_code': '2150'},
    {'code': 'UMD1', 'address': '5501 Holabird Ave', 'city': 'Baltimore', 'state': 'MD', 'country': 'USA', 'zip_code': '21224'},
    {'code': 'UMI2', 'address': '999 Chicago Road', 'city': 'Troy', 'state': 'MI', 'country': 'USA', 'zip_code': '48083'},
    {'code': 'UMN1', 'address': '763 Kasota Ave', 'city': 'Minneapolis', 'state': 'MN', 'country': 'USA', 'zip_code': '55414-2842'},
    {'code': 'UMN2', 'address': '6105 Trenton Ln N', 'city': 'MINNEAPOLIS', 'state': 'MN', 'country': 'USA', 'zip_code': '55442'},
    {'code': 'UNC1', 'address': '', 'city': 'Charlotte', 'state': 'NC', 'country': 'USA', 'zip_code': '28201'},
    {'code': 'UNC2', 'address': '3200 Bush Street', 'city': 'Raleigh', 'state': 'NC', 'country': 'USA', 'zip_code': '27609'},
    {'code': 'UNC3', 'address': '4525 Statesville Ave', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28269'},
    {'code': 'UNJ1', 'address': '940 Monroe Street', 'city': 'Hoboken', 'state': 'NJ', 'country': 'USA', 'zip_code': '7030'},
    {'code': 'UNV1', 'address': '3650 East Post Road. Suite E', 'city': 'Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89120'},
    {'code': 'UNV2', 'address': '1945 E RUSSELL RD SUITES 201-204', 'city': 'Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89119'},
    {'code': 'UNV3', 'address': '2951 N Marion Dr Suite 101-103', 'city': 'Las Vegas', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'UNY1', 'address': '850 3rd Ave.', 'city': 'Brooklyn', 'state': 'NY', 'country': 'USA', 'zip_code': '11232'},
    {'code': 'UNY2', 'address': '1080 Leggett Ave', 'city': 'BRONX', 'state': 'NY', 'country': 'USA', 'zip_code': '10474'},
    {'code': 'UNY3', 'address': '57-00 49th Place', 'city': 'MASPETH', 'state': 'NY', 'country': 'USA', 'zip_code': '11378'},
    {'code': 'UNY4', 'address': '80 Grumman Rd W', 'city': 'BETHPAGE', 'state': 'NY', 'country': 'USA', 'zip_code': '11714'},
    {'code': 'UNY5', 'address': '55 Bay St Brooklyn', 'city': 'BROOKLYN', 'state': 'NY', 'country': 'USA', 'zip_code': '11231'},
    {'code': 'UOH1', 'address': 'Winton Hills', 'city': 'Cincinnati', 'state': 'OH', 'country': 'USA', 'zip_code': '45232'},
    {'code': 'UOH2', 'address': '3563 Interchange Rd', 'city': 'Columbus', 'state': 'OH', 'country': 'USA', 'zip_code': '43204'},
    {'code': 'UOH4', 'address': '4401 Equity Dr', 'city': 'COLUMBUS', 'state': 'OH', 'country': 'USA', 'zip_code': '43228'},
    {'code': 'UOH5', 'address': '492 Central Dr', 'city': 'VIRGINIA BEACH', 'state': 'VA', 'country': 'USA', 'zip_code': '23454'},
    {'code': 'UOR1', 'address': '2250 Northwest 22nd Avenue', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '97210'},
    {'code': 'UOR2', 'address': '5015 NW FRONT AVE', 'city': 'PORTLAND', 'state': 'OR', 'country': 'USA', 'zip_code': '97210-1105'},
    {'code': 'UPA1', 'address': '4101 Sansom St', 'city': 'Philadelphia', 'state': 'PA', 'country': 'USA', 'zip_code': '19104'},
    {'code': 'USC1', 'address': '3640 Ramos Dr', 'city': 'WEST SACRAMENTO', 'state': 'CA', 'country': 'USA', 'zip_code': '95691-6401'},
    {'code': 'USC2', 'address': '2400 McClellan Park Dr', 'city': 'SACRAMENTO', 'state': 'CA', 'country': 'USA', 'zip_code': '95838'},
    {'code': 'USD1', 'address': '9269 Lightwave Ave', 'city': 'SAN DIEGO', 'state': 'CA', 'country': 'USA', 'zip_code': '92123'},
    {'code': 'USF1', 'address': '750 Laurelwood Road', 'city': 'SANTA CLARA', 'state': 'CA', 'country': 'USA', 'zip_code': '95054'},
    {'code': 'USF2', 'address': '1700 Fairway Dr', 'city': 'SAN LEANDRO', 'state': 'CA', 'country': 'USA', 'zip_code': '94577'},
    {'code': 'USF3', 'address': '1911 Lundy Ave', 'city': 'SAN JOSE', 'state': 'CA', 'country': 'USA', 'zip_code': '95131'},
    {'code': 'USF4', 'address': '455 Valley Drive', 'city': 'BRISBANE', 'state': 'CA', 'country': 'USA', 'zip_code': '94005'},
    {'code': 'UTN1', 'address': '410 Harding Industrial Dr.', 'city': 'Nashville', 'state': 'TN', 'country': 'USA', 'zip_code': '37211'},
    {'code': 'UTX1', 'address': '', 'city': 'Irving', 'state': 'TX', 'country': 'USA', 'zip_code': '75014'},
    {'code': 'UTX2', 'address': '', 'city': 'Austin', 'state': 'TX', 'country': 'USA', 'zip_code': '73301'},
    {'code': 'UTX3', 'address': '4221 Way Out West Drive', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77092-1455'},
    {'code': 'UTX4', 'address': 'PO Box 80387', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98108'},
    {'code': 'UTX5', 'address': '4848 Perrin Creek #680', 'city': 'San Antonio', 'state': 'TX', 'country': 'USA', 'zip_code': '78217'},
    {'code': 'UTX7', 'address': '4601 Gold Spike Drive', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76106'},
    {'code': 'UTX8', 'address': '2800 S Texas Avenue, Suite 401', 'city': 'Bryan', 'state': 'TX', 'country': 'USA', 'zip_code': '77802'},
    {'code': 'UTX9', 'address': '4616 W Howard Lane', 'city': 'AUSTIN', 'state': 'TX', 'country': 'USA', 'zip_code': '78728'},
    {'code': 'UVA1', 'address': '5617 Industrial Dr. Suite A', 'city': 'Springfield', 'state': 'VA', 'country': 'USA', 'zip_code': '22151'},
    {'code': 'UVA2', 'address': '', 'city': 'Chesapeake', 'state': 'VA', 'country': 'USA', 'zip_code': ''},
    {'code': 'UVA3', 'address': '2034 Dabney Road', 'city': 'Richmond', 'state': 'VA', 'country': 'USA', 'zip_code': '23230'},
    {'code': 'UVA4', 'address': '4100 Tomlynn St', 'city': 'RICHMOND', 'state': 'VA', 'country': 'USA', 'zip_code': '23230'},
    {'code': 'UVA5', 'address': '492 Central Dr', 'city': 'VIRGINIA BEACH', 'state': 'VA', 'country': 'USA', 'zip_code': '23454'},
    {'code': 'UWA1', 'address': '11710 118th Ave NE Building B', 'city': 'Kirkland', 'state': 'WA', 'country': 'USA', 'zip_code': '98034'},
    {'code': 'UWA2', 'address': '13537 Aurora Ave. N.', 'city': 'North Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98133'},
    {'code': 'UWA3', 'address': '2121 8th Ave.', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98121'},
    {'code': 'UWA4', 'address': '76 S Lander Street', 'city': 'Seattle', 'state': 'WA', 'country': 'USA', 'zip_code': '98134'},
    {'code': 'UWA5', 'address': '18323 Andover Park W., Bldg. 6', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98188'},
    {'code': 'UWA6', 'address': '20202 84th AVE S', 'city': 'KENT', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'UWI1', 'address': '4111 W Mitchell Street', 'city': 'Milwaukee', 'state': 'WI', 'country': 'USA', 'zip_code': '53215'},
    {'code': 'UWR1', 'address': '1517 SW 104th St', 'city': 'SEATTLE', 'state': 'WA', 'country': 'USA', 'zip_code': '98146'},
    {'code': 'VAEO', 'address': '20526 59th Place S.', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'VAVP', 'address': '250 Enterprise Way', 'city': 'Pittston', 'state': 'PA', 'country': 'USA', 'zip_code': '18640-5000'},
    {'code': 'VFSN', 'address': '7401 F ST', 'city': 'OMAHA', 'state': 'NE', 'country': 'USA', 'zip_code': '68127'},
    {'code': 'VGT1', 'address': '5802 E TROPICAL PRKWY', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'VGT2', 'address': '6401 HOWDY WELLS AVE', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'VGT5', 'address': '6501 E HOWDY WELLS AVE', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'VHNA', 'address': '1160 N. Linden Ave', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'VHNB', 'address': '21005 64th Avenue South', 'city': 'KENT', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'VHNC', 'address': '11999 National Rd SW', 'city': 'Etna', 'state': 'OH', 'country': 'USA', 'zip_code': '43062'},
    {'code': 'VHND', 'address': '1700 SPARROWS POINT BLVD', 'city': 'SPARROWS POINT', 'state': 'MD', 'country': 'USA', 'zip_code': '21219'},
    {'code': 'VHNE', 'address': '2601 West Bethel Rd', 'city': 'DFW Airport', 'state': 'TX', 'country': 'USA', 'zip_code': '75019'},
    {'code': 'VHNF', 'address': '6521 Monee Manhattan Rd', 'city': 'MONEE', 'state': 'IL', 'country': 'USA', 'zip_code': '60449'},
    {'code': 'VMEX', 'address': 'Prologis Park, Tres Rios, Edificio 3', 'city': 'Cuautitlan Izcalli', 'state': 'Estado de Mexico', 'country': 'Mexico', 'zip_code': '54715'},
    {'code': 'VMX4', 'address': '123 Unknown', 'city': 'Monterrey', 'state': 'MX', 'country': 'Mexico', 'zip_code': '0'},
    {'code': 'VOPA', 'address': '2 Bramkay St', 'city': 'Brampton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L6S 6E9'},
    {'code': 'VUAC', 'address': '1670 Champagne Ave', 'city': 'ONTARIO', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'VUAD', 'address': '350 E 64TH ST', 'city': 'HOLLAND', 'state': 'MI', 'country': 'USA', 'zip_code': '49423'},
    {'code': 'VUAE', 'address': '3025 COMMERCE CENTER BLVD', 'city': 'BETHLEHEM', 'state': 'PA', 'country': 'USA', 'zip_code': '18015'},
    {'code': 'VUAF', 'address': '1005 COMMERCIAL DR', 'city': 'OWENSVILLE', 'state': 'MO', 'country': 'USA', 'zip_code': '65066'},
    {'code': 'VUAG', 'address': '4580 LOGISTICS DR', 'city': 'STOCKTON', 'state': 'CA', 'country': 'USA', 'zip_code': '95215'},
    {'code': 'VUAH', 'address': '310 HEINZ ST', 'city': 'MECHANICSBURG', 'state': 'PA', 'country': 'USA', 'zip_code': '17055'},
    {'code': 'VUAI', 'address': '3700 INDIAN AVE', 'city': 'PERRIS', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'VUAJ', 'address': '1716 INNOVATION BLVD', 'city': 'CLAYTON', 'state': 'IN', 'country': 'USA', 'zip_code': '46118'},
    {'code': 'VUAK', 'address': '740 VINTAGE AVE', 'city': 'ONTARIO', 'state': 'CA', 'country': 'USA', 'zip_code': '91764'},
    {'code': 'VUAL', 'address': '2101 DANIELDALE RD', 'city': 'LANCASTER', 'state': 'TX', 'country': 'USA', 'zip_code': '75134'},
    {'code': 'VUAM', 'address': '422 N CHIMNEY ROCK RD', 'city': 'GREENSBORO', 'state': 'NC', 'country': 'USA', 'zip_code': '27410'},
    {'code': 'VUAN', 'address': '5550 DONOVAN WAY', 'city': 'NORTH LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89081'},
    {'code': 'VUAO', 'address': '10 SIMMONS DR', 'city': 'HAZLE TOWNSHIP', 'state': 'PA', 'country': 'USA', 'zip_code': '18202'},
    {'code': 'VUAP', 'address': '1871 WILLOW SPRINGS CHURCH RD', 'city': 'SOCIAL CIRCLE', 'state': 'GA', 'country': 'USA', 'zip_code': '30025'},
    {'code': 'VUAQ', 'address': '6201 Seaforth St', 'city': 'BALTIMORE', 'state': 'MD', 'country': 'USA', 'zip_code': '21224'},
    {'code': 'VUAR', 'address': '275 BLAIR RD', 'city': 'AVENEL', 'state': 'NJ', 'country': 'USA', 'zip_code': '7001'},
    {'code': 'VUAT', 'address': '6855 Shannon Pkwy', 'city': 'Union City', 'state': 'GA', 'country': 'USA', 'zip_code': '30291'},
    {'code': 'VUAU', 'address': '6500 W 51ST ST', 'city': 'CHICAGO', 'state': 'IL', 'country': 'USA', 'zip_code': '60638'},
    {'code': 'VUAV', 'address': '1 Commerce Road', 'city': 'Pittston', 'state': 'PA', 'country': 'USA', 'zip_code': '18640'},
    {'code': 'VUAW', 'address': '4009 Montgomery St', 'city': 'SAVANNAH', 'state': 'GA', 'country': 'USA', 'zip_code': '31405'},
    {'code': 'VUAX', 'address': '4000 OSCAR NELSON JR DR', 'city': 'BAYTOWN', 'state': 'TX', 'country': 'USA', 'zip_code': '77523'},
    {'code': 'VUAY', 'address': '725 WALTHAM WAY STE 101', 'city': 'SPARKS', 'state': 'NV', 'country': 'USA', 'zip_code': '89437'},
    {'code': 'VUBA', 'address': '1000 Keystone Industrial Park', 'city': 'Scranton', 'state': 'PA', 'country': 'USA', 'zip_code': '18512'},
    {'code': 'VUBD', 'address': '17182 Nevada Avenue', 'city': 'Victorville', 'state': 'CA', 'country': 'USA', 'zip_code': '92345'},
    {'code': 'VUBF', 'address': '575 Old Forge Road', 'city': 'Union Township', 'state': 'PA', 'country': 'USA', 'zip_code': '17963'},
    {'code': 'VUBG', 'address': '8365 Sultana Ave, Unit 2', 'city': 'Fontana', 'state': 'CA', 'country': 'USA', 'zip_code': '92335'},
    {'code': 'VUBH', 'address': '9950 Calabash Ave', 'city': 'Fontana', 'state': 'CA', 'country': 'USA', 'zip_code': '92335-5210'},
    {'code': 'VUBI', 'address': '501 Meacham Blvd', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76106'},
    {'code': 'VUBJ', 'address': '1456 Harry Shepard Blvd', 'city': 'San Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'VUBN', 'address': '4800 E TROPICAL PKWY', 'city': 'LAS VEGAS', 'state': 'NV', 'country': 'USA', 'zip_code': '89115'},
    {'code': 'VUBP', 'address': '6500 POWERLINE RD', 'city': 'SACRAMENTO', 'state': 'CA', 'country': 'USA', 'zip_code': '95835'},
    {'code': 'VUBQ', 'address': '700 PALMETTO LOGISTICS PKWY STE A', 'city': 'PALMETTO', 'state': 'GA', 'country': 'USA', 'zip_code': '30268'},
    {'code': 'VUBR', 'address': '1405 N LOCUST AVE', 'city': 'RIALTO', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'VUBS', 'address': '121 RIDGE RD', 'city': 'JAMESBURG', 'state': 'NJ', 'country': 'USA', 'zip_code': '8831'},
    {'code': 'VUCA', 'address': '702 Commerce Drive', 'city': 'University Park', 'state': 'IL', 'country': 'USA', 'zip_code': '60484'},
    {'code': 'VUCB', 'address': '5197 Commerce Drive', 'city': 'YORK', 'state': 'PA', 'country': 'USA', 'zip_code': '17408'},
    {'code': 'VUCF', 'address': '1467 Perryman Rd', 'city': 'ABERDEEN', 'state': 'MD', 'country': 'USA', 'zip_code': '21001'},
    {'code': 'VUCG', 'address': '1595 Oakley Industrial Blvd', 'city': 'FAIRBURN', 'state': 'GA', 'country': 'USA', 'zip_code': '30213'},
    {'code': 'VUCH', 'address': '17486 NISQUALLI RD', 'city': 'VICTORVILLE', 'state': 'CA', 'country': 'USA', 'zip_code': '92395'},
    {'code': 'VUCL', 'address': '1460 CARGO CT', 'city': 'MINOOKA', 'state': 'IL', 'country': 'USA', 'zip_code': '60447'},
    {'code': 'VUCO', 'address': '960 WAUHATCHIE PIKE', 'city': 'CHATTANOOGA', 'state': 'TN', 'country': 'USA', 'zip_code': '37419'},
    {'code': 'VUCP', 'address': '84 ZIONS VIEW RD', 'city': 'MANCHESTER', 'state': 'PA', 'country': 'USA', 'zip_code': '17345'},
    {'code': 'VUCT', 'address': '13401 ASHMORE LN', 'city': 'NORTHLAKE', 'state': 'TX', 'country': 'USA', 'zip_code': '76262'},
    {'code': 'VUFC', 'address': '115 KENNEDY DR', 'city': 'SAYREVILLE', 'state': 'NJ', 'country': 'USA', 'zip_code': '8872'},
    {'code': 'VUGA', 'address': '508 Delaware Ave', 'city': 'West Pittston', 'state': 'PA', 'country': 'USA', 'zip_code': '18643'},
    {'code': 'VUGE', 'address': '3450 Dulles Dr', 'city': 'Mira Loma', 'state': 'CA', 'country': 'USA', 'zip_code': '91752-3242'},
    {'code': 'VUGH', 'address': '7875 White Road', 'city': 'Austell', 'state': 'GA', 'country': 'USA', 'zip_code': '30168'},
    {'code': 'VUGJ', 'address': '4275 Fritch Dr', 'city': 'Bethlehem', 'state': 'PA', 'country': 'USA', 'zip_code': '18020'},
    {'code': 'VUGK', 'address': '4120 Indian Ave', 'city': 'Perris', 'state': 'CA', 'country': 'USA', 'zip_code': '92571-7413'},
    {'code': 'VUGL', 'address': '1200 Distribution Drive', 'city': 'Carlisle', 'state': 'PA', 'country': 'USA', 'zip_code': '17013'},
    {'code': 'VUGM', 'address': '597 Alexander Spring Rd.', 'city': 'Carlisle', 'state': 'PA', 'country': 'USA', 'zip_code': '17015'},
    {'code': 'VUGO', 'address': '300 Interstate West Parkway', 'city': 'Austell', 'state': 'GA', 'country': 'USA', 'zip_code': '30168'},
    {'code': 'VUGP', 'address': '234 Walnut Bottom Road', 'city': 'Shippensburg', 'state': 'PA', 'country': 'USA', 'zip_code': '17257'},
    {'code': 'VUGR', 'address': '1565 N Mac Arthur Dr.', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95376'},
    {'code': 'VUGT', 'address': '17789 Harvill Avenue', 'city': 'PERRIS', 'state': 'CA', 'country': 'USA', 'zip_code': '92570'},
    {'code': 'VUGX', 'address': '2 ABBOTT PARK WAY', 'city': 'TIPP CITY', 'state': 'OH', 'country': 'USA', 'zip_code': '45371'},
    {'code': 'VUH1', 'address': '0200 AMARGOSA RD', 'city': 'HESPERIA', 'state': 'CA', 'country': 'USA', 'zip_code': '92345'},
    {'code': 'VUH2', 'address': '2001 Commerce Parkway', 'city': 'FRANKLIN', 'state': 'IN', 'country': 'USA', 'zip_code': '46131'},
    {'code': 'VUH3', 'address': '101 ONEIL ROAD', 'city': 'SIDNEY', 'state': 'NY', 'country': 'USA', 'zip_code': '13838'},
    {'code': 'VUH4', 'address': '2830 E Philadelphia Street', 'city': 'ONTARIO', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'VUH5', 'address': '800 W Stephens St', 'city': 'ARLINGTON', 'state': 'TX', 'country': 'USA', 'zip_code': '76017'},
    {'code': 'VUH6', 'address': '5900 Long Creek Park Dr', 'city': 'CHARLOTTE', 'state': 'NC', 'country': 'USA', 'zip_code': '28269'},
    {'code': 'VUH7', 'address': '3355 E Cedar St', 'city': 'ONTARIO', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'VUH8', 'address': '4433 Fyler Avenue', 'city': 'SAINT LOUIS', 'state': 'MO', 'country': 'USA', 'zip_code': '63116'},
    {'code': 'VUH9', 'address': '2325 Cottonwood Ave', 'city': 'RIVERSIDE', 'state': 'CA', 'country': 'USA', 'zip_code': '92508'},
    {'code': 'VUHA', 'address': '700 Chase Street', 'city': 'Gary', 'state': 'IN', 'country': 'USA', 'zip_code': '46404'},
    {'code': 'VUHE', 'address': '3401 Innovative Way', 'city': 'Mesquite', 'state': 'TX', 'country': 'USA', 'zip_code': '75149'},
    {'code': 'VUHF', 'address': '11111 80TH AVE', 'city': 'Pleasant Prairie', 'state': 'WI', 'country': 'USA', 'zip_code': '53158'},
    {'code': 'VUHG', 'address': '28625 Fountain Parkway', 'city': 'Solon', 'state': 'OH', 'country': 'USA', 'zip_code': '44139'},
    {'code': 'VUI1', 'address': '909 E 236th St', 'city': 'CARSON', 'state': 'CA', 'country': 'USA', 'zip_code': '90745'},
    {'code': 'VUI2', 'address': '101 Center Point Drive', 'city': 'ROCHELLE', 'state': 'IL', 'country': 'USA', 'zip_code': '61068'},
    {'code': 'VUI3', 'address': '17150 Mercury St.', 'city': 'OLATHE', 'state': 'KS', 'country': 'USA', 'zip_code': '66061'},
    {'code': 'VUI4', 'address': '303 Nelson Avenue', 'city': 'NEOSHO', 'state': 'MO', 'country': 'USA', 'zip_code': '64850'},
    {'code': 'VUI5', 'address': '13133 Innovation Way', 'city': 'VICTORVILLE', 'state': 'CA', 'country': 'USA', 'zip_code': '92395'},
    {'code': 'VUI6', 'address': '15835 San Antonio Ave.', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'VUI7', 'address': '2801 North Houston School Road', 'city': 'LANCASTER', 'state': 'TX', 'country': 'USA', 'zip_code': '75134'},
    {'code': 'VUI8', 'address': '212 Progress Blvd', 'city': 'KENT', 'state': 'OH', 'country': 'USA', 'zip_code': '44240'},
    {'code': 'VUJ2', 'address': '13052 Jurupa Ave', 'city': 'FONTANA', 'state': 'CA', 'country': 'USA', 'zip_code': '92337'},
    {'code': 'VUJC', 'address': '9606 West Hills Ct Suite A', 'city': 'KUTZTOWN', 'state': 'PA', 'country': 'USA', 'zip_code': '19530'},
    {'code': 'VUJE', 'address': '355 Byrd Avenue', 'city': 'NEENAH', 'state': 'WI', 'country': 'USA', 'zip_code': '54956'},
    {'code': 'VUJH', 'address': '11940 S HARLAN RD', 'city': 'LATHROP', 'state': 'CA', 'country': 'USA', 'zip_code': '95330'},
    {'code': 'VUJI', 'address': '4500 NORTHPORT DR', 'city': 'NORTHLAKE', 'state': 'TX', 'country': 'USA', 'zip_code': '76262'},
    {'code': 'VUJK', 'address': '15710 SAN ANTONIO AVE', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'VUJL', 'address': '6710 OAKLEY INDUSTRIAL BLVD', 'city': 'UNION CITY', 'state': 'GA', 'country': 'USA', 'zip_code': '30291'},
    {'code': 'VUJU', 'address': '305 Resource Drive', 'city': 'BLOOMINGTON', 'state': 'CA', 'country': 'USA', 'zip_code': '92316'},
    {'code': 'VUKF', 'address': '18120 Bishop Ave', 'city': 'Carson', 'state': 'CA', 'country': 'USA', 'zip_code': '90746-4032'},
    {'code': 'VUKG', 'address': '3201 Centre Parkway', 'city': 'East Point', 'state': 'GA', 'country': 'USA', 'zip_code': '30344'},
    {'code': 'VUKH', 'address': '1901 W Airfield Dr', 'city': 'DFW Airport', 'state': 'TX', 'country': 'USA', 'zip_code': '75261'},
    {'code': 'VUKI', 'address': '400 Arlington Blvd', 'city': 'Swedesboro', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'VUKJ', 'address': '19270 S. Western Avenue', 'city': 'Torrance', 'state': 'CA', 'country': 'USA', 'zip_code': '90501'},
    {'code': 'VUKZ', 'address': '400 Arlington Blvd', 'city': 'Logan Township', 'state': 'NJ', 'country': 'USA', 'zip_code': '8085'},
    {'code': 'VULL', 'address': '1350 S WATERMAN AVE', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92408'},
    {'code': 'VUMC', 'address': '650 Commerce Pkwy W Drive', 'city': 'Greenwood', 'state': 'IN', 'country': 'USA', 'zip_code': '46143'},
    {'code': 'VUMD', 'address': '548 W Merrill Ave', 'city': 'Rialto', 'state': 'CA', 'country': 'USA', 'zip_code': '92376-9101'},
    {'code': 'VUME', 'address': '200 Docks Corner Road, Suite 241', 'city': 'South Brunswick', 'state': 'NJ', 'country': 'USA', 'zip_code': '8810'},
    {'code': 'VUMF', 'address': '500 PALMETTO LOGISTICS PKWY', 'city': 'PALMETTO', 'state': 'GA', 'country': 'USA', 'zip_code': '30268'},
    {'code': 'VUMX', 'address': '241 E Pacific Coast Hwy', 'city': 'Wilmington', 'state': 'CA', 'country': 'USA', 'zip_code': '90744-2920'},
    {'code': 'VUOJ', 'address': '250 Declaration Avenue, Suite 500', 'city': 'McDonough', 'state': 'GA', 'country': 'USA', 'zip_code': '30253'},
    {'code': 'VUOK', 'address': '21837 W. Mississippi Ave', 'city': 'Elwood', 'state': 'IL', 'country': 'USA', 'zip_code': '60421'},
    {'code': 'VUOL', 'address': '14005 North Lombard', 'city': 'Portland', 'state': 'OR', 'country': 'USA', 'zip_code': '97203'},
    {'code': 'VUPG', 'address': '16110 Cosmos Street', 'city': 'Moreno Valley', 'state': 'CA', 'country': 'USA', 'zip_code': '92551'},
    {'code': 'VUPH', 'address': '9300 Olde Scotland Road', 'city': 'Shippensburg', 'state': 'PA', 'country': 'USA', 'zip_code': '17257'},
    {'code': 'VUPJ', 'address': '101 Mars Road', 'city': 'Wilmer', 'state': 'TX', 'country': 'USA', 'zip_code': '75172'},
    {'code': 'VUPK', 'address': '6720 Oakley Industrial Blvd', 'city': 'Union City', 'state': 'GA', 'country': 'USA', 'zip_code': '30291'},
    {'code': 'VUPM', 'address': '22001 84th Avenue', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'VUPN', 'address': '340 Westridge Parkway', 'city': 'McDonough', 'state': 'GA', 'country': 'USA', 'zip_code': '30253'},
    {'code': 'VUPO', 'address': '4808 Mountain Creek Parkway', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75236'},
    {'code': 'VUPQ', 'address': '9211 Kaiser Way', 'city': 'Fontana', 'state': 'CA', 'country': 'USA', 'zip_code': '92335'},
    {'code': 'VUPS', 'address': '3049 Westway Drive', 'city': 'Edwardsville', 'state': 'IL', 'country': 'USA', 'zip_code': '62025'},
    {'code': 'VUPU', 'address': '14916 STATE HIGHWAY 177, Building 1', 'city': 'Jackson', 'state': 'MO', 'country': 'USA', 'zip_code': '63755'},
    {'code': 'VUPV', 'address': '2001 Premier Pkwy', 'city': 'Saint Peters', 'state': 'MO', 'country': 'USA', 'zip_code': '63376'},
    {'code': 'VUPW', 'address': '8778 Le St Dr', 'city': 'West Chester', 'state': 'OH', 'country': 'USA', 'zip_code': '45014-2260'},
    {'code': 'VUPX', 'address': '2300 W San Bernardino Ave', 'city': 'Redlands', 'state': 'CA', 'country': 'USA', 'zip_code': '92374'},
    {'code': 'VUPY', 'address': '2501 Rockhouse Road', 'city': 'Lithia Springs', 'state': 'GA', 'country': 'USA', 'zip_code': '30122'},
    {'code': 'VUPZ', 'address': '4800 Henrietta Creek Rd', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76177'},
    {'code': 'VUQC', 'address': '2020 Ocean Avenue', 'city': 'Ronkonkoma', 'state': 'NY', 'country': 'USA', 'zip_code': '11779'},
    {'code': 'VUQD', 'address': '3101 IN-62', 'city': 'Mt Vernon', 'state': 'IN', 'country': 'USA', 'zip_code': '47620'},
    {'code': 'VUQE', 'address': '69 Green Mountain Road', 'city': 'Hazleton', 'state': 'PA', 'country': 'USA', 'zip_code': '18202'},
    {'code': 'VUQF', 'address': '2100 Innovation Blvd', 'city': 'Mooresville', 'state': 'IN', 'country': 'USA', 'zip_code': '46158'},
    {'code': 'VUQH', 'address': '381 Airtech Pkwy', 'city': 'Plainfeild', 'state': 'IN', 'country': 'USA', 'zip_code': '46168'},
    {'code': 'VUQI', 'address': '512 Liberty Expressway', 'city': 'Albany', 'state': 'GA', 'country': 'USA', 'zip_code': '31705'},
    {'code': 'VUQM', 'address': '441 Masters Boulevard', 'city': 'Anderson', 'state': 'SC', 'country': 'USA', 'zip_code': '29626'},
    {'code': 'VUQN', 'address': '1711 S 4650 W', 'city': 'Salt Lake City', 'state': 'UT', 'country': 'USA', 'zip_code': '84104'},
    {'code': 'VUQO', 'address': '2425 E. Perry Rd', 'city': 'PLAINFIELD', 'state': 'IN', 'country': 'USA', 'zip_code': '46168'},
    {'code': 'VUQP', 'address': '655 E Park St', 'city': 'LOCK HAVEN', 'state': 'PA', 'country': 'USA', 'zip_code': '17745'},
    {'code': 'VURY', 'address': '670 N Perkins St', 'city': 'Appleton', 'state': 'WI', 'country': 'USA', 'zip_code': '54914'},
    {'code': 'VUTD', 'address': '8291 Milliken Avenue', 'city': 'Rancho Cucamonga', 'state': 'CA', 'country': 'USA', 'zip_code': '91730'},
    {'code': 'VUTE', 'address': '1020 SH Morgan Pkwy', 'city': 'Pooler', 'state': 'GA', 'country': 'USA', 'zip_code': '31322'},
    {'code': 'VUTF', 'address': '16047 Mountain Ave', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'VUTG', 'address': '100 E MILLSDALE RD', 'city': 'Elwood', 'state': 'IL', 'country': 'USA', 'zip_code': '60421'},
    {'code': 'VUTH', 'address': '25451 Mountain House Pkwy', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95377'},
    {'code': 'VUTI', 'address': '380 DEANS RHODE HALL RD', 'city': 'MONROE TOWNSHIP', 'state': 'NJ', 'country': 'USA', 'zip_code': '8831'},
    {'code': 'VUVB', 'address': '2053 East Jay St', 'city': 'Ontario', 'state': 'CA', 'country': 'USA', 'zip_code': '91764'},
    {'code': 'VUVC', 'address': '2500 Export Dr, Door 1', 'city': 'Louisville', 'state': 'KY', 'country': 'USA', 'zip_code': '40219'},
    {'code': 'VUWA', 'address': '13243 Nutro Way', 'city': 'Victorville', 'state': 'CA', 'country': 'USA', 'zip_code': '92395'},
    {'code': 'VUWB', 'address': '6373 Brackbill Blvd', 'city': 'Mechanicsburg', 'state': 'PA', 'country': 'USA', 'zip_code': '17050-2876'},
    {'code': 'VUWC', 'address': '4700 E Nestle Purina Ave', 'city': 'Flagstaff', 'state': 'CA', 'country': 'USA', 'zip_code': '86004'},
    {'code': 'VUWE', 'address': '736 Garner Rd', 'city': 'Modesto', 'state': 'CA', 'country': 'USA', 'zip_code': '95357'},
    {'code': 'VUWH', 'address': '5725 Jurupa St', 'city': 'Ontario', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'VUWI', 'address': '4015 Lakeview Corporate Drive', 'city': 'EDWARDSVILLE', 'state': 'IL', 'country': 'USA', 'zip_code': '62025'},
    {'code': 'VUWR', 'address': '2301 W. Bernardino Ave.', 'city': 'REDLANDS', 'state': 'CA', 'country': 'USA', 'zip_code': '92374'},
    {'code': 'WR01', 'address': 'ul. Logistyczna, 55-040', 'city': 'Bielany Wroclawskie', 'state': 'Wroclaw', 'country': 'Poland', 'zip_code': ''},
    {'code': 'WR02', 'address': 'Wroclaw. Poland', 'city': 'Wroclaw', 'state': '', 'country': 'Poland', 'zip_code': ''},
    {'code': 'WRO1', 'address': 'Near Nowa Wie junction linking motorways A4 and A8', 'city': 'Bielany Wroclawskie Suburb', 'state': '', 'country': 'Poland', 'zip_code': ''},
    {'code': 'WRO2', 'address': 'Logistyczna 6', 'city': 'Bielany Wroclawskie', 'state': 'Wroclaw', 'country': 'Poland', 'zip_code': '55-040'},
    {'code': 'WUH1', 'address': 'Wuhan, Hubei', 'city': 'Wuhan', 'state': 'Hubei', 'country': 'China', 'zip_code': ''},
    {'code': 'XBC1', 'address': '15750 Mountain Avenue', 'city': 'Chino', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'XBRA', 'address': 'Avenida Doutor Antonio Joao Abadalla, 260, Bairro Cristais Jordanesia', 'city': 'Cajamar', 'state': 'SP', 'country': 'Brazil', 'zip_code': '7776700'},
    {'code': 'XBRZ', 'address': 'Estrada dos Alpes 970', 'city': 'Barueri', 'state': 'Sao Paulo', 'country': 'Brazil', 'zip_code': '6423080'},
    {'code': 'XBSP', 'address': '15750 Mountain Ave', 'city': 'CHINO', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'XBW1', 'address': '5300 Nottingham Rd.', 'city': 'NOTTINGHAM', 'state': 'MD', 'country': 'USA', 'zip_code': '21236'},
    {'code': 'XCAB', 'address': '1882 118 Avenue NE', 'city': 'Calgary', 'state': 'AB', 'country': 'Canada', 'zip_code': 'T3K 0R1'},
    {'code': 'XCAC', 'address': '9501 Highway 50', 'city': 'Woodbridge', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L4H 2B9'},
    {'code': 'XEW1', 'address': '6855 SHANNON PKWY', 'city': 'UNION CITY', 'state': 'GA', 'country': 'USA', 'zip_code': '30291-2091'},
    {'code': 'XEW2', 'address': '6855 SHANNON PKWY', 'city': 'UNION CITY', 'state': 'GA', 'country': 'USA', 'zip_code': '30291'},
    {'code': 'XFI1', 'address': '6351 Cameron Boulevard', 'city': 'Gilroy', 'state': 'CA', 'country': 'USA', 'zip_code': '95020'},
    {'code': 'XIX1', 'address': '18 APPLEGATE DR', 'city': 'ROBBINSVILLE', 'state': 'NJ', 'country': 'USA', 'zip_code': '8691'},
    {'code': 'XIX2', 'address': '2020 E Central Ave', 'city': 'San Bernardino', 'state': 'CA', 'country': 'USA', 'zip_code': '92408-0123'},
    {'code': 'XIX3', 'address': '1400 SOUTHPORT PKWY BLDG 7', 'city': 'WILMER', 'state': 'TX', 'country': 'USA', 'zip_code': '75172-1265'},
    {'code': 'XIX4', 'address': '5155 Citation Drive', 'city': 'MEMPHIS', 'state': 'TN', 'country': 'USA', 'zip_code': '38118-7830'},
    {'code': 'XIX5', 'address': '11211 Burlington Road', 'city': 'KENOSHA', 'state': 'WI', 'country': 'USA', 'zip_code': '53144-7449'},
    {'code': 'XIX6', 'address': '10681 Production Ave', 'city': 'Fontana', 'state': 'CA', 'country': 'USA', 'zip_code': '92337-8006'},
    {'code': 'XIX7', 'address': '555 E ORANGE SHOW RD', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92408-2453'},
    {'code': 'XIX8', 'address': '235 HOG MOUNTAIN RD', 'city': 'JEFFERSON', 'state': 'GA', 'country': 'USA', 'zip_code': '30549'},
    {'code': 'XIY1', 'address': 'Xiian, Shaanxi', 'city': 'Xiian', 'state': 'Shaanxi', 'country': 'China', 'zip_code': ''},
    {'code': 'XLA2', 'address': '6725 Kimball Ave', 'city': 'Chino', 'state': 'CA', 'country': 'USA', 'zip_code': '91708'},
    {'code': 'XLAA', 'address': '5691 E Philadelphia, Suite 100', 'city': 'Ontario', 'state': 'CA', 'country': 'USA', 'zip_code': '91761'},
    {'code': 'XLAB', 'address': '1701 Normantown Rd', 'city': 'Romeoville', 'state': 'IL', 'country': 'USA', 'zip_code': '60446'},
    {'code': 'XLAE', 'address': '5330 Crosswind Dr', 'city': 'Columbus', 'state': 'OH', 'country': 'USA', 'zip_code': '43228'},
    {'code': 'XLAF', 'address': '1600 Roe St', 'city': 'Dallas', 'state': 'TX', 'country': 'USA', 'zip_code': '75215'},
    {'code': 'XLAG', 'address': '2115 S Sinclair Ave', 'city': 'Stockton', 'state': 'CA', 'country': 'USA', 'zip_code': '95215'},
    {'code': 'XLAH', 'address': '580 Raco Pkwy', 'city': 'Pendergrass', 'state': 'GA', 'country': 'USA', 'zip_code': '30567'},
    {'code': 'XLAI', 'address': '7650 S 228th St', 'city': 'Kent', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'XLAJ', 'address': '3440 Meyers Rd', 'city': 'Memphis', 'state': 'TN', 'country': 'USA', 'zip_code': '38108'},
    {'code': 'XLAK', 'address': '18875 E BROMLEY LN, SUITE A', 'city': 'BRIGHTON', 'state': 'CO', 'country': 'USA', 'zip_code': '80601'},
    {'code': 'XLBA', 'address': '1123 4th ST SW', 'city': 'Conover', 'state': 'NC', 'country': 'USA', 'zip_code': '28613'},
    {'code': 'XLX1', 'address': '1115 WESEL BLVD', 'city': 'HAGERSTOWN', 'state': 'MD', 'country': 'USA', 'zip_code': '21740'},
    {'code': 'XLX2', 'address': '3565 N AIRPORT WAY', 'city': 'MANTECAA', 'state': 'CA', 'country': 'USA', 'zip_code': '95336'},
    {'code': 'XLX3', 'address': '4375 N Perris Blvd', 'city': 'PERRISA', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'XLX4', 'address': '4701 Commerce Rd.', 'city': 'RICHMOND', 'state': 'VA', 'country': 'USA', 'zip_code': '23234'},
    {'code': 'XMN1', 'address': 'Xiamen, Fujian', 'city': 'Xiamen', 'state': 'Fujian', 'country': 'China', 'zip_code': ''},
    {'code': 'XMN2', 'address': 'Xiamen', 'city': 'Fujian', 'state': '', 'country': 'China', 'zip_code': ''},
    {'code': 'XSF1', 'address': '2250 Promontory Pkwy', 'city': 'TRACY', 'state': 'CA', 'country': 'USA', 'zip_code': '95377'},
    {'code': 'XSP1', 'address': '1115 Vaughn Parkway', 'city': 'Portland', 'state': 'TN', 'country': 'USA', 'zip_code': '37148'},
    {'code': 'XUKD', 'address': 'ND Logistics NS 3PL, Bigfoot, Royal Oak Distribution Centre. Royal Oak W', 'city': 'Daventry', 'state': 'East Midlands', 'country': 'United Kingdom', 'zip_code': 'NN11 8QL'},
    {'code': 'XUSB', 'address': '14900 Frye Rd', 'city': 'Fort Worth', 'state': 'TX', 'country': 'USA', 'zip_code': '76155-2726'},
    {'code': 'XUSC', 'address': '40 Logistics Dr', 'city': 'Carlisle', 'state': 'PA', 'country': 'USA', 'zip_code': '17013-7901'},
    {'code': 'XUSD', 'address': '1909 Zephyr St', 'city': 'Stockton', 'state': 'CA', 'country': 'USA', 'zip_code': '95206'},
    {'code': 'XUSE', 'address': '5490 Industrial Court, Suite 300', 'city': 'Whitestown', 'state': 'IN', 'country': 'USA', 'zip_code': '46075'},
    {'code': 'XUSF', 'address': '901 West Landstreet Road, Suite C', 'city': 'Orlando', 'state': 'FL', 'country': 'USA', 'zip_code': '32824'},
    {'code': 'XUSG', 'address': '9645 West Hills Court', 'city': 'Kutztown', 'state': 'PA', 'country': 'USA', 'zip_code': '19530'},
    {'code': 'XUSH', 'address': '7037 West Van Buren Street, Menlo Worldwide Logistics', 'city': 'Phoenix', 'state': 'AZ', 'country': 'USA', 'zip_code': '85043-3313'},
    {'code': 'XUSI', 'address': '101 Broome Corporate Pkwy Conklin', 'city': 'CONKLIN', 'state': 'NY', 'country': 'USA', 'zip_code': '13748'},
    {'code': 'XUSJ', 'address': '1590 Tamarind Ave', 'city': 'Rialto', 'state': 'CA', 'country': 'USA', 'zip_code': '92376'},
    {'code': 'XUSK', 'address': '31450 W 196th St.', 'city': 'Edgerton', 'state': 'KS', 'country': 'USA', 'zip_code': '66021'},
    {'code': 'XUSL', 'address': '610 Chelsea Rd', 'city': 'Aberdeen', 'state': 'MD', 'country': 'USA', 'zip_code': '21001'},
    {'code': 'XUSM', 'address': '610 Chelsea Road', 'city': 'Aberdeen', 'state': 'MD', 'country': 'USA', 'zip_code': '21001'},
    {'code': 'XUSN', 'address': '4200 Ferry Rd', 'city': 'Aurora', 'state': 'IL', 'country': 'USA', 'zip_code': '60502'},
    {'code': 'XUSO', 'address': '657 Nance Street', 'city': 'Perris', 'state': 'CA', 'country': 'USA', 'zip_code': '92571'},
    {'code': 'XUSP', 'address': 'XUSP - 3PL Kuehne-Nagel', 'city': 'Aberdeen', 'state': 'MD', 'country': 'USA', 'zip_code': '21001'},
    {'code': 'XUSQ', 'address': '152 Route 206', 'city': 'Hillsborough', 'state': 'NJ', 'country': 'USA', 'zip_code': '8844'},
    {'code': 'XUSR', 'address': '5425 Dixie Highway', 'city': 'Saginaw', 'state': 'MI', 'country': 'USA', 'zip_code': '48601'},
    {'code': 'XUSS', 'address': '502 10th Ave. Algona', 'city': 'AUBURN', 'state': 'WA', 'country': 'USA', 'zip_code': '98001'},
    {'code': 'XUST', 'address': '3251 De Forest Circle', 'city': 'MIRA LOMA', 'state': 'CA', 'country': 'USA', 'zip_code': '91752'},
    {'code': 'XUSU', 'address': '', 'city': 'Rock Hill', 'state': 'SC', 'country': 'USA', 'zip_code': '29730'},
    {'code': 'XUSV', 'address': '2255 W. Lugonia Avenue', 'city': 'Redlands', 'state': 'CA', 'country': 'USA', 'zip_code': '92374-5049'},
    {'code': 'XUSW', 'address': '7911 S 188th St. No. 103', 'city': 'KENT', 'state': 'WA', 'country': 'USA', 'zip_code': '98032'},
    {'code': 'XUSX', 'address': '19949 Kendall Dr.', 'city': 'SAN BERNARDINO', 'state': 'CA', 'country': 'USA', 'zip_code': '92407'},
    {'code': 'XUXC', 'address': '12415 OLD LAGRANGE RD', 'city': 'LOUISVILLE', 'state': 'KY', 'country': 'USA', 'zip_code': '40245'},
    {'code': 'XUXD', 'address': '5000 Shelbyville Rd', 'city': 'Louisville', 'state': 'KT', 'country': 'USA', 'zip_code': '40207'},
    {'code': 'XUXE', 'address': '17-19 Union Sq. W.', 'city': 'NEW YORK', 'state': 'NY', 'country': 'USA', 'zip_code': '10003'},
    {'code': 'XUXZ', 'address': '5540 minor lane', 'city': 'LOUISVILLE', 'state': 'KY', 'country': 'USA', 'zip_code': '40219'},
    {'code': 'YEG1', 'address': '1440 39 Ave', 'city': 'Edmonton', 'state': 'AB', 'country': 'Canada', 'zip_code': 'T6W 1A7'},
    {'code': 'YOO1', 'address': '858 Salem Rd N', 'city': 'Ajax', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L1Z 0K4'},
    {'code': 'YOW1', 'address': '5225 Boundary Road, Navan', 'city': 'Ottawa', 'state': 'ON', 'country': 'Canada', 'zip_code': 'K4B 0L3'},
    {'code': 'YVR2', 'address': '450 Derwent Pl.', 'city': 'Delta', 'state': 'BC', 'country': 'Canada', 'zip_code': 'V3M 5Y9'},
    {'code': 'YVR3', 'address': '109 Braid Street', 'city': 'New Westminster', 'state': 'BC', 'country': 'Canada', 'zip_code': 'V3L5H4'},
    {'code': 'YVR4', 'address': '4189 Salish Sea Drive', 'city': 'Tsawwassen', 'state': 'BC', 'country': 'Canada', 'zip_code': 'V4M 0B9'},
    {'code': 'YXX2', 'address': '16131 Blundell Rd', 'city': 'Richmond', 'state': 'BC', 'country': 'Canada', 'zip_code': 'V6W 0A3'},
    {'code': 'YYC1', 'address': '293069 Colonel Robertson Way', 'city': 'Calgary', 'state': 'AB', 'country': 'Canada', 'zip_code': 'T0M 0E0'},
    {'code': 'YYZ1', 'address': '6363 Millcreek Drive', 'city': 'Mississauga', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L5N 1L8'},
    {'code': 'YYZ2', 'address': '2750 Peddie Rd', 'city': 'Milton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L9T 0K1'},
    {'code': 'YYZ3', 'address': '7995 Winston Churchill Blvd.', 'city': 'Brampton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L6Y 5Z4'},
    {'code': 'YYZ4', 'address': '8050 Heritage Road', 'city': 'Brampton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L6Y 0C9'},
    {'code': 'YYZ6', 'address': '8050 Heritage Road', 'city': 'Brampton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L6Y0C9'},
    {'code': 'YYZ7', 'address': '12724 COLERAINE DR', 'city': 'Bolton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L7E 4L8'},
    {'code': 'YYZ9', 'address': '900 Passmore Ave', 'city': 'Scarborough', 'state': 'ON', 'country': 'Canada', 'zip_code': 'M1X 0A1'},
    {'code': 'ZAP1', 'address': '9101 Minor Lane', 'city': 'LOUISVILLE', 'state': 'KY', 'country': 'USA', 'zip_code': '40219'},
    {'code': 'ZAP2', 'address': '9101 Minor Lane', 'city': 'Louisville', 'state': 'KY', 'country': 'USA', 'zip_code': '40219'},
    {'code': 'ZAP3', 'address': '12415 OLD LAGRANGE RD', 'city': 'LOUISVILLE', 'state': 'KY', 'country': 'USA', 'zip_code': '40245'},
    {'code': 'ZYO1', 'address': '3850 21st St', 'city': 'Long Island City', 'state': 'NY', 'country': 'USA', 'zip_code': '11101-3604'},
    {'code': 'ZYO2', 'address': '1894 SHORE PARKWAY', 'city': 'BROOKLYN', 'state': 'NY', 'country': 'USA', 'zip_code': '11214'},
    {'code': 'PIT1', 'address': '2250 Roswell Drive', 'city': 'Pittsburgh', 'state': 'PA', 'country': 'USA', 'zip_code': '15205'},
    {'code': 'YEG2', 'address': '27383 92 Ave', 'city': 'Parkland', 'state': 'AB', 'country': 'Canada', 'zip_code': 'T7X 2X2'},
    {'code': 'YYC4', 'address': '6635 106 Ave SE', 'city': 'Calgary', 'state': 'AB', 'country': 'Canada', 'zip_code': 'T2C 2X8'},
    {'code': 'RDU4', 'address': '6309 Bragg Blvd', 'city': 'Fayetteville', 'state': 'NC', 'country': 'USA', 'zip_code': '28303'},
    {'code': 'HGR6', 'address': '55 W Oak Ridge Dr', 'city': 'Hagerstown', 'state': 'MD', 'country': 'USA', 'zip_code': '21740'},
    {'code': 'WBW2', 'address': '1300 Corporate Way', 'city': 'Olyphant', 'state': 'PA', 'country': 'USA', 'zip_code': '18447'},
    {'code': 'YXU1', 'address': '11884 Sunset Dr', 'city': 'St. Thomas', 'state': 'ON', 'country': 'Canada', 'zip_code': 'N6L 1H8'},
    {'code': 'YHM1', 'address': 'Aeropark Blvd', 'city': 'Hamilton', 'state': 'ON', 'country': 'Canada', 'zip_code': 'L0R 1W0'},
    {'code': 'YOW3', 'address': '222 Citigate Dr, Barrhaven', 'city': 'Ottawa', 'state': 'ON', 'country': 'Canada', 'zip_code': 'K2J 6K7'},
    {'code': 'IAH3', 'address': '15525 Milner Rd', 'city': 'Houston', 'state': 'TX', 'country': 'USA', 'zip_code': '77032'},
    {'code': 'PBI3', 'address': '7600 LTC Parkway', 'city': 'Port Saint Lucie', 'state': 'FL', 'country': 'USA', 'zip_code': '34981'},
    {'code': 'HAJ1', 'address': 'Zur alten Molkerei 1', 'city': 'Helmstedt', 'state': '', 'country': 'Germany', 'zip_code': '38350'},
    {'code': 'DTM2', 'address': 'Kaltbandstrabe 4', 'city': 'Dortmund', 'state': '', 'country': 'Germany', 'zip_code': '44145'},
    {'code': 'BHX4', 'address': 'Lyons Park, Sayer Dr', 'city': 'Coventry', 'state': '', 'country': 'United Kingdom', 'zip_code': 'CV5 9PF'},
    {'code': 'LBA4', 'address': 'Toronto Way', 'city': 'Doncaster', 'state': '', 'country': 'United Kingdom', 'zip_code': 'DN11 0BF'},
    {'code': 'BHX2', 'address': '15B Beveridge Ln, Ellistown', 'city': 'Coalville', 'state': '', 'country': 'United Kingdom', 'zip_code': 'LE67 1FB'},
    {'code': 'LCY2', 'address': 'London Distribution Park, Windrush Rd', 'city': 'Tilbury', 'state': '', 'country': 'United Kingdom', 'zip_code': 'RM18 7AN'},
    {'code': 'HAM2', 'address': 'Borgwardstrabe 10', 'city': 'Winsen', 'state': '', 'country': 'Germany', 'zip_code': '21423'},
    {'code': 'WRO5', 'address': 'Okmiany 3', 'city': 'Okmiany', 'state': '', 'country': 'Poland', 'zip_code': '59-225'},
    {'code': 'XDS1', 'address': 'Geodis, Gateway 4 Jasckson Lane, Dale view', 'city': 'Doncaster', 'state': '', 'country': 'United Kingdom', 'zip_code': 'DN3 3EA'},
    {'code': 'MAN2', 'address': '1 Orion Blvd, Great Sankey, Burtonwood', 'city': 'Warrington', 'state': '', 'country': 'United Kingdom', 'zip_code': 'WA5 3XA'},
    {'code': 'MAN3', 'address': 'Bridgewater Ave', 'city': 'Bolton', 'state': '', 'country': 'United Kingdom', 'zip_code': 'BL5 1BT'},
    {'code': 'BRS1', 'address': 'Severn Beach', 'city': 'Bristol', 'state': '', 'country': 'United Kingdom', 'zip_code': 'BS35 4DJ'},
    {'code': 'LCJ4', 'address': 'Jozefow 3a', 'city': 'Lodz', 'state': '', 'country': 'Poland', 'zip_code': '93-614'},
    {'code': 'LCJ3', 'address': 'Jozefow 3a', 'city': 'Lodz', 'state': '', 'country': 'Poland', 'zip_code': '93-614'},
    {'code': 'RMN3', 'address': '220 Centreport Pkwy', 'city': 'Fredericksburg', 'state': 'VA', 'country': 'USA', 'zip_code': '22406'},
    {'code': 'LBE1', 'address': '165 Glenn Fox Rd', 'city': 'New Stanton', 'state': 'PA', 'country': 'USA', 'zip_code': '15672'}
]